@@ -1,8 +1,8 @@
 <?php
 $lang['warning_cron_updated'] = 'Ce test est g&eacute;n&eacute;r&eacute; sur une base peu fr&eacute;quente. Il peut prendre un certain temps pour se terminer.';
 $lang['none'] = 'Aucun';
-$lang['ssl'] = 'SSL ';
-$lang['tls'] = 'TLS ';
+$lang['ssl'] = 'SSL&nbsp;';
+$lang['tls'] = 'TLS&nbsp;';
 $lang['secure'] = 'Protocole de s&eacute;curisation&nbsp;';
 $lang['info_secure'] = 'Applicable uniquement &agrave; la m&eacute;thode de courrier SMTP, cette option permet de sp&eacute;cifier les diff&eacute;rents protocole de s&eacute;curisation pour la connexion';
 $lang['info_cmsmailer'] = 'Ce module est utilis&eacute; par de nombreux autres modules pour faciliter l&#039;envoi d&#039;emails. Il doit &ecirc;tre correctement configur&eacute; pour votre h&eacute;bergement. Utiliser les informations fournies par votre h&eacute;bergeur pour r&eacute;gler ces param&egrave;tres. Si vous ne parvenez toujours pas  &agrave; envoyer le message de test correctement, vous devez contacter votre h&eacute;bergeur pour obtenir de l&#039;aide.';
@@ -37,7 +37,7 @@ $lang['info_timeout'] = 'Nombre de secondes dans une conversation SMTP avant qu&
 $lang['info_smtpauth'] = 'Votre serveur SMTP requiert-il une authentification&nbsp;? (seulement valable pour la m&eacute;thode mail SMTP)';
 $lang['info_username'] = 'Nom d&#039;utilisateur de l&#039;authentification SMTP (seulement valable pour la m&eacute;thode mail SMTP, quand l&#039;authentification est s&eacute;lectionn&eacute;e)';
 $lang['info_password'] = 'Mot de passe de l&#039;authentification SMTP (seulement valable pour la m&eacute;thode mail SMTP, quand l&#039;authentification est s&eacute;lectionn&eacute;e)';
-$lang['friendlyname'] = 'CMSMailer ';
+$lang['friendlyname'] = 'CMSMailer&nbsp;';
 $lang['postinstall'] = 'Le module CMSMailer a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
 $lang['postuninstall'] = 'Le module CMSMailer a &eacute;t&eacute; d&eacute;sinstall&eacute;. D&eacute;sol&eacute;e de vous voir partir...';
 $lang['uninstalled'] = 'Module d&eacute;sinstall&eacute;.';
@@ -45,6 +45,8 @@ $lang['installed'] = 'La version %s du module a &eacute;t&eacute; install&eacute
 $lang['accessdenied'] = 'Acc&egrave;s refus&eacute;. Veuillez v&eacute;rifier vos permissions.';
 $lang['error'] = 'Erreur&nbsp;!';
 $lang['upgraded'] = 'Le module a &eacute;t&eacute; mis &agrave; jour &agrave; la version %s.';
+$lang['settings_title'] = 'Param&egrave;tres';
+$lang['test_title'] = 'Tests';
 $lang['title_mod_prefs'] = 'Pr&eacute;f&eacute;rences du module';
 $lang['title_mod_admin'] = 'Panneau d&#039;administration du module';
 $lang['title_admin_panel'] = 'CMSMailer';
@@ -321,6 +323,9 @@ $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
 
 <h3>Copyright et Licence</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com">calguy1000@hotmail.com</a>. Tous droits r&eacute;serv&eacute;s.</p>
-<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>
-';
+<p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
+$lang['utmz'] = '156861353.1381129428.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.2108348773.1381129428.1381171567.1381217291.4';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
