@@ -10,8 +10,8 @@ $lang['charset'] = 'set di caratteri';
 $lang['sendtestmailconfirm'] = 'Questo spedisce un messaggio di test all&#039;indirizzo specificato. Se la spedizione ha successo, dovreste ritornare a questa pagina. Vuoi procedere?';
 $lang['settingsconfirm'] = 'Scrivo i valori correnti nella configurazione di CMSMailer?';
 $lang['testsubject'] = 'Messaggio di test di CMSMailer';
-$lang['testbody'] = 'Questo messaggio &egrave; inteso a verificare solamente la validit&agrave; della configurazione del modulo CMSMailer.
-Se ricevete questo messaggio significa che sta funzionando a dovere.';
+$lang['testbody'] = 'Questo messaggio &egrave; inteso solo come verifica della validit&agrave; della configurazione del modulo CMSMailer.
+Se ricevete questo messaggio significa tutto sta funzionando a dovere.';
 $lang['error_notestaddress'] = 'Errore: Indirizzo di test non specificato';
 $lang['prompt_testaddress'] = 'Indirizzo email di test';
 $lang['sendtest'] = 'Spedisci il messaggio di test';
@@ -21,25 +21,25 @@ $lang['smtpauth'] = 'Autenticazione SMTP';
 $lang['mailer'] = 'Metodo di spedizione';
 $lang['host'] = 'Nome server SMTP<br /><i>(o indirizzo IP)</i>';
 $lang['port'] = 'Porta del server SMTP';
-$lang['from'] = 'Indirizzo From (Da)';
-$lang['fromuser'] = 'Nome utente From (Da)';
-$lang['sendmail'] = 'Locazione del Sendmail';
+$lang['from'] = 'Indirizzo Mittente';
+$lang['fromuser'] = 'Nome Mittente';
+$lang['sendmail'] = 'Percorso di Sendmail';
 $lang['timeout'] = 'Timeout SMTP';
-$lang['submit'] = 'Inoltra';
-$lang['cancel'] = 'Cancella';
-$lang['info_mailer'] = 'Metodo usato per la spedizione (sendmail, smtp, mail). Di solito smtp &egrave; il pi&ugrave; utilizzato.';
+$lang['submit'] = 'Invia';
+$lang['cancel'] = 'Annulla';
+$lang['info_mailer'] = 'Metodo di spedizione da usare (sendmail, smtp, mail). Di solito smtp &egrave; il pi&ugrave; affidabile.';
 $lang['info_host'] = 'Nome server SMTP (valido solo per il metodo di spedizione smtp)';
 $lang['info_port'] = 'Numero porta SMTP (di solito 25) (valido solo per il metodo di spedizione smtp)';
-$lang['info_from'] = 'Indirizzo usato per la spedizione di tutte le email.<br/><strong>Nota</strong>, questo indirizzo email deve essere configurato correttamente per il vostro host o Voi avrete difficolt&agrave; a spedire email.<br/>Se Voi non conoscete il valore corretto per questa configurazione, Voi dovreste contattare il vostro host.';
-$lang['info_fromuser'] = 'Nome reale per la spedizione di tutte le email';
+$lang['info_from'] = 'Indirizzo usato come mittente per la spedizione di tutte le email.<br/><strong>Nota</strong>, questo indirizzo email deve essere configurato correttamente per il vostro host o avrete difficolt&agrave; a spedire email.<br/>Se non conoscete il valore corretto di questa impostazione, dovreste contattare il vostro host.';
+$lang['info_fromuser'] = 'Nome utilizzato per la spedizione di tutte le email';
 $lang['info_sendmail'] = 'Il percorso completo del programma sendmail (valido solo per il metodo di spedizione smtp)';
-$lang['info_timeout'] = 'Il numero di secondi nella conversazione SMTP prima che accada un errore (valido solo per il metodo di spedizione smtp)';
-$lang['info_smtpauth'] = 'Se il server smtp richiede autenticazione (valido solo per il metodo di spedizione smtp)';
-$lang['info_username'] = 'Nome utente dell&#039;autenticazione SMTP (valido solo per il metodo di spedizione smtp, quando &egrave; selezionata l&#039;autenticazione smtp)';
+$lang['info_timeout'] = 'Il numero di secondi nella conversazione SMTP prima che si verifichi un errore (valido solo per il metodo di spedizione smtp)';
+$lang['info_smtpauth'] = 'Il server smtp richiede autenticazione (valido solo per il metodo di spedizione smtp)';
+$lang['info_username'] = 'Nome utente per l&#039;autenticazione SMTP (valido solo per il metodo di spedizione smtp, quando &egrave; selezionata l&#039;autenticazione smtp)';
 $lang['info_password'] = 'Password dell&#039;autenticazione SMTP (valido solo per il metodo di spedizione smtp, quando &egrave; selezionata l&#039;autenticazione smtp)';
 $lang['friendlyname'] = 'CMSMailer ';
 $lang['postinstall'] = 'Il modulo CMSMailer &egrave; stato installato con successo';
-$lang['postuninstall'] = 'Disinstallazione del Modulo CMSMailer ...';
+$lang['postuninstall'] = 'Modulo CMSMailer disinstallato';
 $lang['uninstalled'] = 'Modulo disinstallato.';
 $lang['installed'] = 'Versione del modulo %s installata.';
 $lang['accessdenied'] = 'Accesso negato. Si prega di controllare i permessi.';
@@ -61,11 +61,13 @@ $lang['changelog'] = '<ul>
 <li>Version 1.73.9. January, 2006. Added test email capability, and confirmation on each button (except cancel)</li>
 <li>Version 1.73.10. August, 2006. Modified to use lazy loading to minimize memory footprint when CMSMailer is not being used.</li>
 <li>Version 1.73.13. January, 2008.  Added more permissions checks.</li>
+<li>Version 2.0.1 - January, 2011 - Remove cancel button.</li>
+<li>Version 2.0.2 - September, 2011 - Set default charset to utf-8.</li>
 </ul>';
 $lang['help'] = '<h3>Che cosa fa?</h3>
 <p>Questo modulo non provvede nessuna funzionalit&agrave; utente. E&#039; disegnato per essere integrato in altri moduli per provvedere la capacit&agrave; di spedizione emails.</p>
 <h3>Come usarlo</h3>
-<p>Questo modulo provvede un semplice wrapper per tutti i metodi e le variabili di phpmailer. E&#039; disegnato per essere usato da altri sviluppatori di moduli, sotto viene riportato un esempio ed un breve riferimento di API. Si prega, per pi&ugrave; informazioni, di leggere la documentazione di PHPMailer inclusa.</p>
+<p>Questo modulo fornisce un semplice wrapper per tutti i metodi e le variabili di phpmailer. E&#039; disegnato per essere usato da altri sviluppatori di moduli, sotto viene riportato un esempio ed un breve riferimento di API. Si prega, per pi&ugrave; informazioni, di leggere la documentazione di PHPMailer inclusa.</p>
 <h3>Un esempio</h3>
 <pre>
   $cmsmailer = $this->GetModuleInstance(&#039;CMSMailer&#039;);
@@ -319,7 +321,6 @@ $lang['help'] = '<h3>Che cosa fa?</h3>
 <h3>Copyright e licenza</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. Tutti i diritti sono riservati.</p>
 <p>Questo modulo &egrave; stato rilasciato sotto la <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. Devi aderire a questa licenza prima di usare il modulo.</p>';
-$lang['utma'] = '57867837.1696517728.1316529586.1320422930.1320656021.5';
-$lang['utmz'] = '57867837.1316529586.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-1222936636-1320224029415';
+$lang['utma'] = '107768413.761460248.1357753980.1357753980.1357753980.1';
+$lang['utmz'] = '107768413.1357753980.1.1.utmcsr=solgea.net|utmccn=(referral)|utmcmd=referral|utmcct=/cmsms/admin/editcontent.php';
 ?>
\ No newline at end of file
