@@ -1,49 +1,54 @@
 <?php
-$lang['info_cmsmailer'] = 'This module is used by numerous other modules to facilitate sending emails.  It must be properly configured to your hosts requirements.  Please use the information provided by your host to adjust these settings.  If you still cannot get the test message to send properly, you may have to contact your host for assistance.';
-$lang['charset'] = 'Simbolių kodavimas';
-$lang['sendtestmailconfirm'] = 'This will send a test message to the address specified. If the send process suceeded, you will be returned to this page.  Do you want to continue?';
-$lang['settingsconfirm'] = 'Įra&scaron;yti konkrečias reik&scaron;mes į CMSmailer nustaymus?';
-$lang['testsubject'] = 'CMSMailer Bandomoji žinutė';
-$lang['testbody'] = 'This message is intended only to verify the validity of the settings in the CMSMailer module.
-If you received it, everything is working fine.';
-$lang['error_notestaddress'] = 'Klaida: nenurodytas testinis adresas';
-$lang['prompt_testaddress'] = 'Testinis el. pa&scaron;to adresas';
-$lang['sendtest'] = 'Siųsti testinę žinutę';
+$lang['warning_cron_updated'] = '&Scaron;is testas generuojamas nedažnai. Jam i&scaron;nykti gali prireikti &scaron;iek tiek laiko.';
+$lang['none'] = 'Joks';
+$lang['ssl'] = 'SSL';
+$lang['tls'] = 'TLS';
+$lang['secure'] = '&Scaron;ifravimo būdas';
+$lang['info_secure'] = '&Scaron;i parinktis, taikoma tik SMTP lai&scaron;kų siuntimo metodui, leidžia pasirinkti ry&scaron;io &scaron;ifravimo būdą';
+$lang['info_cmsmailer'] = 'Nemažai kitų modulių naudojasi &scaron;iuo, siųsdami elektroninius lai&scaron;kus. Prie&scaron; &scaron;iuo moduliu naudojantis, jį reikia sukonfigūruoti. Keisdami &scaron;ias nuostatas, atsižvelkite į Jums suteiktus serverio duomenis ir nustatymus. Jeigu testinio lai&scaron;ko i&scaron;siųsti vis tiek nepavyks, Jums gali tekti kreiptis pagalbos į prieglobos paslaugos teikėją.';
+$lang['charset'] = 'Teksto koduotė';
+$lang['sendtestmailconfirm'] = 'Bus bandoma nurodytu adresu i&scaron;siųsti bandomąjį lai&scaron;ką. Jeigu pavyks, bus sugrįžta atgal į &scaron;į tinklapį. Ar norite tęsti?';
+$lang['settingsconfirm'] = 'Įra&scaron;yti &scaron;ias &bdquo;CMSmailer&ldquo; modulio nuostatas?';
+$lang['testsubject'] = '&bdquo;CMSMailer&ldquo; bandomasis lai&scaron;kas';
+$lang['testbody'] = '&Scaron;is lai&scaron;kas skirtas patikrinti, ar &bdquo;CMSMailer&ldquo; modulio nuostatos yra tinkamos lai&scaron;kams siųsti.
+Jeigu gavote &scaron;į lai&scaron;ką, vadinasi, viskas veikia tvarkingai.';
+$lang['error_notestaddress'] = 'Klaida: nenurodytas adresas bandomajam lai&scaron;kui siųsti';
+$lang['prompt_testaddress'] = 'El. pa&scaron;to adresas bandomajam lai&scaron;kui siųsti';
+$lang['sendtest'] = 'Siųsti bandomąjį lai&scaron;ką';
 $lang['password'] = 'Slaptažodis';
-$lang['username'] = 'Vartotojo vardas';
-$lang['smtpauth'] = 'SMTP autentifikacija';
-$lang['mailer'] = 'Mailer metodas';
-$lang['host'] = 'SMTP host name<br/><i>(arba IP adresas)</i>';
-$lang['port'] = 'SMTP serverio portas';
-$lang['from'] = 'I&scaron; adreso';
-$lang['fromuser'] = 'Nuo Vartotojo';
-$lang['sendmail'] = 'Sendmail vieta';
-$lang['timeout'] = 'SMTP timeoutas';
-$lang['submit'] = 'Siųsti';
-$lang['cancel'] = 'At&scaron;aukti';
-$lang['info_mailer'] = 'E. lai&scaron;kų siuntimo metodas (sendmail, smtp, mail). Dažnai smtp metodas yra patikimiausias.';
-$lang['info_host'] = 'SMTP serverio vardas (tinka tik smtp metodui)';
-$lang['info_port'] = 'SMTP porto numeris (dažniausiai 25) (tinka tik smtp metodui)';
-$lang['info_from'] = 'Adresas, kuris bus visuose lai&scaron;kuose naudojamas kaip siuntėjas';
-$lang['info_fromuser'] = 'Friendly name used for sending all emails';
-$lang['info_sendmail'] = 'The complete path to your sendmail executable (only valid for the sendmail mailer method)';
-$lang['info_timeout'] = 'The number of seconds in an SMTP conversation before an error occurs (valid for the smtp mailer method)';
-$lang['info_smtpauth'] = 'Ar smtp serveris reikalauja autentifikacijos  (tinka tik smtp metodui)';
-$lang['info_username'] = 'SMTP naudotojo vardas  (tinka tik smtp metodui, kai pasirinkta smtp autentifikacija)';
-$lang['info_password'] = 'SMTP naudotojo slaptažodis (tinka tik smtp metodui, kai pasirinkta smtp autentifikacija)';
-$lang['friendlyname'] = 'CMSMailer modulis';
-$lang['postinstall'] = 'CMSMailer modulis sėkmingai įdiegtas';
-$lang['postuninstall'] = 'CMSMailer modulis pa&scaron;alintas.';
+$lang['username'] = 'Naudotojo vardas';
+$lang['smtpauth'] = 'SMTP autentikacija';
+$lang['mailer'] = 'Lai&scaron;kų siuntimo metodas';
+$lang['host'] = 'SMTP serverio vardas<br/><i>(arba IP adresas)</i>';
+$lang['port'] = 'SMTP serverio prievadas';
+$lang['from'] = 'Siuntėjo adresas';
+$lang['fromuser'] = 'Siuntėjo vardas';
+$lang['sendmail'] = 'Kelias iki &bdquo;sendmail&ldquo;';
+$lang['timeout'] = 'SMTP laiko limitas';
+$lang['submit'] = 'Įra&scaron;yti';
+$lang['cancel'] = 'Atsisakyti';
+$lang['info_mailer'] = 'Elektroninių lai&scaron;kų siuntimo metodas (&bdquo;sendmail&ldquo;, &bdquo;smtp&ldquo;, &bdquo;mail&ldquo;). Dažnai &bdquo;smtp&ldquo; metodas yra patikimiausias.';
+$lang['info_host'] = 'SMTP serverio vardas (galioja tik &bdquo;smtp&ldquo; metodui)';
+$lang['info_port'] = 'SMTP serverio prievadas (dažniausiai 25) (galioja tik &bdquo;smtp&ldquo; metodui)';
+$lang['info_from'] = 'Lai&scaron;kuose naudotinas siuntėjo adresas. <br/><strong>Pastaba:</strong> reikia nurodyti serveriui priimtiną adresą, prie&scaron;ingu atveju siunčiant lai&scaron;kus, kiltų problemų.<br/>Jeigu nežinote teisingos reik&scaron;mės, bandykite susisiekti su prieglobos paslaugos teikėju.';
+$lang['info_fromuser'] = 'Lai&scaron;kuose naudotinas siuntėjo vardas';
+$lang['info_sendmail'] = 'Pilnas kelias iki &bdquo;sendmail&ldquo; vykdomojo failo (galioja tik &bdquo;sendmail&ldquo; metodui)';
+$lang['info_timeout'] = 'Kiek ilgiausiai sekundžių gali trukti SMTP ry&scaron;ys. Užtrukus ilgiau, bus grąžinama klaida (galioja tik &bdquo;smtp&ldquo; metodui)';
+$lang['info_smtpauth'] = 'Ar SMTP serveris reikalauja autentikacijos  (galioja tik &bdquo;smtp&ldquo; metodui)';
+$lang['info_username'] = 'SMTP naudotojo vardas  (galioja tik &bdquo;smtp&ldquo; metodui, kai pasirinkta SMTP autentikacija)';
+$lang['info_password'] = 'SMTP naudotojo slaptažodis (galioja tik &bdquo;smtp&ldquo; metodui, kai pasirinkta SMTP autentifikacija)';
+$lang['friendlyname'] = '&bdquo;CMSMailer&ldquo; modulis';
+$lang['postinstall'] = '&bdquo;CMSMailer&ldquo; modulis sėkmingai įdiegtas';
+$lang['postuninstall'] = '&bdquo;CMSMailer&ldquo; modulis pa&scaron;alintas';
 $lang['uninstalled'] = 'Modulis pa&scaron;alintas.';
 $lang['installed'] = 'Įdiegta modulio %s versija.';
-$lang['accessdenied'] = 'Priėjimas uždraustas. Patikrinkite leidimus.';
+$lang['accessdenied'] = 'Prieiga uždrausta. Patikrinkite leidimus.';
 $lang['error'] = 'Klaida!';
-$lang['upgraded'] = 'Modulio versija atnaujinta į %s.';
-$lang['title_mod_prefs'] = 'Modulio nustatymai';
+$lang['upgraded'] = 'Modulis atnaujintas iki %s versijos.';
+$lang['title_mod_prefs'] = 'Modulio nuostatos';
 $lang['title_mod_admin'] = 'Modulio administravimas';
-$lang['title_admin_panel'] = 'CMSMailer modulis';
-$lang['moddescription'] = 'This is a simple wrapper around PHPMailer, it has an equivalent API (function for function) and a simple interface for some defaults.';
-$lang['welcome_text'] = '<p>Sveiki atvykę į CMSMailer modulio administravimo sekciją';
+$lang['title_admin_panel'] = '&bdquo;CMSMailer&ldquo; modulis';
+$lang['moddescription'] = 'Tai &ndash; paprastas &bdquo;PHPMailer&ldquo; apvalkalas, turintis ekvivalenčią API sąsają ir patogią sąsają numatytosioms reik&scaron;mėms nustatyti.';
 $lang['changelog'] = '<ul>
 <li>Version 1.73.1. October, 2005. Initial Release.</li>
 <li>Version 1.73.2. October, 2005. Minor bug fix with the admin panel.  The dropdown was not representing the current value from the preferences database</li>
@@ -54,6 +59,10 @@ $lang['changelog'] = '<ul>
 <li>Version 1.73.7. January, 2006. Increased field lengths in most fields</li>
 <li>Version 1.73.8. January, 2006. Changed the preferences panel to be a bit more descriptive.</li>
 <li>Version 1.73.9. January, 2006. Added test email capability, and confirmation on each button (except cancel)</li>
+<li>Version 1.73.10. August, 2006. Modified to use lazy loading to minimize memory footprint when CMSMailer is not being used.</li>
+<li>Version 1.73.13. January, 2008.  Added more permissions checks.</li>
+<li>Version 2.0.1 - January, 2011 - Remove cancel button.</li>
+<li>Version 2.0.2 - September, 2011 - Set default charset to utf-8.</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module provides no end user functionality.  It is designed to be integrated into other modules to provide email capabilities.  Thats it, nothing more.</p>
@@ -63,7 +72,7 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <pre>
   $cmsmailer = $this->GetModuleInstance(&#039;CMSMailer&#039;);
   $cmsmailer->AddAddress(&#039;calguy1000@hotmail.com&#039;,&#039;calguy&#039;);
-  $cmsmailer->SetBody(&#039;<h1>This is a test message<h1>&#039;);
+  $cmsmailer->SetBody(&#039;&amp;lt;h4&amp;gt;This is a test message&amp;lt;/h4&amp;gt;&#039;);
   $cmsmailer->IsHTML(true);
   $cmsmailer->SetSubject(&#039;Test message&#039;);
   $cmsmailer->Send();
@@ -302,20 +311,19 @@ $lang['help'] = '<h3>What Does This Do?</h3>
 <h3>Support</h3>
 <p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
 <ul>
-<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguys homepage at <a href="http://techcom.dyndns.org">techcom.dyndns.org</a>.</li>
-<li>Additional discussion of this module may also be found in the <a href="http://forum.cmsmadesimple.org">CMS Made Simple Forums</a>.</li>
-<li>The author, calguy1000, can often be found in the <a href="irc://irc.freenode.net/#cms">CMS IRC Channel</a>.</li>
+<li>For the latest version of this module, FAQs, or to file a Bug Report or buy commercial support, please visit calguys homepage at <a href=&#039;http://techcom.dyndns.org&#039;>techcom.dyndns.org</a>.</li>
+<li>Additional discussion of this module may also be found in the <a href=&#039;http://forum.cmsmadesimple.org&#039;>CMS Made Simple Forums</a>.</li>
+<li>The author, calguy1000, can often be found in the <a href=&#039;irc://irc.freenode.net/#cms&#039;>CMS IRC Channel</a>.</li>
 <li>Lastly, you may have some success emailing the author directly.</li>  
 </ul>
 <p>As per the GPL, this software is provided as-is. Please read the text
 of the license for the full disclaimer.</p>
 
 <h3>Copyright and License</h3>
-<p>Copyright &copy; 2005, Robert Campbell <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
-<p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>
-';
-$lang['utma'] = '156861353.2019063869.1234011242.1235937699.1236412787.12';
-$lang['utmz'] = '156861353.1236412787.12.10.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utmb'] = '156861353';
+<p>Copyright &amp;copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;>&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
+<p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
+$lang['utma'] = '156861353.1536208981.1367699838.1369929121.1369932008.3';
+$lang['utmz'] = '156861353.1369932008.3.3.utmccn=(organic)|utmcsr=google|utmctr=|utmcmd=organic';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
