@@ -45,6 +45,8 @@ $lang['installed'] = 'Instalirana je %s verzija modula.';
 $lang['accessdenied'] = 'Pristup nije dozvoljen. Molimo proverite dozvole.';
 $lang['error'] = 'Gre&scaron;ka!';
 $lang['upgraded'] = 'Modul je nadograđen u verziju %s.';
+$lang['settings_title'] = 'Pode&scaron;avnaja';
+$lang['test_title'] = 'Testiranje';
 $lang['title_mod_prefs'] = 'Pode&scaron;avanja modula';
 $lang['title_mod_admin'] = 'Administratorski panel modula';
 $lang['title_admin_panel'] = 'CMSMailer Modul';
@@ -319,10 +321,9 @@ of the license for the full disclaimer.</p>
 
 <h3>Copyright and License</h3>
 <p>Copyright &copy; 2005, Robert Campbell <a href=&#039;mailto:calguy1000@hotmail.com&#039;><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
-<p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>
-';
-$lang['utma'] = '156861353.911854766.1328710628.1328710628.1328710628.1';
-$lang['utmz'] = '156861353.1328710628.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+<p>This module has been released under the <a href=&#039;http://www.gnu.org/licenses/licenses.html#GPL&#039;>GNU Public License</a>. You must agree to this license before using the module.</p>';
+$lang['utma'] = '156861353.114482514.1383506026.1383506026.1383510479.2';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1383506026.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
