@@ -1,6 +1,6 @@
 <?php
-$lang['friendlyname'] = 'Impression';
-$lang['description'] = 'Ce module permet de personnaliser l&#039;affichage de pages pour impression pour CMSMS.  ';
+$lang['friendlyname'] = 'Impression CMSPrinting';
+$lang['description'] = 'Ce module permet de personnaliser l&#039;affichage de pages pour impression pour CMSMS&trade;.';
 $lang['postinstall'] = 'Le module a &eacute;t&eacute; install&eacute; avec succ&egrave;s';
 $lang['confirmuninstall'] = '&Ecirc;tes-vous s&ucirc;r de vouloir d&eacute;sinstaller le module ?';
 $lang['postuninstall'] = 'Le module a &eacute;t&eacute; d&eacute;sinstall&eacute; avec succ&egrave;s';
@@ -9,7 +9,7 @@ $lang['printtemplate'] = 'Gabarit d&#039;impression';
 $lang['templatesaved'] = 'Le gabarit a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s';
 $lang['templatereset'] = 'Le gabarit a &eacute;t&eacute; r&eacute;initialis&eacute; avec succ&egrave;s';
 $lang['confirmresettemplate'] = '&Ecirc;tes-vous s&ucirc;r de vouloir r&eacute;initialiser le gabarit &agrave; son contenu par d&eacute;faut ?';
-$lang['reset'] = 'R&eacute;initialiser par d&eacute;faut ';
+$lang['reset'] = 'R&eacute;initialiser par d&eacute;faut';
 $lang['save'] = 'Sauvegarder';
 $lang['upgraded'] = 'A &eacute;t&eacute; mis &agrave; jour &agrave; la version %s';
 $lang['savetemplate'] = 'Sauvegarder le gabarit';
@@ -54,4 +54,8 @@ Dans votre page o&ugrave; votre gabarit ins&eacute;rez &agrave; l&#039;endroit d
 </pre>
 <br />pour utiliser le plugin d&#039;impression.
 <br />';
+$lang['utmz'] = '156861353.1381513532.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.251601174.1381513532.1381565946.1381570373.4';
+$lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
