@@ -32,7 +32,7 @@ $lang['help_excludeprefix'] = 'Exclut toutes les donn&eacute;es des pages (et de
 $lang['help_collapse'] = '&Agrave; activer (d&eacute;finir en 1) pour que le menu cache les objets non relatifs &agrave; la page s&eacute;lectionn&eacute;e.';
 $lang['help_items'] = 'Utilisez ceci pour s&eacute;lectionner la liste de pages &agrave; afficher dans le menu. La valeur entr&eacute;e doit &ecirc;tre la liste des alias, s&eacute;par&eacute;e par des virgules.';
 $lang['help_number_of_levels'] = 'Ce param&egrave;tre permet au menu d&#039;afficher uniquement un certain nombre de niveaux. Par d&eacute;faut la valeur de ce param&egrave;tre est suppos&eacute; &ecirc;tre illimit&eacute;e pour montrer tous les niveaux enfants. Sauf si vous utilisez le param&egrave;tre, dans lequel number_of_levels est implicite &agrave; 1 sauf s&#039;il est modifi&eacute;.';
-$lang['help_show_all'] = 'Cette option affichera tous les niveaux s&#039;ils sont coch&eacute;s visibles dans le menu. Il n&#039;affichera pas les pages inactives.';
+$lang['help_show_all'] = 'Cette option affichera tous les niveaux m&ecirc;me s&#039;ils sont configur&eacute; pour ne pas &ecirc;tre afficher dans le menu. Il n&#039;affichera pas les pages inactives.';
 $lang['help_show_root_siblings'] = 'Cette option est utile lorsque start_element ou start_page est utilis&eacute;. Les autres &eacute;l&eacute;ments du m&ecirc;me niveau que l&#039;&eacute;l&eacute;ment s&eacute;lectionn&eacute; seront affich&eacute;s.';
 $lang['help_start_level'] = 'Cette option permet d&#039;afficher uniquement les &eacute;l&eacute;ments &agrave; partir d&#039;un niveau donn&eacute;. Un exemple: vous avez un menu avec number_of_levels=&#039;1&#039;.  Puis, comme second menu, vous avez start_level=&#039;2&#039;.  Le second menu affichera les &eacute;l&eacute;ments bas&eacute;s sur ce qui est s&eacute;lectionn&eacute; dans le premier menu.';
 $lang['help_start_element'] = 'Cette option permet d&#039;afficher uniquement les &eacute;l&eacute;ments &agrave; partir d&#039;un &eacute;l&eacute;ment donn&eacute; (start_element), ainsi que les niveaux en-dessous de cet &eacute;l&eacute;ment.  la valeur doit &ecirc;tre &eacute;gale &agrave; la position hi&eacute;rarchique de l&#039;&eacute;l&eacute;ment (exemple : 5.1.2).';
@@ -88,7 +88,7 @@ $lang['help'] = '	<h3>Que fait ce module&nbsp;?</h3>
 <p>Chaque gabarit de menu peut &ecirc;tre marqu&eacute; comme &quot;&ecirc;tre mis en cache&quot;. Quand un mod&egrave;le de menu cachable est utilis&eacute;e sur une page de contenu qui est mis en cache, toute sortie de menu en cache qui est disponible pour cette page sera utilis&eacute;s. Le param&egrave;tre nocache sur l&#039;&eacute;tiquette de menu peut &ecirc;tre utilis&eacute; pour d&eacute;sactiver compl&egrave;tement la mise en cache.</p>
 <p>Tous les fichiers mis en cache menu sont effac&eacute;s si un &eacute;l&eacute;ment de contenu est ajout&eacute;, modifi&eacute; ou supprim&eacute; ... et aussi quand un gabarit de menu est ajout&eacute;/modifi&eacute; ou supprim&eacute;.</p>	
 <h3>Balise alternative :</h3>
-<p>La balise <strong>{cms_breadcrumbs}</strong>(application {menu action=breadcrumbs}) peut &ecirc;tre utilis&amp;eacute; pour cr&eacute;er un fil d&rsquo;Ariane de navigation pour la page actuellement affich&eacute;e.';
+<p>La balise <strong>{cms_breadcrumbs}</strong>(raccourci de {menu action=breadcrumbs} ) peut &ecirc;tre utilis&amp;eacute; pour cr&eacute;er un fil d&rsquo;Ariane de navigation pour la page actuellement affich&eacute;e.';
 $lang['importtemplate'] = 'Importer le gabarit dans la base de donn&eacute;es';
 $lang['menumanager'] = 'Gestion de Menu';
 $lang['newtemplate'] = 'Nom du nouveau gabarit&nbsp;';
@@ -97,6 +97,4 @@ $lang['notemplatefiles'] = 'Aucun gabarit sous forme de fichier dans %s';
 $lang['notemplatename'] = 'Aucun nom de gabarit entr&eacute;';
 $lang['templatecontent'] = 'Contenu du gabarit&nbsp;';
 $lang['templatenameexists'] = 'Un gabarit du m&ecirc;me nom existe d&eacute;j&agrave;';
-$lang['qca'] = 'P0-483686814-1251229608352';
-$lang['utma'] = '57867837.1772960952774974200.1251229608.1315083144.1315177962.175';
 ?>
\ No newline at end of file
