@@ -1,10 +1,17 @@
 <?php
+$lang['help_action'] = 'Spesifiser handlingen for denne modulen. Det er to muligheter for denne parameteren:
+<ul>
+  <li>default <em>(standard)</em> - Brukes til &aring; bygge en navigeringsmeny.</li>
+  <li>breadcrumbs - Brukes til &aring; bygge en br&oslash;dsmulesti til siden som vises til enhver tid. <strong>Merk: {cms_breadcrumbs}</strong> er en forkortet m&aring;te &aring; kalle denne handlingen.</li>
+</ul>';
+$lang['help_root'] = 'Kun gyldig for br&oslash;dsmule-handlingen, og tillater &aring; spesifisere et startniv&aring; som ikke er standardsiden.';
+$lang['youarehere'] = 'Du er her';
 $lang['set_cachable'] = 'Tillat denne malen &aring; mellomlagres';
 $lang['help_nocache'] = 'Sl&aring; av all mellomlagring for dette kallet til menyen. Denne parameteren, om den er satt til en positiv verdi, vil overstyre alle innstillinger i innholdobjektet og i malen for menyen.';
 $lang['cachable'] = 'Kan mellomlagres';
 $lang['help_childrenof'] = 'Dette valget vil gj&oslash;re at menyen kun viser enheter som er etterkommere av den valgte sideID eller alias. F.eks. s&aring; vil: <code>{menu childrenof=$page_alias}</code> kun vise barn av den gjeldende siden.';
 $lang['usage'] = 'Benyttes slik';
-$lang['import'] = 'Import ';
+$lang['import'] = 'Importer';
 $lang['edit'] = 'Rediger';
 $lang['delete'] = 'Slett';
 $lang['help_loadprops'] = 'Benytt denne parameter om du IKKE benytter avanserte egenskaper i din menybehandlermal. Denne parameter vil SL&Aring; AV lasting av alle innholdsegenskaper for hver node (som extra1, image, thumbnail, osv.). Dette vil dramatisk minske antall sp&oslash;rringer krevd for &aring; bygge en meny og minsker ogs&aring; minnekravet, men dette vil fjerne muligheten for bygging av mye mer avanserte menyer';
@@ -16,22 +23,6 @@ $lang['default'] = 'Standard';
 $lang['templates'] = 'Maler';
 $lang['addtemplate'] = 'Legg til mal';
 $lang['areyousure'] = 'Er du sikker p&aring; at du vil slette dette?';
-$lang['changelog'] = '	<ul>
-<li>1.7 - Adds the possibility to cache menumanager output to a cache file, this will remove a bunch of queries from mostly static sites.</li>
-<li>1.6.3 - Adds usage column.</li>
-<li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
-<li>1.6.1 - Add created and modified entries on each node.</li>
-<li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
-        <li>1.5.4 - Minor bugfix, now require CMS 1.5.3.</li>
-        <li>1.5.3 - Support for syntax hilighter.</li>
-        <li>1.5.2 - Added more fields available in each node in the template.</li>
-        <li>1.5 - Bump version to be compatible with 1.1 only, and add the SetParameterTypes calls</li>
-	<li>1.4.1 -- Fix a problem where menus would not show if includeprefix was not specified.
-	<li>1.4 -- Accept a comma separated list of includeprefixes or excludeprefixes</li>
-	<li>1.3 -- Added includeprefix and excludeprefix params</li>
-	<li>1.1 -- Added handling of target parameter, mainly for the Link content type</li>
-	<li>1.0 -- Initial Release</li>
-	</ul> ';
 $lang['dbtemplates'] = 'Database maler';
 $lang['description'] = 'Behandle meny maler for &aring; vise menyer p&aring; alle tenkelige m&aring;ter';
 $lang['deletetemplate'] = 'Slett mal';
@@ -42,7 +33,8 @@ $lang['help_includeprefix'] = 'Inkluder kun de punktene hvor sidealias starter m
 $lang['help_excludeprefix'] = 'Utelat alle punkter (og deres underpunkter) hvor side alias inneholder den spesifiserte forstavelsen. Denne parameter m&aring; ikke benyttes sammen med includeprefix (inkluder-prefiks) parameteren.';
 $lang['help_collapse'] = 'Sl&aring; p&aring; (sett til 1) for &aring; f&aring; menyen til &aring; skjule artikler som ikke er relatert til den valgte siden.';
 $lang['help_items'] = 'Bruk denne verdien for &aring; velge en liste av sider som denne menyen skal vise.  Verdien skal v&aelig;re en liste over side-alias separert med komma.';
-$lang['help_number_of_levels'] = 'Denne innstillingen vil bare tillate menyen &aring; vise et visst antall av niv&aring;er ned.';
+$lang['help_number_of_levels'] = 'Denne innstillingen vil bare tillate menyen &aring; vise et visst antall av niv&aring;er ned.
+Som standard er verdien for denne parameteren underforst&aring;tt &aring; v&aelig;re ubegrenset for &aring; vise alle niv&aring;er av barn. Unntatt n&aring;r du bruker  items  parameteren, i s&aring; fall number_of_levels er underforst&aring;tt &aring; v&aelig;re 1 med mindre det overstyres.';
 $lang['help_show_all'] = 'Dette valget vil gj&oslash;re at menyen vil vise alle noder selv om de eventuelt er satt til ikke &aring; vises i menyen. Men inaktive sider vil fortsatt ikke vises.';
 $lang['help_show_root_siblings'] = 'Dette valget er kun nyttig om start_element eller start_page er i bruk.  I basis vil menyen vise s&oslash;sken for det valgte start_page/element.';
 $lang['help_start_level'] = 'Dette valget vil f&aring; menyen til kun &aring; vise poster startende p&aring; et gitt niv&aring;.  Et enkelt eksempel vil v&aelig;re om du hadde en meny p&aring; siden med number_of_levels=&#039;1&#039;.  S&aring; som en andre meny, du kan ha start_level=&#039;2&#039;.  N&aring; vil din andre meny vise poster basert p&aring; hva som er valgt i den f&oslash;rste menyen.';
@@ -86,15 +78,19 @@ $lang['help'] = '	<h3>Hva gj&oslash;r denne?</h3>
 			<li>$node->image -- Dette feltet inneholder verdien av image side-egenskapen (om den ikke er tom), om ikke loadprops-parameteren er satt til &aring; IKKE laste disse egenskapene.</li>
 			<li>$node->thumbnail -- Dette feltet inneholder verdien av thumbnail side-egenskapen (om den ikke er tom), om ikke loadprops-parameteren er satt til &aring; IKKE laste disse egenskapene.</li>
 			<li>$node->target -- Dette feltet inneholder Target for lenken (om den ikke er tom), om ikke loadprops-parameteren er satt til &aring; IKKE laste disse egenskapene.</li>
-			<li>$node->created -- Enhet opprettet dato</li>
-			<li>$node->modified -- Enhet endret dato</li>
-			<li>$node->index -- Nummer for denne klyngen i hele menyen</li>
-			<li>$node->parent -- Sann om denne klyngen ar foreldre til den n&aring; valgte side</li>
+<li>$node->created -- Artikkelliste opprettelsesdato </li>
+<li>$node->modified -- Artikkelliste endret dato </li>
+<li>$node->index -- nummer for denne noden i hele menyen </li>
+<li>$node->parent -- True hvis denne noden er en forelder av den valgte side</li>
+<li>$node->current -- True hvis denne noden er valgt side </li>
 		</ul>
 	</p>
-<p> Denne modulen har funksjoner for &aring; mellomlagre sine utdata inn i statiske filer for &aring; redusere krav til minne og sql sp&oslash;rringer, og for &aring; forbedre frontend-ytelsen. Dette gir alle fordelene med statiske menyer uten det tunge involvert n&aring;r du oppretter eller redigerer sider. </p>
+        <h3>Mellomlagring</h3>
+        <p>Denne modulen har funksjoner for &aring; mellomlagre sine utdata inn i statiske filer for &aring; redusere krav til minne og sql sp&oslash;rringer, og for &aring; forbedre frontend-ytelsen. Dette gir alle fordelene med statiske menyer uten det tunge involvert n&aring;r du oppretter eller redigerer sider. </p>
         <p> Hver menymal kan v&aelig;re merket som &quot;Kan mellomlagres&quot;. N&aring;r en mellomlagret menymal brukes p&aring; en innholdside som kan mellomlagres, vil mellomlagrede menyvisinger som er tilgjengelig for denne siden vil bli brukt. Den ikke mellomlagres parameteren p&aring; menytaggen kan brukes til helt &aring; deaktivere hurtigbufring. </p>
-        <p>Alle mellomlagrede menyfiler slettes n&aring;r et innholdselement er lagt til, redigert eller slettet ... og ogs&aring; n&aring;r en menymal blir lagt til/ redigert eller slettet. </p>';
+        <p>Alle mellomlagrede menyfiler slettes n&aring;r et innholdselement er lagt til, redigert eller slettet ... og ogs&aring; n&aring;r en menymal blir lagt til/ redigert eller slettet. </p>
+        <h3>Alternative tagger:</h3>
+        <p><strong>{cms_breadcrumbs}</strong> taggen (forkortelse for {menu action=&#039;breadcrumbs}) kan benyttes for &aring; lage en br&oslash;dsmulesti til siden som til enhver tid vises.</p>';
 $lang['importtemplate'] = 'Importer mal til databasen';
 $lang['menumanager'] = 'Meny behandler';
 $lang['newtemplate'] = 'Nytt malnavn';
@@ -104,8 +100,8 @@ $lang['notemplatename'] = 'Ingen malnavn oppgitt.';
 $lang['templatecontent'] = 'Mal innhold';
 $lang['templatenameexists'] = 'En mal med dette navnet eksisterer allerede';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.402562905.1316281878.1316281878.1316287926.2';
-$lang['utmz'] = '156861353.1316281878.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.522559348.1337094363.1337438797.1337453769.8';
+$lang['utmz'] = '156861353.1337094363.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.2.10.1337453769';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1316287926';
 ?>
\ No newline at end of file
