@@ -1,5 +1,19 @@
 <?php
+$lang['help_action'] = 'Specify the behavior of the module.  There are two possiblities for this parameter:
+<ul>
+  <li>default <em>(default)</em> - Used for building a navigation menu.</li>
+  <li>breadcrumbs - Used to build a breadcrumb trail to the currently displayed page.  <strong>Note: {cms_breadcrumbs}</strong> is a short way of calling this action.</li>
+</ul>';
+$lang['help_root'] = 'Applicable only to the breadcrumbs action, allows specifying a start level that is not the default page.';
+$lang['youarehere'] = 'Voc&ecirc; est&aacute; aqui';
+$lang['set_cachable'] = 'Set this template as cachable';
+$lang['help_nocache'] = 'Disable any caching of this call to the menu.  This parameter, if set to any positive value will override any settings in the content object and the menu template.';
+$lang['cachable'] = 'Cachable';
+$lang['help_childrenof'] = 'Esta op&ccedil;&atilde;o tem o menu a exibir apenas os itens que s&atilde;o descendentes dos id da p&aacute;gina selecionada ou alias. ou seja: <code>{menu childrenof=$page_alias}</code> ir&aacute; exibir somente as sub items da p&aacute;gina actual.';
 $lang['usage'] = 'Uso';
+$lang['import'] = 'Import';
+$lang['edit'] = 'Edit';
+$lang['delete'] = 'Delete';
 $lang['help_loadprops'] = 'Use este par&acirc;metro quando utilizar propriedades avan&ccedil;adas no Template do Gestor de Menus. Este par&acirc;metro ir&aacute; for&ccedil;ar o carregamento de todos os conte&uacute;dos propriedades de cada n&oacute; (como extra1, imagem, miniatura, etc.) e ir&aacute; aumentar dramaticamente o n&uacute;mero de consultas necess&aacute;rias para construir um menu, e aumenta os requisitos de mem&oacute;ria, mas vai permitir menus mais avan&ccedil;ados';
 $lang['readonly'] = 'somente de leitura';
 $lang['error_templatename'] = 'N&atilde;o pode especificar um template com um nome terminado .tpl';
@@ -9,21 +23,6 @@ $lang['default'] = 'Padr&atilde;o';
 $lang['templates'] = 'Templates ';
 $lang['addtemplate'] = 'Adicionar Template';
 $lang['areyousure'] = 'Tem a Certeza que pertende eliminar?';
-$lang['changelog'] = '	<ul>
-<li>1.6.3 - Adds usage column.</li>
-<li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
-<li>1.6.1 - Add created and modified entries on each node.</li>
-<li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
-        <li>1.5.4 - Minor bugfix, now require CMS 1.5.3.</li>
-        <li>1.5.3 - Support for syntax hilighter.</li>
-        <li>1.5.2 - Added more fields available in each node in the template.</li>
-        <li>1.5 - Bump version to be compatible with 1.1 only, and add the SetParameterTypes calls</li>
-	<li>1.4.1 -- Fix a problem where menus would not show if includeprefix was not specified.
-	<li>1.4 -- Accept a comma separated list of includeprefixes or excludeprefixes</li>
-	<li>1.3 -- Added includeprefix and excludeprefix params</li>
-	<li>1.1 -- Added handling of target parameter, mainly for the Link content type</li>
-	<li>1.0 -- Initial Release</li>
-	</ul> ';
 $lang['dbtemplates'] = 'Base de Dados Templates';
 $lang['description'] = 'Gerir os templates do menu para exibir menus de qualquer forma imagin&aacute;vel.';
 $lang['deletetemplate'] = 'Eliminar Template';
@@ -35,12 +34,12 @@ $lang['help_excludeprefix'] = 'Excluir todos os itens (e seus filhos), que o &#0
 $lang['help_collapse'] = 'Ligue (definir a 1) para ter o menu de itens escondidos, que n&atilde;o est&atilde;o relacionadas com a actual p&aacute;gina seleccionada.';
 $lang['help_items'] = 'Use este item para seleccionar uma lista de p&aacute;ginas que este menu deve exibir. O valor deve ser uma lista de p&aacute;gina apelidos separados por v&iacute;rgulas.';
 $lang['help_number_of_levels'] = 'Esta defini&ccedil;&atilde;o s&oacute; ir&aacute; permitir o menu a exibir apenas um determinado n&uacute;mero de n&iacute;veis profundos.';
-$lang['help_show_all'] = 'Essa op&ccedil;&atilde;o far&aacute; com que o menu mostre todos os &#039;nodes&#039;, mesmo que n&atilde;o estejam definidas para mostrar no menu. Ela ainda n&atilde;o ir&aacute; exibir p&aacute;ginas inativas no entanto.';
+$lang['help_show_all'] = 'Esta op&ccedil;&atilde;o far&aacute; com que o menu mostre todos os &#039;nodes&#039; (n&oacute;s), mesmo que n&atilde;o estejam definidos para serem vistos no menu. No entanto n&atilde;o exibir&aacute; p&aacute;ginas inactivas.';
 $lang['help_show_root_siblings'] = 'Esta op&ccedil;&atilde;o s&oacute; se torna &uacute;til se start_element ou start_page forem utilizados. &Eacute; basicamente exibir&aacute; os irm&atilde;os ao lado dos seleccionados start_page/elemento.';
 $lang['help_start_level'] = 'Esta op&ccedil;&atilde;o ter&aacute; o menu a exibir apenas os itens ao iniciar um determinado n&iacute;vel. Um exemplo seria f&aacute;cil se tivesse um menu na p&aacute;gina com number_of_levels =&#039;1 &#039;. Ent&atilde;o, como um segundo menu,  ter&aacute; start_level =&#039;2 &#039;. Agora, o sue segundo menu ir&aacute; mostrar itens com base naquilo que for seleccionado no primeiro menu.';
-$lang['help_start_element'] = 'Inicia o menu a exibir um determinado elemento start_page e mostrando as filhas s&oacute;. Retorna uma hierarquia de posi&ccedil;&atilde;o (ex. 5.1.2).';
-$lang['help_start_page'] = 'Inicia o menu a exibir um determinado elemento start_page e mostrando as filhas s&oacute;. Retorna uma p&aacute;gina alias.';
-$lang['help_template'] = 'O template a utilizar para exibir o menu. Template ser&atilde;o provenientes da base de dados, a menos que o nome do modelo termine  .tpl, nesse caso em vir&atilde;o a partir de um arquivo no diret&oacute;rio templates do MenuManager (padr&atilde;o para simple_navigation.tpl)';
+$lang['help_start_element'] = 'Come&ccedil;a a exibir o men&uacute; num determinado elemento start_element e mostrando s&oacute; elementos filhos. Aceita uma posi&ccedil;&atilde;o na hierarquia (ex. 5.1.2).';
+$lang['help_start_page'] = 'Come&ccedil;a a exibir o men&uacute; num determinado elemento start_page e mostrando s&oacute; elementos filhos. Aceita o ali&aacute;s de p&aacute;gina.';
+$lang['help_template'] = 'O template a utilizar para exibir o menu. Os templates ser&atilde;o provenientes da base de dados, a menos que o nome termine em &quot;.tpl&quot;, vindo nesse caso a partir de um ficheiro no diret&oacute;rio templates do MenuManager (por defeito &quot;simple_navigation.tpl&quot;)';
 $lang['help'] = '<h3>What does this do?</h3>
 	<p>Menu Manager is a module for abstracting menus into a system that&#039;s easily usable and customizable.  It abstracts the display portion of menus into smarty templates that can be easily modified to suit the user&#039;s needs. That is, the menu manager itself is just an engine that feeds the template. By customizing templates, or make your own ones, you can create virtually any menu you can think of.</p>
 	<h3>How do I use it?</h3>
@@ -71,12 +70,12 @@ $lang['help'] = '<h3>What does this do?</h3>
 			<li>$node->menutext -- Menu Text</li>
 			<li>$node->raw_menutext -- Menu Text without having html entities converted</li>
 			<li>$node->alias -- Page alias</li>
-			<li>$node->extra1 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra1 page property.</li>
-			<li>$node->extra2 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra2 page property.</li>
-			<li>$node->extra3 -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the extra3 page property.</li>
-			<li>$node->image -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the image page property (if non empty)</li>
-			<li>$node->thumbnail -- Applicable only when the loadprops parameter is supplied on the menu tag, this field contains the value of the thumbnail page property (if non empty)</li>
-			<li>$node->target -- Applicable only when the loadprops parameter is supplied in the menu tag, this field contains Target for the link.  Will be empty if content does not set it.</li>
+			<li>$node->extra1 -- This field contains the value of the extra1 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->extra2 -- This field contains the value of the extra2 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->extra3 -- This field contains the value of the extra3 page property, unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->image -- This field contains the value of the image page property (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->thumbnail -- This field contains the value of the thumbnail page property (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
+			<li>$node->target -- This field contains Target for the link (if non empty), unless the loadprops-parameter is set to NOT load the properties.</li>
 			<li>$node->created -- Item creation date</li>
 			<li>$node->modified -- Item modified date</li>
 			<li>$node->index -- Count of this node in the whole menu</li>
@@ -89,11 +88,10 @@ $lang['newtemplate'] = 'Novo nome do template';
 $lang['nocontent'] = 'Nenhum conte&uacute;do dado ';
 $lang['notemplatefiles'] = 'Nenhum arquivo de templates em %s';
 $lang['notemplatename'] = 'Nenhum nome do template dado.';
-$lang['templatecontent'] = 'Template Conte&uacute;do';
+$lang['templatecontent'] = 'Conte&uacute;do do Template';
 $lang['templatenameexists'] = 'Um Template com esse nome j&aacute; existe';
-$lang['utma'] = '156861353.979735442.1272325796.1272383028.1272726635.4';
-$lang['utmz'] = '156861353.1272325796.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-1983650401-1272325796645';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1374162751.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.2136809862.1374162751.1374162751.1374165542.2';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
