@@ -14,7 +14,7 @@ $lang['error_request_problem'] = 'Un probl&egrave;me est survenu avec la communi
 $lang['error_searchterm'] = 'Merci de sp&eacute;cifier quelque chose pour une recherche valide';
 $lang['search_noresults'] = 'Recherche r&eacute;ussie, mais aucun r&eacute;sultat ne correspondait &agrave; l&#039;expresssion';
 $lang['advancedsearch_help'] = 'Sp&eacute;cifiez les mots &agrave; inclure ou &agrave; exclure de la recherche en utilisant un + ou -, avec des guillemets entourant une expression exacte. Exemple : +rouge -pomme +&quot;certain texte&quot;';
-$lang['search_results'] = 'R&eacute;sultats de recherche';
+$lang['search_results'] = 'R&eacute;sultats de recherche&nbsp;';
 $lang['prompt_advancedsearch'] = 'Recherche avanc&eacute;e';
 $lang['search_input'] = 'Donn&eacute;es de recherche&nbsp;';
 $lang['searchterm'] = 'Rechercher par termes';
@@ -52,18 +52,18 @@ $lang['error_permissions'] = '<strong><em>ATTENTION :</em></strong> vous n&#039;
 $lang['error_minimumrepository'] = 'La version du d&eacute;p&ocirc;t de modules n&#039;est pas compatible avec ce &quot;module manager&quot;';
 $lang['prompt_reseturl'] = 'Remettre l&#039;URL par d&eacute;faut&nbsp;';
 $lang['prompt_resetcache'] = 'Effacer les donn&eacute;es du cache local&nbsp;';
-$lang['prompt_dl_chunksize'] = 'Taille de t&eacute;l&eacute;chargement (Kb)&nbsp;';
+$lang['prompt_dl_chunksize'] = 'Taille de t&eacute;l&eacute;chargement (Koctets)&nbsp;';
 $lang['text_dl_chunksize'] = 'La taille maximale des donn&eacute;es &agrave; t&eacute;l&eacute;charger du serveur en une fois (lors de l&#039;installation d&#039;un module)';
 $lang['error_nofilesize'] = 'Aucun param&egrave;tre de taill&eacute; sp&eacute;cifi&eacute;';
 $lang['error_nofilename'] = 'Aucun param&egrave;tre de nom de fichier sp&eacute;cifi&eacute;';
-$lang['error_unsatisfiable_dependency'] = 'Vous ne trouvez pas le module n&eacute;cessaire &quot;%s&quot; (version %s sup&eacute;rieure) dans le r&eacute;f&eacute;rentiel. Il est directement requis par %s; ce qui pourrait indiquer un probl&egrave;me avec la version de ce module dans le r&eacute;f&eacute;rentiel. S&#039;il vous pla&icirc;t contacter l&#039;auteur du module. Abandon.';
+$lang['error_unsatisfiable_dependency'] = 'Le module &quot;%s&quot; (version %s sup&eacute;rieure) requis n&#039;a pas &eacute;t&eacute; trouv&eacute; dans le r&eacute;f&eacute;rentiel. Il est directement requis par %s; ce qui pourrait indiquer un probl&egrave;me avec la version de ce module dans le r&eacute;f&eacute;rentiel. Veuillez svp contacter l&#039;auteur du module. Fin de l&#039;op&eacute;ration.';
 $lang['error_checksum'] = 'Erreur Checksum. Ceci indique probablement qu&#039;il y a un fichier corrompu, soit lorsqu&#039;il a &eacute;t&eacute; t&eacute;l&eacute;charg&eacute; sur le d&eacute;p&ocirc;t s&eacute;lectionn&eacute;, soit lorsqu&#039;il a &eacute;t&eacute; transmis &agrave; votre machine.';
 $lang['cantdownload'] = 'Impossible de t&eacute;l&eacute;charger';
 $lang['download'] = 'T&eacute;l&eacute;charger et installer';
 $lang['error_moduleinstallfailed'] = 'L&#039;installation du module a &eacute;chou&eacute;';
 $lang['error_connectnomodules'] = 'Bien qu&#039;une connexion au d&eacute;p&ocirc;t de module aie &eacute;t&eacute; &eacute;tablie avec succ&egrave;s, il appara&icirc;t que ce d&eacute;p&ocirc;t ne partage aucun module pour l&#039;instant.';
 $lang['submit'] = 'Soumettre';
-$lang['text_repository_url'] = 'L&#039;URL doit &ecirc;tre dans un format tel que http://www.mycmsms.com/ModuleRepository/request/v2 (en supposant que les URLs rewriting soient activ&eacute;es sur le serveur de r&eacute;f&eacute;rentiel)';
+$lang['text_repository_url'] = 'L&#039;URL doit &ecirc;tre dans un format tel que http://www.mycmsms.com/ModuleRepository/request/v2 (en supposant que les URLs rewriting soient activ&eacute;es sur le serveur de r&eacute;f&eacute;rentiel)<br />Note : l&#039;ouverture de ce lien dans votre navigateur renvoie une Erreur 404 !';
 $lang['prompt_repository_url'] = 'URL du d&eacute;p&ocirc;t de modules&nbsp;';
 $lang['title_installation'] = 'Installation ';
 $lang['availmodules'] = 'Modules disponibles';
@@ -155,11 +155,15 @@ Ajout de v&eacute;rification des d&eacute;pendances.
 </li>
 </ul>';
 $lang['help'] = '<h3>Que fait ce module&nbsp;?</h3>
-<p>Un client pour le d&eacute;p&ocirc;t de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le FTP, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant SOAP, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.</p>
+<p>Un client pour le d&eacute;p&ocirc;t de modules (ModuleRepository), ce module permet la pr&eacute;visualisation, et l&#039;installation de modules depuis des sites distants sans avoir besoin d&#039;utiliser le FTP, ou de d&eacute;zipper des archives. Les fichier XML de modules sont t&eacute;l&eacute;charg&eacute;s en utilisant REST, l&#039;int&eacute;grit&eacute; est v&eacute;rifi&eacute;e et automatiquement ajust&eacute;e.<br/> Lors de l&#039;installation d&#039;un module avec des d&eacute;pendances, cette option fera en sorte que la derni&egrave;re version de la d&eacute;pendance sera install&eacute;e</p>
 <h3>Comment l&#039;utiliser&nbsp;?</h3>
 <p>pour utiliser ce module, vous devez d&eacute;finir la permission &#039;Modify Modules&#039;, vous avez aussi besoin de l&#039;URL complet &agrave; un d&eacute;p&ocirc;t de modules (Module Repository).  Vous pouvez sp&eacute;cifier cet URL dans le menu &quot;Extensions / Gestionnaire de Modules / Pr&eacute;f&eacute;rences&quot;.</p><br/>
 <p>Vous trouverez l&#039;interface de ce module sous le menu &#039;Extensions&#039;.  Quand vous s&eacute;lectionnez ce module, une requ&ecirc;te va automatiquement &ecirc;tre au d&eacute;p&ocirc;t de modules, pour trouver les modules XML disponibles. Cette liste sera compar&eacute;e &agrave; la liste des modules d&eacute;j&agrave; install&eacute;s, et une page de sommaire sera affich&eacute;e.  Puis, vous pourrez voir une information descriptive, l&#039;aide et l&#039;information &#039;&Agrave; propos&#039; des modules, sans les installer. Vous pourrez alors choisir de mettre &agrave; niveau, ou installer des modules.</p>
 <h3>Support</h3>
 <p>Copyright &copy; 2006,  <a href="mailto:calguy1000@hotmail.com">Robert Campbell calguy1000</a>. Tous droits r&eacute;serv&eacute;s.</p>
 <p>Ce module est distribu&eacute; sous la licence <a href="http://www.gnu.org/licenses/licenses.html#GPL" target="_blank">GNU Public License</a>. Vous devez agr&eacute;er aux termes de cette licence pour pouvoir utiliser ce module.</p>';
+$lang['utma'] = '156861353.1534329511.1341818282.1341818282.1341818282.1';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1341818282.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
