@@ -43,12 +43,12 @@ class News extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.12.7';
+	  return '2.14.2';
 	}
 
 	function MinimumCMSVersion()
 	{
-		return '1.11-alpha0';
+	  return '1.11.9';
 	}
 
 	function GetAdminDescription()
@@ -88,7 +88,8 @@ class News extends CMSModule
 	  $this->SetParameterType('assign',CLEAN_STRING);
 	  $this->SetParameterType('inline',CLEAN_STRING);
 	  $this->SetParameterType('preview',CLEAN_STRING);
-		
+	  $this->SetParameterType('idlist',CLEAN_STRING);
+
 	  // form parameters
 	  $this->SetParameterType('submit',CLEAN_STRING);
 	  $this->SetParameterType('cancel',CLEAN_STRING);
@@ -121,7 +122,7 @@ class News extends CMSModule
 	  $this->SetParameterType('useexp',CLEAN_INT);
 	  $this->SetParameterType('input_category',CLEAN_STRING);
 	  $this->SetParameterType('category_id',CLEAN_INT);
-		
+
 	  $this->SetParameterType(CLEAN_REGEXP.'/news_customfield_.*/',CLEAN_STRING);
 	  $this->SetParameterType('junk',CLEAN_STRING);
 	}
@@ -146,6 +147,7 @@ class News extends CMSModule
 	  $this->CreateParameter('start', 0, $this->lang('helpstart'));
 	  $this->CreateParameter('action','default',$this->Lang('helpaction'));
 	  $this->CreateParameter('articleid','',$this->Lang('help_articleid'));
+	  $this->CreateParameter('idlist','',$this->Lang('help_idlist'));
 	}
 
 	function AllowSmartyCaching()
@@ -170,7 +172,7 @@ class News extends CMSModule
 	    $this->CheckPermission('Modify Templates') || 
 	    $this->CheckPermission('Approve News');
 	}
-	
+
     function GetDfltEmailTemplate()
     {
       $text = "A new news article has been posted to your website.  The details are as follows:\n";
@@ -207,7 +209,7 @@ class News extends CMSModule
     {
       return file_get_contents(dirname(__FILE__).'/changelog.inc');
     }
-	
+
     function GetEventDescription( $eventname )
     {
       return $this->lang('eventdesc-' . $eventname);
@@ -217,150 +219,87 @@ class News extends CMSModule
     {
       return $this->lang('eventhelp-' . $eventname);
     }
-	
-    function SearchResult($returnid, $articleid, $attr = '')
-    {
-      $result = array();
-		
-      if ($attr == 'article')
-	{
-	  $db = $this->GetDb();
-	  $now = $db->DbTimeStamp(time());
-	  $zerotime = $db->DbTimeStamp(1);
-	  $q = "SELECT news_title,news_url FROM ".cms_db_prefix()."module_news WHERE
-		       news_id = ?";
-	  if( $this->GetPreference('expired_searchable',1) == 0 )
-	    {
-	      // make sure we don't return expired articles.
-	      // if we don't want em to.
-	      $q .= " AND ((".$db->IfNull('end_time',$zerotime)." = ".$zerotime.") OR (end_time > $now))";
-	    }
-	  $dbresult = $db->Execute( $q, array( $articleid ) );
-	  if ($dbresult)
-	    {
-	      $row = $dbresult->FetchRow();
-
-	      //0 position is the prefix displayed in the list results.
-	      $result[0] = $this->GetFriendlyName();
-		
-	      //1 position is the title
-	      $result[1] = $row['news_title'];
-
-	      //2 position is the URL to the title.
-	      $pretty_url = $row['news_url'];
-	      if( $pretty_url == '' )
-		{
-		  $aliased_title = munge_string_to_url($row['news_title']);
-		  $prettyurl = 'news/' . $articleid.'/'.$returnid."/$aliased_title";
-		}
-	      $result[2] = $this->CreateLink('cntnt01', 'detail', $returnid, '', array('articleid' => $articleid) ,'', true, false, '', true, $prettyurl);
-	    }
-	}
-	
-      return $result;
-    }
-
 
     function SearchResultWithParams($returnid, $articleid, $attr = '', $params = '')
     {
       $gCms = cmsms();
       $result = array();
-      
-      if ($attr == 'article')
-	{
-	  $db = $this->GetDb();
-	  $q = "SELECT news_title,news_url FROM ".cms_db_prefix()."module_news WHERE news_id = ?";
-	  $row = $db->GetRow( $q, array( $articleid ) );
-	  
-	  if ($row)
-	    {
-	      //0 position is the prefix displayed in the list results.
-	      $result[0] = $this->GetFriendlyName();
-	      
-	      //1 position is the title
-	      $result[1] = $row['news_title'];
-	      
-	      //2 position is the URL to the title.
-	      $detailpage = $returnid;
-	      if( isset($params['detailpage']) )
-		{
-		  $manager = $gCms->GetHierarchyManager();
-		  $node = $manager->sureGetNodeByAlias($params['detailpage']);
-		  if (isset($node))
-		    {
-		      $detailpage = $node->getID();
-		    }
-		  else
-		    {
-		      $node = $manager->sureGetNodeById($params['detailpage']);
-		      if (isset($node))
-			{
-			  $detailpage = $params['detailpage'];
-			}
-		    }
-		}
-	      if( $detailpage == '' ) $detailpage = $returnid;
 
-	      $detailtemplate = '';
-	      if( isset($params['detailtemplate']) )
-		{
-		  $manager = $gCms->GetHierarchyManager();
-		  $node = $manager->sureGetNodeByAlias($params['detailtemplate']);
-		  if (isset($node))
-		    {
-		      $detailtemplate = '/d,' . $params['detailtemplate'];
-		    }
-		}
+      if ($attr == 'article') {
+	$db = $this->GetDb();
+	$q = "SELECT news_title,news_url FROM ".cms_db_prefix()."module_news WHERE news_id = ?";
+	$row = $db->GetRow( $q, array( $articleid ) );
 
-	      if( $row['news_url'] != '' )
-		{
-		  $aliased_title = munge_string_to_url($row['news_title']);
-		  $prettyurl = 'news/' . $articleid.'/'.$detailpage."/$aliased_title".$detailtemplate;
-		}
-	      else
-		{
-		  $prettyurl = $row['news_url'];
-		}
+	if ($row) {
+	  //0 position is the prefix displayed in the list results.
+	  $result[0] = $this->GetFriendlyName();
 
-	      $parms = array();
-	      $parms['articleid'] = $articleid;
-	      if( isset($params['detailtemplate']) ) $parms['detailtemplate'] = $params['detailtemplate'];
-	      $result[2] = $this->CreateLink('cntnt01', 'detail', $detailpage, '', $parms ,'', true, false, '', true, $prettyurl);
+	  //1 position is the title
+	  $result[1] = $row['news_title'];
+
+	  //2 position is the URL to the title.
+	  $detailpage = $returnid;
+	  if( isset($params['detailpage']) ) {
+	    $manager = $gCms->GetHierarchyManager();
+	    $node = $manager->sureGetNodeByAlias($params['detailpage']);
+	    if (isset($node)) {
+	      $detailpage = $node->getID();
 	    }
+	    else {
+	      $node = $manager->sureGetNodeById($params['detailpage']);
+	      if (isset($node))  $detailpage = $params['detailpage'];
+	    }
+	  }
+	  if( $detailpage == '' ) $detailpage = $returnid;
+
+	  $detailtemplate = '';
+	  if( isset($params['detailtemplate']) ) {
+	    $manager = $gCms->GetHierarchyManager();
+	    $node = $manager->sureGetNodeByAlias($params['detailtemplate']);
+	    if (isset($node)) $detailtemplate = '/d,' . $params['detailtemplate'];
+	  }
+
+	  if( $row['news_url'] != '' ) {
+	    $aliased_title = munge_string_to_url($row['news_title']);
+	    $prettyurl = 'news/' . $articleid.'/'.$detailpage."/$aliased_title".$detailtemplate;
+	  }
+	  else {
+	    $prettyurl = $row['news_url'];
+	  }
+
+	  $parms = array();
+	  $parms['articleid'] = $articleid;
+	  if( isset($params['detailtemplate']) ) $parms['detailtemplate'] = $params['detailtemplate'];
+	  $result[2] = $this->CreateLink('cntnt01', 'detail', $detailpage, '', $parms ,'', true, false, '', true, $prettyurl);
 	}
-      
+      }
+
       return $result;
     }
-	
 
     function SearchReindex(&$module)
     {
       $db = $this->GetDb();
-		
+
       $query = 'SELECT * FROM '.cms_db_prefix().'module_news ORDER BY news_date';
       $result = $db->Execute($query);
 
-      while ($result && !$result->EOF)
-	{
-	  if ($result->fields['status'] == 'published')
-	    {
-	      $module->AddWords($this->GetName(), 
-				$result->fields['news_id'], 'article', 
-				$result->fields['news_data'] . ' ' . $result->fields['summary'] . ' ' . $result->fields['news_title'] . ' ' . $result->fields['news_title'],
-				($result->fields['end_time'] != NULL && $this->GetPreference('expired_searchable',0) == 0) ?  $db->UnixTimeStamp($result->fields['end_time']) : NULL);
-	    }
-	  $result->MoveNext();
+      while ($result && !$result->EOF) {
+	if ($result->fields['status'] == 'published') {
+	  $module->AddWords($this->GetName(), 
+			    $result->fields['news_id'], 'article', 
+			    $result->fields['news_data'] . ' ' . $result->fields['summary'] . ' ' . $result->fields['news_title'] . ' ' . $result->fields['news_title'],
+			    ($result->fields['end_time'] != NULL && $this->GetPreference('expired_searchable',0) == 0) ?  $db->UnixTimeStamp($result->fields['end_time']) : NULL);
 	}
+	$result->MoveNext();
+      }
     }
 
 
   function myRedirectToTab( $id, $tab, $params = '' )
   {
     $parms = array();
-    if( is_array( $params ) )
-      {
-	$parms = $params;
-      }
+    if( is_array( $params ) ) $parms = $params;
     $parms = array('active_tab' => $tab );
     $this->myRedirect( $id, 'defaultadmin', $parms );
   }
@@ -373,15 +312,22 @@ class News extends CMSModule
   }
 
 
+  public function GetFieldTypes()
+  {
+    $items = array('textbox'=>$this->Lang('textbox'),
+		   'checkbox'=>$this->Lang('checkbox'),
+		   'textarea'=>$this->Lang('textarea'),
+		   'dropdown'=>$this->Lang('dropdown'),
+		   'file'=>$this->Lang('file'));
+    return $items;
+  }
+
   function GetTypesDropdown( $id, $name, $selected = '' )
   {
-    $items = array($this->Lang('textbox') => 'textbox', 
-		   $this->Lang('checkbox') => 'checkbox',
-		   $this->Lang('textarea') => 'textarea',
-		   $this->Lang('file') => 'file');
-    return $this->CreateInputDropdown($id, $name, $items, -1, $selected);
+    $items = $this->GetFieldTypes();
+    return $this->CreateInputDropdown($id, $name, array_flip($items), -1, $selected);
   }
-  
+
 
   function GetNotificationOutput($priority = 2)
   {
@@ -389,44 +335,47 @@ class News extends CMSModule
     // Draft to published, and there are draft news articles
     // then display a nice message.
     // this is a priority 2 item.
-    if( $priority >= 2 )
-      {
-	$output = array();
-	if( $this->CheckPermission('Approve News') )
-	  {
-	    $db = $this->GetDb();
-	    $query = 'SELECT count(news_id) FROM '.cms_db_prefix().'module_news n
-                   WHERE status != \'published\'
-                     AND (('.$db->IfNull('end_time',$db->DbTimeStamp(1)).' = '.$db->DbTimeStamp(1).') OR (end_time > '.$db->DbTimeStamp(time()).')) ';
-	    $count = $db->GetOne($query);
-	    if( $count )
-	      {
-		$obj = new StdClass;
-		$obj->priority = 2;
-		$link = $this->CreateLink('m1_','defaultadmin','',
-					  $this->Lang('notify_n_draft_items_sub',$count));
-		$obj->html = $this->Lang('notify_n_draft_items',$link);
-		$output[] = $obj;
-	      }
-	  }
+    if( $priority >= 2 ) {
+      $output = array();
+      if( $this->CheckPermission('Approve News') ) {
+	$db = $this->GetDb();
+	$query = 'SELECT count(news_id) FROM '.cms_db_prefix().'module_news n
+                  WHERE status != \'published\'
+                  AND (('.$db->IfNull('end_time',$db->DbTimeStamp(1)).' = '.$db->DbTimeStamp(1).') OR (end_time > '.$db->DbTimeStamp(time()).')) ';
+	$count = $db->GetOne($query);
+	if( $count ) {
+	  $obj = new StdClass;
+	  $obj->priority = 2;
+	  $link = $this->CreateLink('m1_','defaultadmin','',
+				    $this->Lang('notify_n_draft_items_sub',$count));
+	  $obj->html = $this->Lang('notify_n_draft_items',$link);
+	  $output[] = $obj;
+	}
       }
+    }
     return $output;
   }
 
-  
+
   public function CreateStaticRoutes()
   {
     $db = cmsms()->GetDb();
+    cms_route_manager::del_static('',$this->GetName());
 
-    $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)\/d,(?P<detailtemplate>.*?)$/',
-			  $this->GetName());
-    cms_route_manager::add_static($route);
-    $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',$this->GetName());
-    cms_route_manager::add_static($route);
-    $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)$/',$this->GetName());
-    cms_route_manager::add_static($route);
-    $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)$/',$this->GetName());
-    cms_route_manager::add_static($route);
+    try {
+      $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)\/d,(?P<detailtemplate>.*?)$/',
+			    $this->GetName());
+      cms_route_manager::add_static($route);
+      $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)\/(?P<junk>.*?)$/',$this->GetName());
+      cms_route_manager::add_static($route);
+      $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)\/(?P<returnid>[0-9]+)$/',$this->GetName());
+      cms_route_manager::add_static($route);
+      $route = new CmsRoute('/[nN]ews\/(?P<articleid>[0-9]+)$/',$this->GetName(),array('returnid'=>$this->GetPreference('detail_returnid',-1)));
+      cms_route_manager::add_static($route);
+    }
+    catch( Exception $e ) {
+      audit('',$this->GetName(),'Error updating routes');
+    }
 
     $query = 'SELECT news_id,news_url FROM '.cms_db_prefix().'module_news
               WHERE status = ? AND news_url != ? AND '
@@ -435,15 +384,18 @@ class News extends CMSModule
     $query .= ' ORDER BY news_date DESC';
     $tmp = $db->GetArray($query,array('published',''));
 
-    if( is_array($tmp) )
-      {
-	foreach( $tmp as $one )
-	  {
-	    news_admin_ops::register_static_route($one['news_url'],$one['news_id']);
-	  }
+    if( is_array($tmp) ) {
+      foreach( $tmp as $one ) {
+	try {
+	  news_admin_ops::register_static_route($one['news_url'],$one['news_id']);
+	}
+	catch( Exception $e ) {
+	  audit('',$this->GetName(),'Error updating routes');
+	}
       }
+    }
   }
 }
 
 # vim:ts=4 sw=4 noet
-?>
+?>
\ No newline at end of file
