@@ -408,28 +408,25 @@ else
     $query = 'SELECT * FROM '.cms_db_prefix().'module_news WHERE news_id = ?';
     $row = $db->GetRow($query, array($articleid));
     
-    if ($row)
-      {
-	$title = $row['news_title'];
-	$content = $row['news_data'];
-	$extra = $row['news_extra'];
-	$summary = $row['summary'];
-	$news_url = $row['news_url'];
-	$status = $row['status'];
-	$usedcategory = $row['news_category_id'];
-	$postdate = $db->UnixTimeStamp($row['news_date']);
-	$startdate = $db->UnixTimeStamp($row['start_time']);
-	$author_id = $row['author_id'];
-	if (isset($row['end_time']))
-	  {
-	    $useexp = 1;
-	    $enddate = $db->UnixTimeStamp($row['end_time']);
-	  }
-	else
-	  {
-	    $useexp = 0;
-	  }
+    if ($row) {
+      $title = $row['news_title'];
+      $content = $row['news_data'];
+      $extra = $row['news_extra'];
+      $summary = $row['summary'];
+      $news_url = $row['news_url'];
+      $status = $row['status'];
+      $usedcategory = $row['news_category_id'];
+      $postdate = $db->UnixTimeStamp($row['news_date']);
+      $startdate = $db->UnixTimeStamp($row['start_time']);
+      $author_id = $row['author_id'];
+      if (isset($row['end_time'])) {
+	$useexp = 1;
+	$enddate = $db->UnixTimeStamp($row['end_time']);
       }
+      else {
+	$useexp = 0;
+      }
+    }
   }
 
 $statusdropdown = array();
@@ -540,48 +537,52 @@ if( is_array($tmp) )
 $query = 'SELECT * FROM '.cms_db_prefix().'module_news_fielddefs ORDER BY item_order';
 $dbr = $db->Execute($query);
 $custom_flds = array();
-while( $dbr && ($row = $dbr->FetchRow()) )
-  {
-    $value = '';
-    if( isset($fieldvals[$row['id']]) )
-      {
-	$value = $fieldvals[$row['id']]['value'];
-      }
-	$value = isset($params['customfield'][$row['id']])&&in_array($params['customfield'][$row['id']],$params['customfield']) ? $params['customfield'][$row['id']]:$value;
-    $obj = new StdClass();
-    $name = "customfield[".$row['id']."]";
-    $obj->prompt = $row['name'];
-    switch( $row['type'] )
-      {
-      case 'textbox':
-	$size = min(50,$row['max_length']);
-	$obj->field = $this->CreateInputText($id,$name,$value,$size,$row['max_length']);
-	break;
-      case 'checkbox':
-	$obj->field = $this->CreateInputHidden($id,$name,0).$this->CreateInputCheckbox($id,$name,1,(int)$value);
-	break;
-      case 'textarea':
-	$obj->field = $this->CreateTextArea(true,$id,$value,$name);
-	break;
-      case 'file':
-	$name = "customfield_".$row['id'];
-	$del = '';
-	if( $value != '' )
-	  {
-	    $deln = 'delete_customfield['.$row['id'].']';
-	    $del = '&nbsp;'.$this->Lang('delete').$this->CreateInputCheckbox($id,$deln,'delete');
-	  }
-	$obj->field = 
-	  $value.'&nbsp;'.$this->CreateFileUploadInput($id,$name).$del;;
-	break;
-      }
+while( $dbr && ($row = $dbr->FetchRow()) ) {
+  if( isset($row['extra']) ) {
+    $row['extra'] = unserialize($row['extra']);
+  }
+
+  $value = '';
+  if( isset($fieldvals[$row['id']]) ) $value = $fieldvals[$row['id']]['value'];
+
+  $value = isset($params['customfield'][$row['id']])&&in_array($params['customfield'][$row['id']],$params['customfield']) ? $params['customfield'][$row['id']]:$value;
+  $obj = new StdClass();
+  $name = "customfield[".$row['id']."]";
+  $obj->prompt = $row['name'];
+  switch( $row['type'] ) {
+  case 'textbox':
+    $size = min(50,$row['max_length']);
+    $obj->field = $this->CreateInputText($id,$name,$value,$size,$row['max_length']);
+    break;
+
+  case 'checkbox':
+    $obj->field = $this->CreateInputHidden($id,$name,0).$this->CreateInputCheckbox($id,$name,1,(int)$value);
+    break;
+
+  case 'textarea':
+    $obj->field = $this->CreateTextArea(true,$id,$value,$name);
+    break;
+
+  case 'file':
+    $name = "customfield_".$row['id'];
+    $del = '';
+    if( $value != '' ) {
+      $deln = 'delete_customfield['.$row['id'].']';
+      $del = '&nbsp;'.$this->Lang('delete').$this->CreateInputCheckbox($id,$deln,'delete');
+    }
+    $obj->field = $value.'&nbsp;'.$this->CreateFileUploadInput($id,$name).$del;;
+    break;
+
+  case 'dropdown':
+    $obj->field = $this->CreateInputDropdown($id,$name,array_flip($row['extra']['options']),-1,$value);
+    break;
+  } // switch
     
-    $custom_flds[] = $obj;
-  }
-if( count($custom_flds) > 0 )
-  {
-    $smarty->assign('custom_fields',$custom_flds);
-  }
+  $custom_flds[] = $obj;
+}
+if( count($custom_flds) > 0 ) {
+  $smarty->assign('custom_fields',$custom_flds);
+}
 
 // tab stuff.
 $smarty->assign('start_tab_headers',$this->StartTabHeaders());
