@@ -1,4 +1,10 @@
 <?php
+$lang['help_idlist'] = 'Applicable only to the default action (summary view).  This parameter accepts a comma separated list of numeric article ids and allows further filtering articles to only the article ids specified.  The actual list of articles output is still subject to article status, expiry date, and other parameters.';
+$lang['error_nooptions'] = 'No options specified for field definition';
+$lang['dropdown'] = 'Dropdown';
+$lang['info_public'] = 'Only Public fields are available for frontend editing, or for display in summary or detail views.';
+$lang['info_expired_viewable'] = 'If enabled, expired articles can be viewed in detail mode (this is reproducing older functionality).  the showall parameter can be used on the URL (when not using pretty urls) to also indicate that expired articles can be viewed';
+$lang['expired_viewable'] = 'Expired articles can be viewed in the detail view';
 $lang['error_insufficientparams'] = 'Insufficient (or empty) parameters';
 $lang['error_duplicatename'] = 'An item with that name already exists';
 $lang['detail_page'] = 'Detail Page';
@@ -215,6 +221,7 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
 <li>"end_time" - Date the article should stop being displayed</li>
 <li>"useexp" - Whether the expiration date should be ignored or not</li>
 </ul>
+<p><strong>Note:</strong> Not all parameters may be present when this event is sent.</p>
 ';
 $lang['eventdesc-NewsArticleDeleted'] = 'Sent when an article is deleted.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
@@ -268,7 +275,7 @@ $lang['helpaction'] = <<<EOT
 <ul>
 <li>&quot;detail&quot; - to display a specified articleid in detail mode.</li>
 <li>&quot;default&quot; - to display the summary view</li>
-<li>&quot;fesubmit&quot; - to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
+<li>&quot;fesubmit&quot; - <strong>Deprecated</strong> to display the frontend form for allowing users to submit news articles on the front end. Add the <code>{cms_init_editor}</code> tag in the metadata section to initialize the selected wysiwyg editor. (Site Admin >> Global Settings)</li>
 <li>&quot;browsecat&quot; - to display a browseable category list.</li>
 </ul>
 EOT;
