@@ -1,5 +1,21 @@
 <?php
-$lang['expired_searchable'] = 'Vypr&scaron;el&eacute; čl&aacute;nky se mohou zobrazovat ve v&yacute;sledc&iacute;ch vyhled&aacute;v&aacute;n&iacute;';
+$lang['error_insufficientparams'] = 'Nedostatečn&eacute; (nebo pr&aacute;zdn&eacute;) parametry';
+$lang['error_duplicatename'] = 'Položka s t&iacute;mto n&aacute;zvem již existuje';
+$lang['detail_page'] = 'Str&aacute;nka detailu';
+$lang['detail_template'] = '&Scaron;ablona detailu';
+$lang['warning_preview'] = 'Varov&aacute;n&iacute;: Tento n&aacute;hledov&yacute; panel se chov&aacute; v&iacute;ce jako okno prohl&iacute;žeče a umožňuje navigaci z původně prohl&iacute;žen&eacute; str&aacute;nky. Pokud tak uděl&aacute;te, může nastat nepředv&iacute;dan&eacute; chov&aacute;n&iacute;. 
+<br/><strong>Pozn&aacute;mka:</strong> Tento n&aacute;hled nenahraje vybran&eacute; soubory.';
+$lang['article'] = 'Čl&aacute;nek';
+$lang['preview'] = 'N&aacute;hled';
+$lang['info_detail_returnid'] = 'T&iacute;mto nastaven&iacute;m zbol&iacute;te, jakou str&aacute;nku (a tedy i &scaron;ablonu) použ&iacute;t pro zobrazov&aacute;n&iacute; detailu. Pokud nebude tento parametr nastaven na platnou str&aacute;nku, nebude fungovat vlastn&iacute; URL adresa zadan&aacute; ve vlastnostech čl&aacute;nku. D&aacute;le tak&eacute; určuje v&yacute;choz&iacute; hodnotu parametru detailpage, pokud nebude v tagu {news} definov&aacute;n.';
+$lang['title_detail_returnid'] = 'V&yacute;choz&iacute; str&aacute;nka pro zobrazen&iacute; detailu';
+$lang['title_submission_settings'] = 'Vkl&aacute;d&aacute;n&iacute; novinek';
+$lang['title_fesubmit_settings'] = 'Novinky od koncov&yacute;ch uživatelů (FEU)';
+$lang['title_notification_settings'] = 'Upozorněn&iacute;';
+$lang['title_detail_settings'] = 'Zobrazen&iacute; detailu';
+$lang['error_invalidurl'] = 'Neplatn&eacute; URL <em>(možn&aacute; je již použito, nebo obsahuje nepovolen&eacute; znaky)</em>';
+$lang['url'] = 'URL';
+$lang['expired_searchable'] = 'Expirovan&eacute; čl&aacute;nky se mohou zobrazovat ve v&yacute;sledc&iacute;ch vyhled&aacute;v&aacute;n&iacute;';
 $lang['helpshowall'] = 'Zobrazit v&scaron;echny čl&aacute;nky nehledě na jejich konečn&eacute; datum';
 $lang['error_invaliddates'] = 'Jeden nebo v&iacute;ce zadan&yacute;ch datumů je neplatn&yacute;ch';
 $lang['notify_n_draft_items_sub'] = '%d čl&aacute;nků';
@@ -20,6 +36,8 @@ $lang['expiry_date_desc'] = 'Podle data expirace sestupně';
 $lang['expiry_date_asc'] = 'Podle data expirace vzestupně';
 $lang['title_desc'] = 'Podle titulku sestupně (Z-A)';
 $lang['title_asc'] = 'Podle titulku vzestupně (A-Z)';
+$lang['status_desc'] = 'Podle stavu sestupně';
+$lang['status_asc'] = 'Podle stavu vzestupně';
 $lang['fesubmit_status'] = 'Stav novinek vložen&yacute;ch přes frontend (vlastn&iacute; str&aacute;nky)';
 $lang['error_invalidfiletype'] = 'Tento typ souboru nen&iacute; možno nahr&aacute;t';
 $lang['error_upload'] = 'Nastal probl&eacute;m při nahr&aacute;v&aacute;n&iacute; souboru';
@@ -62,7 +80,7 @@ $lang['deprecated'] = 'nepodporov&aacute;no';
 $lang['subject_newnews'] = 'Nov&yacute; čl&aacute;nek byl publikov&aacute;n';
 $lang['email_subject'] = 'Předmět ochoz&iacute;ho e-mailu';
 $lang['email_template'] = 'Form&aacute;t e-mailov&eacute; zpr&aacute;vy';
-$lang['formsubmit_emailaddress'] = 'E-mailov&aacute; adresa pro přijet&iacute; upozorněn&iacute; na vložen&iacute; čl&aacute;nku';
+$lang['formsubmit_emailaddress'] = 'E-mailov&aacute; adresa, na kterou bude odesl&aacute;no upozorněn&iacute; na vložen&iacute; čl&aacute;nku';
 $lang['extra'] = 'Extra';
 $lang['uploadscategory'] = 'Kategorie uploadu';
 $lang['title_available_templates'] = 'Dostupn&eacute; &scaron;ablony';
@@ -75,13 +93,13 @@ $lang['prompt_template'] = 'Zdroj &scaron;ablony';
 $lang['title_form_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona formul&aacute;ře';
 $lang['title_summary_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona souhrnu';
 $lang['title_detail_sysdefault'] = 'V&yacute;choz&iacute; &scaron;ablona detailu';
-$lang['info_sysdefault2'] = '<strong>Pozn&aacute;mka:</strong> Tento panel obsahuje textov&aacute; pole, kter&eacute; v&aacute;m umožňuj&iacute; upravit sadu &scaron;ablon, jež jsou zobrateny, když vytvoř&iacute;te &quot;novou&quot; &scaron;ablonu shrnut&iacute;, detailu nebo formul&aacute;ře.';
-$lang['info_sysdefault'] = '<em>(v&yacute;choz&iacute; &scaron;ablona při v&yacute;běru nov&eacute; &scaron;ablony)</em>';
+$lang['info_sysdefault2'] = '<strong>Pozn&aacute;mka:</strong> Tento panel obsahuje textov&aacute; pole, kter&eacute; v&aacute;m umožňuj&iacute; upravit sadu &scaron;ablon, jež jsou zobrazeny, když vytvoř&iacute;te &quot;novou&quot; &scaron;ablonu shrnut&iacute;, detailu nebo formul&aacute;ře. Změna obsahu na t&eacute;to str&aacute;nce a potvrzen&iacute; tlač&iacute;tkem &quot;Odeslat&quot; <strong>nezměn&iacute; ž&aacute;dn&eacute; současn&eacute; &scaron;ablony</strong>';
+$lang['info_sysdefault'] = '(toto je v&yacute;choz&iacute; obsah nově vytořen&yacute;ch &scaron;ablon)';
 $lang['template'] = '&Scaron;ablona';
 $lang['prompt_name'] = 'Jm&eacute;no';
 $lang['prompt_default'] = 'V&yacute;choz&iacute;';
 $lang['prompt_newtemplate'] = 'Vytvořit novou &scaron;ablonu';
-$lang['help_pagelimit'] = 'Maxim&aacute;ln&iacute; počet položek k zobrazen&iacute; (na str&aacute;nku).  Pokud tento parametr nen&iacute; zad&aacute;n, budou zobrazeny v&scaron;echy vyhovuj&iacute;c&iacute; položky.  Pokud je zad&aacute;n a položek je v&iacute;ce než uvedeno v tomto parametru, bude vložen text a odkazy pro proch&aacute;zen&iacute; v&yacute;sledky';
+$lang['help_pagelimit'] = 'Maxim&aacute;ln&iacute; počet položek k zobrazen&iacute; (na str&aacute;nku).  Pokud tento parametr nen&iacute; zad&aacute;n, budou zobrazeny v&scaron;echy vyhovuj&iacute;c&iacute; položky.  Pokud je zad&aacute;n a položek je v&iacute;ce než uvedeno v tomto parametru, bude vložen text a odkazy pro proch&aacute;zen&iacute; v&yacute;sledků';
 $lang['prompt_page'] = 'Str&aacute;nka';
 $lang['firstpage'] = '<<';
 $lang['prevpage'] = '<';
@@ -115,7 +133,7 @@ $lang['category'] = 'Kategorie';
 $lang['categories'] = 'Kategorie';
 $lang['default_category'] = 'V&yacute;choz&iacute; kategorie';
 $lang['content'] = 'Obsah';
-$lang['dateformat'] = '%s nen&iacute; ve spr&aacute;vn&eacute;m yyyy-mm-dd hh:mm:ss form&aacute;tu';
+$lang['dateformat'] = '%s nen&iacute; ve spr&aacute;vn&eacute;m form&aacute;tu yyyy-mm-dd hh:mm:ss ';
 $lang['delete'] = 'Smazat';
 $lang['description'] = 'Vložit, upravit nebo smazat novinky';
 $lang['formtemplate'] = '&Scaron;ablony formul&aacute;ře';
@@ -133,24 +151,25 @@ $lang['filter'] = 'Filtr';
 $lang['more'] = 'V&iacute;ce';
 $lang['category_label'] = 'Kategorie:';
 $lang['author_label'] = 'Zaslal:';
+$lang['extra_label'] = 'Extra:';
 $lang['moretext'] = 'V&iacute;ce textu';
 $lang['name'] = 'Jm&eacute;no';
 $lang['news'] = 'Novinky';
 $lang['news_return'] = 'N&aacute;vrat';
 $lang['newcategory'] = 'Nov&aacute; kategorie';
-$lang['needpermission'] = 'Potřebujete \&#039;%s\&#039; opr&aacute;vněn&iacute; pro proveden&iacute; t&eacute;to funkce.';
+$lang['needpermission'] = 'pro proveden&iacute; t&eacute;to funkce potřebujete opr&aacute;vněn&iacute; &#039;%s&#039;.';
 $lang['nocategorygiven'] = 'Kategorie nezad&aacute;na';
 $lang['startdatetoolate'] = 'Datum poč&aacute;tku je př&iacute;li&scaron; pozdn&iacute; (po datu konce?)';
 $lang['nocontentgiven'] = 'Obsah nezad&aacute;n';
 $lang['noitemsfound'] = '<strong>Ž&aacute;dn&eacute;</strong> položky nenalezeny v kategorii: %s';
 $lang['nopostdategiven'] = 'Datum vložen&iacute; nezad&aacute;no';
-$lang['note'] = '<em>Pozn&aacute;mka:</em> Data mus&iacute; b&yacute;t v \&#039;yyyy-mm-dd hh:mm:ss\&#039; form&aacute;tu.';
+$lang['note'] = '<em>Pozn&aacute;mka:</em> Datum mus&iacute; b&yacute;t ve form&aacute;tu &#039;yyyy-mm-dd hh:mm:ss&#039;';
 $lang['notitlegiven'] = 'Nadpis nezad&aacute;n';
 $lang['nonamegiven'] = 'Nezad&aacute;no jm&eacute;no';
 $lang['numbertodisplay'] = 'Počet k zobrazen&iacute; (pr&aacute;zdn&eacute; zobraz&iacute; v&scaron;echny z&aacute;znamy)';
 $lang['print'] = 'Tisknout';
 $lang['postdate'] = 'Datum vložen&iacute;';
-$lang['postinstall'] = 'Nastavte \&quot;Modify News\&quot; opr&aacute;vněn&iacute; uživatelům, kteř&iacute; budou spravovat novinky.';
+$lang['postinstall'] = 'Nastavte opr&aacute;vněn&iacute; &quot;Modify News&quot; v&scaron;em uživatelům, kteř&iacute; budou spravovat novinky.';
 $lang['selectcategory'] = 'Vybrat kategorii';
 $lang['showchildcategories'] = 'Zobrazit podř&iacute;zen&eacute; kategorie';
 $lang['sortascending'] = 'Tř&iacute;dit vzestupně';
@@ -165,61 +184,65 @@ $lang['title'] = 'Nadpis';
 $lang['options'] = 'Volby';
 $lang['optionsupdated'] = 'Volby &uacute;spě&scaron;ně aktualizov&aacute;ny.';
 $lang['useexpiration'] = 'Použ&iacute;t datum konce';
-$lang['eventdesc-NewsArticleAdded'] = 'Odeslat po vložen&iacute; položky.';
-$lang['eventhelp-NewsArticleAdded'] = '<p>Odeslat po vložen&iacute; položky.</p>
+$lang['eventdesc-NewsArticleAdded'] = 'Odesl&aacute;no po vložen&iacute; položky.';
+$lang['eventhelp-NewsArticleAdded'] = '<p>Odesl&aacute;no po vložen&iacute; položky.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id položky</li>
-<li>\&quot;category_id\&quot; - Id kategorie t&eacute;to položky</li>
-<li>\&quot;title\&quot; - N&aacute;zev položky</li>
-<li>\&quot;content\&quot; - Obsah položky</li>
-<li>\&quot;summary\&quot; - Souhrn položky</li>
-<li>\&quot;status\&quot; - Stav položky (\&quot;draft\&quot; nebo \&quot;publish\&quot;)</li>
-<li>\&quot;start_time\&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
-<li>\&quot;end_time\&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
+<li>&quot;news_id&quot; - Id položky</li>
+<li>&quot;category_id&quot; - Id kategorie t&eacute;to položky</li>
+<li>&quot;title&quot; - N&aacute;zev položky</li>
+<li>&quot;content&quot; - Obsah položky</li>
+<li>&quot;summary&quot; - Souhrn položky</li>
+<li>&quot;status&quot; - Stav položky (&quot;draft&quot; nebo &quot;publish&quot;)</li>
+<li>&quot;start_time&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
+<li>&quot;end_time&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
+<li>&quot;useexp&quot; - Zda m&aacute; b&yacute;t datum vypr&scaron;en&iacute; platnosti ignorov&aacute;no nebo ne</li>
 </ul>
 ';
-$lang['eventdesc-NewsArticleEdited'] = 'Odeslat po editaci položky.';
-$lang['eventhelp-NewsArticleEdited'] = '<p>Odeslat po editaci položky.</p>
+$lang['eventdesc-NewsArticleEdited'] = 'Odesl&aacute;no po editaci položky.';
+$lang['eventhelp-NewsArticleEdited'] = '<p>Odesl&aacute;no po editaci položky.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id položky</li>
-<li>\&quot;category_id\&quot; - Id kategorie t&eacute;to položky</li>
-<li>\&quot;title\&quot; - N&aacute;zev položky</li>
-<li>\&quot;content\&quot; - Obsah položky</li>
-<li>\&quot;summary\&quot; - Souhrn položky</li>
-<li>\&quot;status\&quot; - Stav položky (\&quot;draft\&quot; nebo \&quot;publish\&quot;)</li>
-<li>\&quot;start_time\&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
-<li>\&quot;end_time\&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
+<li>&quot;news_id&quot; - Id položky</li>
+<li>&quot;category_id&quot; - Id kategorie t&eacute;to položky</li>
+<li>&quot;title&quot; - N&aacute;zev položky</li>
+<li>&quot;content\&quot; - Obsah položky</li>
+<li>&quot;summary&quot; - Souhrn položky</li>
+<li>&quot;status&quot; - Stav položky (&quot;draft&quot; nebo &quot;publish&quot;)</li>
+<li>&quot;start_time&quot; - Datum, od kdy ma b&yacute;t položka zobrazov&aacute;na</li>
+<li>&quot;end_time&quot; - Datum, od kdy se m&aacute; položka přestat zobrazovat</li>
+<li>&quot;useexp&quot; - Zda m&aacute; b&yacute;t datum vypr&scaron;en&iacute; platnosti ignorov&aacute;no nebo ne</li>
 </ul>';
-$lang['eventdesc-NewsArticleDeleted'] = 'Odeslat po smaz&aacute;n&iacute; položky.';
-$lang['eventhelp-NewsArticleDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; položky.</p>
+$lang['eventdesc-NewsArticleDeleted'] = 'Odesl&aacute;no po smaz&aacute;n&iacute; položky.';
+$lang['eventhelp-NewsArticleDeleted'] = '<p>Odesl&aacute;no po smaz&aacute;n&iacute; položky.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;news_id\&quot; - Id položky</li>
+<li>&quot;news_id&quot; - Id položky</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryAdded'] = 'Odeslat po vložen&iacute; kategorie.';
-$lang['eventhelp-NewsCategoryAdded'] = '<p>Odeslat po vložen&iacute; kategorie.</p>
+$lang['eventdesc-NewsCategoryAdded'] = 'Odesl&aacute;no po vložen&iacute; kategorie.';
+$lang['eventhelp-NewsCategoryAdded'] = '<p>Odesl&aacute;no po vložen&iacute; kategorie.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id kategorie</li>
-<li>\&quot;name\&quot; - Jm&eacute;no kategorie</li>
+<li>&quot;category_id&quot; - Id kategorie</li>
+<li>&quot;name&quot; - Jm&eacute;no kategorie</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryEdited'] = 'Odeslat po &uacute;pravě kategorie.';
-$lang['eventhelp-NewsCategoryEdited'] = '<p>Odeslat po &uacute;pravě kategorie.</p>
+$lang['eventdesc-NewsCategoryEdited'] = 'Odesl&aacute;no po &uacute;pravě kategorie.';
+$lang['eventhelp-NewsCategoryEdited'] = '<p>Odesl&aacute;no po &uacute;pravě kategorie.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id kategorie</li>
-<li>\&quot;name\&quot; - Jm&eacute;no kategorie</li>
+<li>&quot;category_id&quot; - Id kategorie</li>
+<li>&quot;name&quot; - Jm&eacute;no kategorie</li>
+<li>&quot;origname&quot; - Původn&iacute; jm&eacute;no kategorie</li>
 </ul>
 ';
-$lang['eventdesc-NewsCategoryDeleted'] = 'Odeslat po smaz&aacute;n&iacute; kategorie.';
-$lang['eventhelp-NewsCategoryDeleted'] = '<p>Odeslat po smaz&aacute;n&iacute; kategorie.</p>
+$lang['eventdesc-NewsCategoryDeleted'] = 'Odesl&aacute;no po smaz&aacute;n&iacute; kategorie.';
+$lang['eventhelp-NewsCategoryDeleted'] = '<p>Odesl&aacute;no po smaz&aacute;n&iacute; kategorie.</p>
 <h4>Parametry</h4>
 <ul>
-<li>\&quot;category_id\&quot; - Id kategorie</li>
+<li>&quot;category_id&quot; - Id kategorie</li>
+<li>&quot;name&quot; - Jm&eacute;no smazan&eacute; kategorie</li>
 </ul>
 ';
 $lang['help_articleid'] = 'Tento parametr je možn&eacute; použ&iacute;t pouze u detailn&iacute;ho pohledu. Povoluje zadat jak&eacute; novinky zobrazit v detailn&iacute;m m&oacute;du. Pokud je použita speci&aacute;ln&iacute; hodnota -1, syst&eacute;m zobraz&iacute; nejnověj&scaron;&iacute;, publikovan&eacute;, nevypr&scaron;el&eacute; čl&aacute;nky.';
@@ -234,14 +257,14 @@ $lang['helpdetailtemplate'] = 'Použ&iacute;vat oddělenou &scaron;ablonu pro de
 $lang['helpsortby'] = 'Pole pro tř&iacute;děn&iacute;. Možnosti jsou: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  v&yacute;choz&iacute; je &quot;news_date&quot;. Při zadan&iacute;m &quot;random&quot; je ignorov&aacute;n parametr sortasc.';
 $lang['helpsortasc'] = 'Tř&iacute;dit novinky vzestupně.';
 $lang['helpdetailpage'] = 'Str&aacute;nka pro zobrazn&iacute; detailu novinky. Toto může b&yacute;t buď alias nebo id str&aacute;nky. Umožňuje zobrazit detaily v jin&eacute; &scaron;abloně než souhrn.';
-$lang['helpshowarchive'] = 'Zobrazit pouze vypr&scaron;el&eacute; novinky.';
+$lang['helpshowarchive'] = 'Zobrazit pouze expirovan&eacute; novinky.';
 $lang['helpbrowsecat'] = 'Zobrazit prohl&iacute;žiteln&yacute; seznam kategori&iacute;.';
 $lang['helpaction'] = 'Přepsat v&yacute;choz&iacute; akci. Možn&eacute; hodnoty jsou:
 <ul>
-<li>&amp;quot;detail&amp;quot; - pro zobrazen&iacute; zadan&eacute;ho čl&aacute;nku v detailn&iacute;m m&oacute;du.</li>
-<li>&amp;quot;default&amp;quot; - pro zobrazen&iacute; pohledu souhrnu</li>
-<li>&amp;quot;fesubmit&amp;quot; - pro zobrazen&iacute; formul&aacute;ře na str&aacute;nk&aacute;ch povoluj&iacute;c&iacute; uživatelům vkl&aacute;dat novnky.</li>
-<li>&amp;quot;browsecat&amp;quot; - pro zobrazen&iacute; prohled&aacute;vateln&eacute;ho seznamu kategori&iacute;.</li>
+<li>&quot;detail&quot; - pro zobrazen&iacute; zadan&eacute;ho čl&aacute;nku v detailn&iacute;m m&oacute;du.</li>
+<li>&quot;default&quot; - pro zobrazen&iacute; pohledu souhrnu</li>
+<li>&quot;fesubmit&quot; - pro zobrazen&iacute; formul&aacute;ře na str&aacute;nk&aacute;ch povoluj&iacute;c&iacute; vkl&aacute;dat novinky koncov&yacute;m uživatelům. Pro zobrazen&iacute; vybran&eacute;ho WYSIWYG editoru (Administrace str&aacute;nek - Glob&aacute;ln&iacute; nastaven&iacute;) vložte do oblasti pro metadata <code>{cms_init_editor}</code>.</li>
+<li>&quot;browsecat&quot; - pro zobrazen&iacute; prohled&aacute;vateln&eacute;ho seznamu kategori&iacute;.</li>
 </ul>';
 $lang['help'] = '<h3>Důležit&eacute; pozn&aacute;mky</h3>
 <p>Verze Novinek 2.9 a vy&scaron;&scaron;&iacute; odstraňuje ze &scaron;ablony parametr formatpostdate a dateformat.  M&iacute;sto toho se pro form&aacute;tov&aacute;n&iacute; data použ&iacute;v&aacute; cms_date_format (jak je naznačeno ve v&yacute;choz&iacute;ch &scaron;ablon&aacute;ch) a v &scaron;ablon&aacute;ch se použ&iacute;v&aacute; entry->postdate m&iacute;sto entry->formatpostdate.</p>
@@ -273,8 +296,9 @@ $lang['help'] = '<h3>Důležit&eacute; pozn&aacute;mky</h3>
 <li>Stisknout odeslat</li>
 </ul>
 <p>N&aacute;sledov&aacute;n&iacute; těchto kroků vyře&scaron;&iacute; probl&eacute;m s nenalezen&iacute;m &scaron;ablon novinek a jin&eacute; podobn&eacute; chyby smarty při aktualizaci CMS obsahuj&iacute;c&iacute; Novinky ve verzi 2.3 nebo vy&scaron;&scaron;&iacute;.</p>';
-$lang['utma'] = '156861353.4545864025444168000.1227726513.1235876853.1235894120.23';
-$lang['utmz'] = '156861353.1235854022.19.6.utmccn=(referral)|utmcsr=miditower|utmcct=/cms/admin/listmodules.php|utmcmd=referral';
+$lang['utma'] = '156861353.947599811.1321089285.1321089285.1321103008.2';
+$lang['utmz'] = '156861353.1321089285.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-2065764558-1319293569112';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
