@@ -1,4 +1,6 @@
 <?php
+$lang['info_expired_viewable'] = 'Wenn aktiviert, k&ouml;nnen abgelaufene Artikel im Detail-Modus angezeigt werden (dies reproduziert alte Funktionalit&auml;t). Der showall Parameter kann f&uuml;r die URL (wenn sie pretty URL&#039;s nicht verwenden) verwendet werden, um zu zeigen dass auch abgelaufene Artikel angezeigt werden k&ouml;nnen.';
+$lang['expired_viewable'] = 'Abgelaufene Artikel k&ouml;nnen in der Detailansicht angezeigt werden';
 $lang['error_insufficientparams'] = 'Unzureichende (oder leere) Parameter';
 $lang['error_duplicatename'] = 'Ein Eintrag mit diesem Namen existiert bereits';
 $lang['detail_page'] = 'Detail-Ansichtsseite';
@@ -374,8 +376,9 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 </ul>
 <p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &bdquo;musterfeld&ldquo; &uuml;ber die Variable entry->musterfeld abfragen.</p>
 <p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&bdquo;_&ldquo;) ersetzt werden.</p>';
-$lang['utma'] = '156861353.843417466.1337413794.1337413794.1337413794.1';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utma'] = '156861353.284115588.1346760248.1346760248.1346760248.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1337413794.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1346760248.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
