@@ -1,4 +1,10 @@
 <?php
+$lang['help_idlist'] = 'Aplicable solo para la acci&oacute;n por defecto (vista sumaria). Este par&aacute;metro acepta una lista separada por comas de los valores num&eacute;ricos (ids) de art&iacute;culos y permite filtrar art&iacute;culos. La lista de art&iacute;culos desplegada est&aacute; sujeta al status de dichos art&iacute;culos, fecha de expiraci&oacute;n y otros par&aacute;metros.';
+$lang['error_nooptions'] = 'No hay opciones especificadas para la definici&oacute;n del campo';
+$lang['dropdown'] = 'Menu desplegable';
+$lang['info_public'] = 'Los campos p&uacute;blicos no estan disponibles para edici&oacute;n a traves de la pagina frontal, o para desplegar en la vista sumaria o vista detallada. Estos son utiles para informaci&oacute;n que es asociada con los articulos de noticias, pero no es para uso publico.';
+$lang['info_expired_viewable'] = 'Si se habilita, articulos expirados se pueden ver en la vista detallada. El par&aacute;metro &#039;showall&#039; puede usarse en la URL (cuando no se utilicen the URLS amigables) para indicar que los articulos expirados se pueden ver.';
+$lang['expired_viewable'] = 'Articulos que han expirado se pueden ver en la vista detallada.';
 $lang['error_insufficientparams'] = 'Faltan los par&aacute;metros necesarios';
 $lang['error_duplicatename'] = 'Ya existe un &iacute;tem con el mismo nombre';
 $lang['detail_page'] = 'P&aacute;gina de detalle';
@@ -13,7 +19,7 @@ $lang['title_fesubmit_settings'] = 'Configuraci&oacute;n de env&iacute;o a trav&
 $lang['title_notification_settings'] = 'Configuraci&oacute;n de notificaci&oacute;n';
 $lang['title_detail_settings'] = 'Configuraci&oacute;n de la vista de detalle';
 $lang['error_invalidurl'] = 'URL Inv&aacute;lida <em>(puede que est&eacute; en uso, o que contenga caracteres inv&aacute;lidos)</em>';
-$lang['url'] = 'URL ';
+$lang['url'] = 'URL';
 $lang['expired_searchable'] = 'Los art&iacute;culos vencidos pueden aparecer en resultados de b&uacute;squedas';
 $lang['helpshowall'] = 'Mostrar todos los art&iacute;culos, sin importar la fecha en que finalizan';
 $lang['error_invaliddates'] = 'Una o m&aacute;s de las fechas introducidas son invalidas';
@@ -80,7 +86,7 @@ $lang['subject_newnews'] = 'Se ha enviado un art&iacute;culo nuevo de Noticias';
 $lang['email_subject'] = 'El Asunto del email saliente';
 $lang['email_template'] = 'El formato del mensaje del email';
 $lang['formsubmit_emailaddress'] = 'Direcci&oacute;n del email para recibir notificaciones de env&iacute;os de noticias';
-$lang['extra'] = 'Extra ';
+$lang['extra'] = 'Extra';
 $lang['uploadscategory'] = 'Categor&iacute;a de Subidas';
 $lang['title_available_templates'] = 'Plantillas Disponibles';
 $lang['resettodefault'] = 'Resetear a los Valores Iniciales';
@@ -150,7 +156,7 @@ $lang['filter'] = 'Filtro';
 $lang['more'] = 'M&aacute;s';
 $lang['category_label'] = 'Categor&iacute;a:';
 $lang['author_label'] = 'Enviado por:';
-$lang['extra_label'] = 'Extra: ';
+$lang['extra_label'] = 'Extra:';
 $lang['moretext'] = 'Texto M&aacute;s';
 $lang['name'] = 'Nombre';
 $lang['news'] = 'Noticias';
@@ -197,8 +203,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>Se env&iacute;a cuando a&ntilde;adimos
 <li>\&quot;start_time\&quot; - Fecha de inicio a partir de la cual se muestra el art&iacute;culo</li>
 <li>\&quot;end_time\&quot; - Fecha de vencimiento a partir de la cual no se muestra el art&iacute;culo</li>
 <li>\&quot;useexp\&quot; - Si la fecha de vencimiento se ignora o no</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsArticleEdited'] = 'Se envia cuando editamos un art&iacute;culo.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Se env&iacute;a cuando se edita un art&iacute;culo.</p>
 <h4>Par&aacute;metros</h4>
@@ -212,8 +217,7 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>Se env&iacute;a cuando se edita un ar
 <li>\&quot;start_time\&quot; - Fecha de inicio a partir de la cual se muestra el art&iacute;culo</li>
 <li>\&quot;end_time\&quot; - Fecha de vencimiento a partir de la cual no se muestra el art&iacute;culo</li>
 <li>\&quot;useexp\&quot; - Si la fecha de vencimiento se ignora o no</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsArticleDeleted'] = 'Se env&iacute;a cuando eliminamos un art&iacute;culo.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Se env&iacute;a cuando se elimina un art&iacute;culo.</p>
 <h4>Par&aacute;metros</h4>
@@ -241,8 +245,7 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Se env&iacute;a cuando se elimina u
 <ul>
 <li>\&quot;category_id\&quot; - Id de la categor&iacute;a eliminada</li>
 <li>\&quot;name\&quot; - Nombre de la categor&iacute;a eliminada</li>
-</ul>
-';
+</ul>';
 $lang['help_articleid'] = 'Este parametro s&oacute;lo se aplica a la vista en detalle. Permite especificar qu&eacute; art&iacute;culos de noticias se muestran en el modo detalle. Con el valor especial -1, el sistema mostrar&aacute; el articulo m&aacute;s nuevo, publicado, que no ha vencido.';
 $lang['helpnumber'] = 'N&uacute;mero m&aacute;ximo de elementos a mostrar (por p&aacute;gina) -- dej&aacute;ndolo en blanco los muestra todos. Es equivalente al par&aacute;metro pagelimit.';
 $lang['helpstart'] = 'Comenzar por el en&eacute;simo elemento -- dej&aacute;ndolo en blanco comenzar&aacute; por el primero.';
@@ -292,8 +295,8 @@ $lang['help'] = '<h3>Notas Importantes</h3>
 <li>Pulse en Enviar</li>
 </ul>
 <p>Con estos pasos se deber&iacute;a solucionar el problema de las plantillas no encontradas y otros errores smarty similares que se producen cuando actualiza a una la versi&oacute;n de CMS que incluye el m&oacute;dulo News 2.3 o superior.</p>';
-$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
-$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.920242698.1386014977.1386014977.1386014977.1';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1386014977.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
