@@ -1,19 +1,25 @@
 <?php
+$lang['help_idlist'] = 'Applicable uniquement &agrave; l&#039;action par d&eacute;faut (Affiche le sommaire). Ce param&egrave;tre accepte une liste s&eacute;par&eacute;e par des virgules des ID num&eacute;riques des articles et permet de filtrer davantage d&#039;articles que &quot;articleid&quot;. La sortie de la liste actuelle des articles est toujours soumise &agrave; l&#039;&eacute;tat de l&#039;article, &agrave; date d&#039;expiration, et &agrave; d&#039;autres param&egrave;tres.';
+$lang['error_nooptions'] = 'Pas d&#039;option sp&eacute;cifi&eacute;e pour la d&eacute;finition de champ';
+$lang['dropdown'] = 'Liste d&eacute;roulante';
+$lang['info_public'] = 'Seuls les champs publics sont disponibles pour l&#039;&eacute;dition sur le site (frontend), ou pour l&#039;affichage du r&eacute;sum&eacute; ou du d&eacute;tail.';
+$lang['info_expired_viewable'] = 'Si activ&eacute;e, les articles p&eacute;rim&eacute;s peuvent &ecirc;tre visualis&eacute;es en mode d&eacute;tail (ce qui est l&#039;ancienne fonctionnalit&eacute;). Le param&egrave;tre showall peut &ecirc;tre utilis&eacute; avec l&#039;URL (si vous n&#039;utilisez pas les pretty URLs jolies)pour indiquer &eacute;galement que les articles p&eacute;rim&eacute;s peuvent &ecirc;tre consult&eacute;s.';
+$lang['expired_viewable'] = 'Articles expir&eacute;s peuvant &ecirc;tre consult&eacute;s dans la vue de d&eacute;tail';
 $lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant (ou vide)';
 $lang['error_duplicatename'] = 'Un &eacute;l&eacute;ment avec ce nom existe d&eacute;j&agrave;';
 $lang['detail_page'] = 'Page de d&eacute;tail&nbsp;';
 $lang['detail_template'] = 'Gabarit du d&eacute;tail&nbsp;';
 $lang['warning_preview'] = 'Attention : cette page d&#039;aper&ccedil;u se comporte comme une fen&ecirc;tre permettant de naviguer loin de cette page aper&ccedil;u originale. Toutefois, si vous faites cela, attention aux comportements inattendus ! <strong>Note :</strong> La pr&eacute;visualisation ne tient pas compte des fichiers pouvant &ecirc;tre en attente d&#039;upload.';
-$lang['article'] = 'Article ';
+$lang['article'] = 'Article&nbsp;';
 $lang['preview'] = 'Aper&ccedil;u';
-$lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails';
+$lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails.';
 $lang['title_detail_returnid'] = 'Page par d&eacute;faut &agrave; utiliser pour des vues de d&eacute;tail';
 $lang['title_submission_settings'] = 'Param&egrave;tres de soumission des articles (News)';
 $lang['title_fesubmit_settings'] = 'Param&egrave;tres de soumission via le Frontend';
 $lang['title_notification_settings'] = 'Param&egrave;tres des notifications';
 $lang['title_detail_settings'] = 'Param&eacute;tres d&#039;affichage des d&eacute;tails';
 $lang['error_invalidurl'] = 'URL incorrecte <em>(peut-&ecirc;tre d&eacute;j&agrave; utilis&eacute;e, ou il y a des caract&egrave;res non valides)</em>';
-$lang['url'] = 'URL ';
+$lang['url'] = 'URL&nbsp;';
 $lang['expired_searchable'] = 'Les articles expir&eacute;s peuvent appara&icirc;tre dans les r&eacute;sultats de recherche&nbsp;';
 $lang['helpshowall'] = 'Si positionn&eacute; &agrave; 1 : affiche tous les articles, quelle que soit la date de fin';
 $lang['error_invaliddates'] = 'Une ou plusieurs dates entr&eacute;es sont invalides';
@@ -80,7 +86,7 @@ $lang['subject_newnews'] = 'Un nouvel article a &eacute;t&eacute; post&eacute;';
 $lang['email_subject'] = 'Le sujet du mail de notification&nbsp;';
 $lang['email_template'] = 'Le format du message par email&nbsp;';
 $lang['formsubmit_emailaddress'] = 'Adresse email pour recevoir les notifications des articles soumis&nbsp;';
-$lang['extra'] = 'Extra ';
+$lang['extra'] = 'Extra&nbsp;';
 $lang['uploadscategory'] = 'Cat&eacute;gorie t&eacute;l&eacute;chargements';
 $lang['title_available_templates'] = 'Gabarits disponibles';
 $lang['resettodefault'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
@@ -99,7 +105,7 @@ $lang['prompt_name'] = 'Nom';
 $lang['prompt_default'] = 'D&eacute;faut';
 $lang['prompt_newtemplate'] = 'Cr&eacute;er un nouveau gabarit';
 $lang['help_pagelimit'] = 'Nombre maximal d&#039;articles affich&eacute;s (par page). Si ce param&egrave;tre n&#039;est pas d&eacute;fini, tous les articles sont affich&eacute;s. Si ce param&egrave;tre est d&eacute;fini, et que le nombre d&#039;articles est sup&eacute;rieur, les textes et les liens seront affich&eacute;s pour permettre le d&eacute;filement des r&eacute;sultats.';
-$lang['prompt_page'] = 'Page ';
+$lang['prompt_page'] = 'Page&nbsp;';
 $lang['firstpage'] = '<<';
 $lang['prevpage'] = '<';
 $lang['nextpage'] = '>';
@@ -126,7 +132,7 @@ $lang['addnewsitem'] = 'Ajouter un article';
 $lang['allcategories'] = 'Toutes les cat&eacute;gories';
 $lang['allentries'] = 'Toutes les entr&eacute;es';
 $lang['areyousure'] = '&Ecirc;tes-vous s&ucirc;r(e) de vouloir supprimer&nbsp;?';
-$lang['articles'] = 'Articles ';
+$lang['articles'] = 'Articles&nbsp;';
 $lang['cancel'] = 'Annuler';
 $lang['category'] = 'Cat&eacute;gorie&nbsp;';
 $lang['categories'] = 'Cat&eacute;gories';
@@ -150,8 +156,8 @@ $lang['filter'] = 'Filtre';
 $lang['more'] = 'Plus';
 $lang['category_label'] = 'Cat&eacute;gorie&nbsp;:';
 $lang['author_label'] = 'Post&eacute; par&nbsp;:';
-$lang['extra_label'] = 'Extra : ';
-$lang['moretext'] = 'Texte pour ';
+$lang['extra_label'] = 'Extra :';
+$lang['moretext'] = 'Texte pour';
 $lang['name'] = 'Nom&nbsp;';
 $lang['news'] = 'Articles';
 $lang['news_return'] = 'Retour';
@@ -181,7 +187,7 @@ $lang['summary'] = 'Sommaire&nbsp;';
 $lang['summarytemplate'] = 'Gabarit du sommaire article';
 $lang['summarytemplateupdated'] = 'Le gabarit de l&#039;affichage du sommaire de l&#039;article a &eacute;t&eacute; mis &agrave; jour avec succ&egrave;s';
 $lang['title'] = 'Titre&nbsp;';
-$lang['options'] = 'Options ';
+$lang['options'] = 'Options&nbsp;';
 $lang['optionsupdated'] = 'Les options ont &eacute;t&eacute; mises &agrave; jour avec succ&egrave;s';
 $lang['useexpiration'] = 'Utiliser la date d&#039;expiration&nbsp;';
 $lang['eventdesc-NewsArticleAdded'] = 'Envoy&eacute; quand un article est ajout&eacute;';
@@ -197,8 +203,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>Envoy&eacute; quand un article est ajo
 <li>&quot;start_time&quot; - Date de d&eacute;but de publication de l&#039;article</li>
 <li>&quot;end_time&quot; - Date de fin de publication de l&#039;article</li>
 <li>&quot;useexp&quot; - Si la date d&#039;expiration doit &ecirc;tre ignor&eacute;e ou pas</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsArticleEdited'] = 'Envoy&eacute; quand un article est &eacute;dit&eacute;';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Envoy&eacute; quand un article est &eacute;dit&eacute;</p>
 <h4>Param&egrave;tres</h4>
@@ -213,22 +218,20 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>Envoy&eacute; quand un article est &e
 <li>&quot;end_time&quot; - Date de fin de publication de l&#039;article</li>
 <li>&quot;useexp&quot; - Si la date d&#039;expiration doit &ecirc;tre ignor&eacute;e ou pas</li>
 </ul>
-';
+<p><strong>Note :</strong> Tous les param&egrave;tres peuvent ne pas &ecirc;tre pr&eacute;sents lorsque cet &eacute;v&eacute;nement est envoy&eacute;..</p>';
 $lang['eventdesc-NewsArticleDeleted'] = 'Envoy&eacute; quand un article est supprim&eacute;';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Envoy&eacute; quand un article est supprim&eacute;</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>&quot;news_id&quot; - Id de l&#039;article</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryAdded'] = 'Envoy&eacute; quand une cat&eacute;gorie est ajout&eacute;e';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est ajout&eacute;e</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
 <li>&quot;name&quot; - Nom de la cat&eacute;gorie</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryEdited'] = 'Envoy&eacute; quand une cat&eacute;gorie est &eacute;dit&eacute;e';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est &eacute;dit&eacute;e</p>
 <h4>Param&egrave;tres</h4>
@@ -236,16 +239,14 @@ $lang['eventhelp-NewsCategoryEdited'] = '<p>Envoy&eacute; quand une cat&eacute;g
 <li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
 <li>&quot;name&quot; - Nom de la cat&eacute;gorie</li>
 <li>&quot;origname&quot; - Nom original de la cat&eacute;gorie</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryDeleted'] = 'Envoy&eacute; quand une cat&eacute;gorie est supprim&eacute;e';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Envoy&eacute; quand une cat&eacute;gorie est supprim&eacute;e</p>
 <h4>Param&egrave;tres</h4>
 <ul>
 <li>&quot;category_id&quot; - Id de la cat&eacute;gorie</li>
 <li>&quot;name&quot; - Nom de la cat&eacute;gorie supprim&eacute;e</li>
-</ul>
-';
+</ul>';
 $lang['help_articleid'] = 'Ce param&egrave;tre est applicable uniquement &agrave; la vue de d&eacute;tail. Il permet de sp&eacute;cifier que l&#039;article sera afficher en mode d&eacute;tail. Si la valeur utilis&eacute;e est -1, le syst&egrave;me affichera l&#039;article le plus r&eacute;cemment, publi&eacute;, mais non expir&eacute;.';
 $lang['helpnumber'] = 'Le nombre maximal d&#039;articles &agrave; afficher -- laisser ce param&egrave;tre vide affichera tous les articles. C&#039;est identique au param&egrave;tre &quot;pagelimit&quot;.';
 $lang['helpstart'] = 'Commence au &eacute;ni&egrave;me article -- laisser ce param&egrave;tre vide commencera l&#039;affichage au premier article';
@@ -264,11 +265,9 @@ $lang['helpaction'] = 'Outrepasse l&#039;action par d&eacute;faut. Les valeurs p
 <ul>
 <li>&quot;detail&quot; - pour afficher l&#039;article en mode d&eacute;tail.</li>
 <li>&quot;default&quot; - pour afficher le sommaire de l&#039;article</li>
-<li>&quot;fesubmit&quot; - pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site. Ajouter le <code>{cms_init_editor}</code> dans la section des m&eacute;ta-donn&eacute;es pour initialiser l&#039;&eacute;diteur WYSIWYG s&eacute;lectionn&eacute; (Administration du site/Param&egrave;tres globaux/WYSIWYG de la partie publique).</li>
+<li>&quot;fesubmit&quot; - <strong>Obsol&egrave;te</strong>pour afficher le gabarit de soumission (frontend) d&#039;articles des utilisateurs dans les pages du site. Ajouter le <code>{cms_init_editor}</code> dans la section des m&eacute;ta-donn&eacute;es pour initialiser l&#039;&eacute;diteur WYSIWYG s&eacute;lectionn&eacute; (Administration du site/Param&egrave;tres globaux/WYSIWYG de la partie publique).</li>
 <li>&quot;browsecat&quot; - pour afficher une liste de cat&eacute;gories.</li>
-</ul>
-
-';
+</ul>';
 $lang['help'] = '<h3>Notes Importantes</h3>
 <p>la Version 2.9 a supprim&eacute; le format &quot;formatpostdate&quot; des gabarits, et a &eacute;galement supprim&eacute; le param&egrave;tre &quot;dateformat&quot;. Vous devez utiliser le param&egrave;tre &quot;cms_date_format&quot; (comme indiqu&eacute; dans les gabarits par d&eacute;faut) pour les format des dates, et devrait utiliser entry->postdate au lieu de entry->formatpostdate dans vos gabarits.</p>
 <h3>Que fait ce module ?</h3>
@@ -295,9 +294,8 @@ $lang['help'] = '<h3>Notes Importantes</h3>
 <li>Cliquer sur le bouton Envoyer</li>
 </ul>
 <p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
-$lang['qca'] = 'P0-1532147203-1273233257739';
-$lang['utma'] = '156861353.372298033.1340641332.1340641332.1340641332.1';
-$lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1340641332.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.2066204022.1383683408.1383683408.1383683408.1';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1383683408.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
