@@ -1,4 +1,9 @@
 <?php
+$lang['error_nooptions'] = 'Za definiciju polja nisu izabrane potrebne opcije';
+$lang['dropdown'] = 'Padajući meni';
+$lang['info_public'] = 'U korisničkom delu sajta za editovanje ili za prikazivanje novosti dostupna su samo javna polja.';
+$lang['info_expired_viewable'] = 'Ukoliko je omogućena, ova opcija učiniće da članci koji su istekli budu vidljivi u detaljnom pregledu (ovo podražava jednu staru funkcionalnost).  Parametar <code>showall</code>  takođe može biti upotrebljen u URL (kada sajt ne koristi tzv. <em>pretty urls</em> ) da bi se odredila vidljivost isteklih članaka';
+$lang['expired_viewable'] = 'Članci koji su istekli mogu se pogledati u detaljnom pregledu';
 $lang['error_insufficientparams'] = 'Nedovoljan broj parametara (ili su neki prazni)';
 $lang['error_duplicatename'] = 'Stavka sa ovim nazivom već postoji';
 $lang['detail_page'] = 'Stranica za detaljan prikaz';
@@ -13,7 +18,7 @@ $lang['title_fesubmit_settings'] = 'Pode&scaron;avanje procedue objavljivanja iz
 $lang['title_notification_settings'] = 'Pode&scaron;avanje obave&scaron;tenja';
 $lang['title_detail_settings'] = 'Pode&scaron;avanja detaljnog pregleda';
 $lang['error_invalidurl'] = 'Lo&scaron; URL <em>(možda je već u upotrebi, ili sadrži nevalidne karaktere)</em>';
-$lang['url'] = 'URL ';
+$lang['url'] = 'URL';
 $lang['expired_searchable'] = 'Članci kojima je važnost istekla mogu se pojaviti u rezultatima pretrage';
 $lang['helpshowall'] = 'Prikaži sve članke, nezavisno od datuma prestanka važnosti';
 $lang['error_invaliddates'] = 'Jedan ili vi&scaron;e unetih datuma nisu validni';
@@ -144,9 +149,9 @@ $lang['edit'] = 'Izmeni';
 $lang['enddate'] = 'Datum isteka';
 $lang['endrequiresstart'] = 'Uno&scaron;enje datuma isteka zahteva da unesete i datum početka važenja';
 $lang['entries'] = '%s članak(a)';
-$lang['status'] = 'Status ';
+$lang['status'] = 'Status';
 $lang['expiry'] = 'Ističe';
-$lang['filter'] = 'Filter ';
+$lang['filter'] = 'Filter';
 $lang['more'] = 'Jo&scaron;';
 $lang['category_label'] = 'Kategorija:';
 $lang['author_label'] = 'Objavio/la:';
@@ -197,8 +202,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>&Scaron;alje se nakon objavljivanja sv
 <li>\&quot;start_time\&quot; - Datum kada bi se novost trebala početi prikazivati</li>
 <li>\&quot;end_time\&quot; - Datum kada bi će novost prestati prikazivati</li>
 <li>\&quot;useexp\&quot; - Da li datum isteka važnosti treba zanemariti ili ne</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsArticleEdited'] = '&Scaron;alje se nakon ažuriranja članka.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>&Scaron;alje se nakon ažuriranja članka.</p>
 <h4>Parametri</h4>
@@ -212,23 +216,20 @@ $lang['eventhelp-NewsArticleEdited'] = '<p>&Scaron;alje se nakon ažuriranja čl
 <li>\&quot;start_time\&quot; - Datum kada bi se novost trebala početi prikazivati</li>
 <li>\&quot;end_time\&quot; - Datum kada bi će novost prestati prikazivati</li>
 <li>\&quot;useexp\&quot; - Da li datum isteka važnosti treba zanemariti ili ne</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsArticleDeleted'] = '&Scaron;alje se nakon brisanja članka';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>&Scaron;alje se nakon brisanja članka</p>
 <h4>Parametri</h4>
 <ul>
 <li>\&quot;news_id\&quot; - Id članka</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryAdded'] = '&Scaron;alje se nakon dodavanja nove kategorije.';
 $lang['eventhelp-NewsCategoryAdded'] = '<p>&Scaron;alje se nakon dodavanja nove kategorije.</p>
 <h4>Parametri</h4>
 <ul>
 <li>\&quot;category_id\&quot; - Id kategorije novosti</li>
 <li>\&quot;name\&quot; - Naziv kategorije</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryEdited'] = '&Scaron;alje se nakon ažuriranja kategorije.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>&Scaron;alje se nakon ažuriranja kategorije.</p>
 <h4>Parametri</h4>
@@ -236,16 +237,14 @@ $lang['eventhelp-NewsCategoryEdited'] = '<p>&Scaron;alje se nakon ažuriranja ka
 <li>\&quot;category_id\&quot; - Id kategorije novosti</li>
 <li>\&quot;name\&quot; - Naziv kategorije</li>
 <li>\&quot;origname\&quot; - Prethodni naziv kategorije</li>
-</ul>
-';
+</ul>';
 $lang['eventdesc-NewsCategoryDeleted'] = '&Scaron;alje se nakon brisanja kategorije.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>&Scaron;alje se nakon brisanja kategorije.</p>
 <h4>Parametri</h4>
 <ul>
 <li>\&quot;category_id\&quot; - Id kategorije novosti</li>
 <li>\&quot;name\&quot; - Naziv obrisane kategorije</li>
-</ul>
-';
+</ul>';
 $lang['help_articleid'] = 'Parametar je primenljiv isključivo na detaljan prikaz novosti. Omogućava koji članci će biti prikazani u detaljnom modu. Ukoliko je pode&scaron;en na specijalnu vrednost -1, sistem će prikazivati najsvežiji, objavljeni važeći članak.';
 $lang['helpnumber'] = 'Maksimalan broj članaka koji mogu biti prikazani na jednoj stranici. Ukoliko ovo polje ostavite prazno, prikazaće se svi članci. Ovo je sinonim parametra <code>pagelimit</code>';
 $lang['helpstart'] = 'Počni od n-tog članka. Ukoliko ostavite ovo polje prazno, počeće se od prvog članka.';
@@ -295,8 +294,8 @@ $lang['help'] = '<h3>Važne napomene</h3>
 <li>Kliknite na &#039;Po&scaron;alji&#039;</li>
 </ul>
 <p>Ovo bi trebalo da re&scaron;i problem nepronalaženja &scaron;ablona za novosti i druge slične Smarty gre&scaron;ke koje su se mogle javiti nakon &scaron;to se prebacite na verziju CMS MS-a koja sadrži verziju 2.3 modula ili noviju.</p>';
-$lang['utma'] = '156861353.279934917.1335981957.1335981957.1335981957.1';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.114482514.1383506026.1383506026.1383510479.2';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1335981957.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1383506026.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
