@@ -3,12 +3,12 @@ $lang['use_or'] = 'Trova corrispondenze su QUALSIASI parola';
 $lang['param_detailpage'] = 'Usato solo per combinare risultati dai moduli, questo parametro permette specificare una differente pagina per i risultati. Questo &egrave; utile se, per esempio, mostrate sempre le viste di dettaglio in una pagina con un template diverso.  <em>(<strong>Nota:</strong> i moduli hanno la possibilit&agrave; di sovrascrivere questo parametro.)</em>';
 $lang['prompt_resultpage'] = 'Pagina per risultati di moduli individuali <em>(Nota che i moduli possono opzionalmente sovrascrive questo)</em>';
 $lang['search_method'] = 'Compatibilit&agrave; Pretty Urls via metodo POST, valore predefinito &egrave; sempre GET, per utilizzarlo dovete mettere {search search_method=&quot;post&quot;}';
-$lang['export_to_csv'] = 'Esporta a CSV';
+$lang['export_to_csv'] = 'Esporta in CSV';
 $lang['prompt_savephrases'] = 'Traccia Frasi ricercate, non Parole Individuali';
 $lang['word'] = 'Parola';
 $lang['count'] = 'Contatore';
-$lang['confirm_clearstats'] = 'Siete sicuri di voler cancellare tutte le statistiche?';
-$lang['clear'] = 'Cancella';
+$lang['confirm_clearstats'] = 'Siete sicuri di volere eliminare tutte le statistiche?';
+$lang['clear'] = 'Pulisci';
 $lang['statistics'] = 'Statistiche';
 $lang['param_action'] = 'Specifica il modo operativo del modulo. Valori accettabili sono &#039;default&#039; e &#039;keywords&#039;. La azione keywords pu&ograve; essere usata per generare una lista separata da virgola di parole da usare nel meta tag keywords.';
 $lang['param_count'] = 'Usata con l&#039;azione keywords, questo parametro limita l&#039;uscita al numero specificato di parole';
@@ -18,7 +18,7 @@ $lang['param_passthru'] = 'Passa i parametri nominati ai moduli specificati. Il
 $lang['param_modules'] = 'Limita i risultati della ricerca ai valori indicizzati dalla specifica lista (separati da virgola) di moduli';
 $lang['searchsubmit'] = 'Invia';
 $lang['search'] = 'Cerca';
-$lang['param_submit'] = 'Testo da posizionare nel bottone di submit';
+$lang['param_submit'] = 'Testo da posizionare nel pulsante Invio';
 $lang['param_searchtext'] = 'Testo da posizionare nel box di ricerca';
 $lang['prompt_searchtext'] = 'Testo di ricerca predefinito';
 $lang['param_resultpage'] = 'Pagina che visualizza i risultati della ricerca. Questa pu&ograve; essere un alias di pagina o un id. Usato per permettere che i risultati siano visualizzati in un diverso Modello di quello della ricerca';
@@ -98,8 +98,6 @@ $lang['help'] = '<h3>What does this do?</h3>
 <h4>How do i prevent certain content from being indexed</h4>
 <p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> When the search module sees this tag in the page it will not index any content for that page.</p>
 <p>The <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>';
-$lang['utma'] = '156861353.1173279377.1339488425.1339488425.1339492135.2';
-$lang['utmz'] = '156861353.1339488425.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '107768413.761460248.1357753980.1357753980.1357753980.1';
+$lang['utmz'] = '107768413.1357753980.1.1.utmcsr=solgea.net|utmccn=(referral)|utmcmd=referral|utmcct=/cmsms/admin/editcontent.php';
 ?>
\ No newline at end of file
