@@ -376,8 +376,6 @@ foreach( $stylesheet_ids as $id )
   $output .= "  </stylesheet>\n";	
 }
 
-debug_to_log('associations');
-debug_to_log($associations);
 foreach( $associations as $assoc1 )
 {
   $tname = $assoc1['tname'];
@@ -433,16 +431,13 @@ foreach( $urls as $oneurl )
     }
   if( !file_exists($oneurl) )
     {
-      debug_to_log("file not found url: $origurl -  file:$oneurl");
       continue;
     }
   $contents = file_get_contents( $oneurl );
   if( !$contents ) 
     {
-      debug_to_log('unable to read: '.$oneurl);
       continue;
     }
-  debug_to_log('converted: '.$origurl.' to '.$oneurl);
   $encoded = base64_encode( $contents );
   $output .= "  <reference>\n";
   $output .= "    <refname>".basename($oneurl)."</refname>\n";
