@@ -20,7 +20,7 @@
 	Main function
 **********************************************************/
 
-function smarty_function_cms_stylesheet($params, &$template)
+function smarty_cms_function_cms_stylesheet($params, &$template)
 {
 	#---------------------------------------------
 	# Initials
@@ -58,7 +58,7 @@ function smarty_function_cms_stylesheet($params, &$template)
 	if (isset($params["templateid"]) && $params["templateid"]!="") {
 		$template_id = $params["templateid"];
 	} else {
-		$content_obj = cmsms()->variables['content_obj'];
+		$content_obj = cms_utils::get_current_content();
 		if( !is_object($content_obj) ) return;
 		$template_id = $content_obj->TemplateId();
 		$use_https = (int)$content_obj->Secure();
@@ -199,7 +199,7 @@ function smarty_function_cms_stylesheet($params, &$template)
 							if( !endswith($text,"\n") ) $text .= "\n";
 					}
 
-					cms_stylesheet_writeCache($fn, $text, $trimbackground, $smarty, $forceblackandwhite);
+					cms_stylesheet_writeCache($fn, $text, $trimbackground, $smarty, $forceblackandwhite, $template_id);
 				}
 
 				cms_stylesheet_toString($filename, $params['media'], '', $root_url, $stylesheet, $params);
@@ -233,7 +233,7 @@ function smarty_function_cms_stylesheet($params, &$template)
 							if( !endswith($text,"\n") ) $text .= "\n";
 						}
 
-						cms_stylesheet_writeCache($fn, $text, $trimbackground, $smarty, $forceblackandwhite);
+						cms_stylesheet_writeCache($fn, $text, $trimbackground, $smarty, $forceblackandwhite, $template_id);
 					}
 
 					cms_stylesheet_toString($filename, $media_query, $media_type, $root_url, $stylesheet, $params);
@@ -260,7 +260,7 @@ function smarty_function_cms_stylesheet($params, &$template)
 				
 				if (!file_exists($fn)) {
 		
-					cms_stylesheet_writeCache($fn, $one['css_text'], $trimbackground, $smarty, $forceblackandwhite);					
+					cms_stylesheet_writeCache($fn, $one['css_text'], $trimbackground, $smarty, $forceblackandwhite, $template_id);					
 				}
 
 				cms_stylesheet_toString($filename, $media_query, $media_type, $root_url, $stylesheet, $params);
@@ -303,12 +303,23 @@ function smarty_function_cms_stylesheet($params, &$template)
 	Misc functions
 **********************************************************/
 
-function cms_stylesheet_writeCache($filename, $string, $trimbackground, &$smarty, $forceblackandwhite = false)
+function cms_stylesheet_writeCache($filename, $string, $trimbackground, &$smarty, $forceblackandwhite = false, $template_id = null)
 {
+	$_contents = '';
+
 	// Smarty processing
 	$smarty->left_delimiter = '[[';
 	$smarty->right_delimiter = ']]';
-	$_contents = $smarty->fetch('string:'.$string);
+
+	try {
+
+		$_contents = $smarty->fetch('string:'.$string);
+	}	
+	catch (SmartyException $e)
+	{
+		audit($template_id, 'Plugin: cms_stylesheet', 'Smarty Compile process failed, unable to write cache file');
+	}	
+	
 	$smarty->left_delimiter = '{';
 	$smarty->right_delimiter = '}';					
 
@@ -336,6 +347,7 @@ function cms_stylesheet_writeCache($filename, $string, $trimbackground, &$smarty
 
 function cms_stylesheet_toString($filename, $media_query = '', $media_type = '', $root_url, &$stylesheet, &$params)
 {
+	if( !endswith($root_url,'/') ) $root_url .= '/';
 	if( isset($params['nolinks']) )
 	{
 		$stylesheet .= $root_url.$filename.',';
@@ -377,4 +389,4 @@ function smarty_cms_about_function_cms_stylesheet()
 	</p>
 	<?php
 } // end of about
-?>
\ No newline at end of file
+?>
