@@ -16,8 +16,9 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-function smarty_cms_function_modified_date($params, &$smarty)
+function smarty_function_modified_date($params, &$template)
 {
+  $smarty = $template->smarty;
 	$gCms = cmsms();
 	$content_obj = $gCms->variables['content_obj'];
 
