@@ -1,4 +1,6 @@
 <?php
+$lang['error_timedifference'] = 'The filesystem where CMSMS is installed has a significantly different time than the actual server time';
+$lang['test_timedifference'] = 'Testing if filesystem time is different than server time';
 $lang['detected'] = 'Detected';
 $lang['docroot_leaveblank'] = 'Leave this blank to use the system default';
 $lang['test_xmlreader_class'] = 'Checking if the XMLReader class exists';
@@ -10,7 +12,7 @@ $lang['ip_addr'] = 'IP Address';
 $lang['install_admin_pwsalt_note'] = 'If you choose to enable password salts, there is absolutely no way to reset lost admin passwords, other than through the lost password functionality.   It is critical that you associate an email address with each admin account';
 $lang['admin_salt'] = 'Salt Admin Passwords';
 $lang['setup_flat_urls'] = 'Flat URLs are setup';
-$lang['install_timezone'] = 'Some servers running PHP 5.3 do not have the timezone set correctly. Please select the appropriate timezone from the list below before proceeding. If this is not necessary on your server, you may select &quot;None&quot;. <strong>Note:</strong> Please select your servers timezone, this is not a display setting, but is used in arithmetic related to dates.  This setting can be changed after installation by modifying the config.php file.';
+$lang['install_timezone2'] = 'Please select the timezone for your installation.  This timezone value will be used for entering times into the system and for date and time calculations.<br/><br/>CMSMS has attempted to choose an intelligent default for you based on your servers current location, however this may not be correct.<br/><br/><strong style="color: red;">Note:</strong> This is a change in behavior from previous versions of CMSMS. Also, you may need to enable the set_db_timezone config value if your server is in a different timezone than your primary user base.';
 $lang['timezone'] = 'Timezone';
 $lang['none'] = 'None';
 $lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
@@ -63,7 +65,7 @@ $lang['noneed_upgrade_modules'] = 'The core modules are up to date';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of "%s" module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of "%s" module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a "Site Down for Maintainence" message on your site';
-$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it\'s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Module Manager page and looking in the tab "Available Upgrades"';
+$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset its permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Module Manager page and looking in the tab "Available Upgrades"';
 $lang['upgrade_complete'] = 'Upgrade process complete';
 $lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
 $lang['here'] = 'here';
