@@ -1,4 +1,7 @@
 <?php
+$lang['test_xmlreader_class'] = 'Checking if the XMLReader class exists';
+$lang['test_xmlreader_failed'] = 'The XMLReader class is not enabled in your php install.  You can still use the system but will not be able to use any of the remote module installation functions.';
+$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
 $lang['installed_module'] = 'Module Installed';
 $lang['automatedtask_success'] = 'Automated Task Succeeded';
 $lang['ip_addr'] = 'عنوان IP';
@@ -19,7 +22,7 @@ $lang['empty_query'] = 'Empty query?? %s';
 $lang['no_db_driver'] = 'No compatible database drivers found';
 $lang['test_check_output_buffering'] = 'Checking output buffering';
 $lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
-$lang['phpinfo'] = 'Display PHP Information';
+$lang['phpinfo'] = 'عرض معلومات PHP';
 $lang['mod_security'] = 'Apache Mod Security';
 $lang['test_check_tempnam'] = 'Checking for tempnam Function';
 $lang['test_check_db_drivers'] = 'DB drivers';
@@ -31,7 +34,7 @@ $lang['test_check_disable_functions_failed'] = 'Warning: this is a list of funct
 $lang['install_admin_db_port'] = 'Database port';
 $lang['install_admin_db_port_info'] = 'If you don&#039;t know, leave this blank to use default settings.';
 $lang['install_admin_db_socket'] = 'Database socket';
-$lang['install_admin_db_socket_info'] = 'NOT SUPPORTED.';
+$lang['install_admin_db_socket_info'] = 'غير معتمد.';
 $lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
 $lang['install_default_encoding'] = 'In almost all cases, default_encoding should be utf-8.';
 $lang['installer_done'] = '[done]';
@@ -259,7 +262,6 @@ $lang['test_may_not_exist'] = 'This file may not exist yet. If it does not, you
 $lang['could_not_retrieve_a_value'] = 'Could not retrieve a value.... passing anyways.';
 $lang['displaying_the_value_originally'] = '<br />Displaying the value originally set in the config file (this may not be accurate).';
 $lang['test_check_xml_func'] = 'Checking for basic XML (expat) support';
-$lang['test_check_xml_failed'] = 'XML support is not compiled into your php install. You can still use the system, but will not be able to use any of the remote module installation functions.';
 $lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
 $lang['test_remote_url'] = 'Test for remote URL';
 $lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
@@ -347,8 +349,8 @@ username: %s
 password: %s
 
 Log into the site admin here: %s';
-$lang['utma'] = '156861353.478918710.1311178605.1311178605.1311178605.1';
-$lang['utmz'] = '156861353.1311178605.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1091097006.1334784264.1335277717.1335612942.7';
+$lang['utmz'] = '156861353.1334784264.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
 $lang['qca'] = 'P0-1393246855-1304498842364';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
