@@ -1,14 +1,24 @@
 <?php
-$lang['setup_flat_urls'] = 'Flat URLs are setup';
-$lang['install_timezone'] = 'Some servers running php 5.3 have not set the timezone correctly.  Please select the appropriate timezone from the list before.  If this is not necessary on your server you may select &quot;None&quot;, you can always change this setting later in the config.php.';
+$lang['detected'] = 'Fundet';
+$lang['docroot_leaveblank'] = 'Tomt felt betyder, at systemets grundindstillinger anvendes';
+$lang['test_xmlreader_class'] = 'Unders&oslash;ger om XMLReader class findes';
+$lang['test_xmlreader_failed'] = 'XMLReader class er ikke aktiveret i din installation af php.  Du kan bruge systemet alligevel, men du vil ikke kunne anvende nogen af de funktioner, som installerer moduler fra andre servere.';
+$lang['test_check_xml_failed'] = 'XML underst&oslash;ttelse er ikke kompileret ind i din php installation. Du kan stadig benytte systemet, men vil ikke kunne benytte modul h&aring;ndteringen til at installere nyt moduler direkte fra fjernserveren.';
+$lang['installed_module'] = 'Modul installeret';
+$lang['automatedtask_success'] = 'Automatiseret opgave gennemf&oslash;rt';
+$lang['ip_addr'] = 'IP adresse';
+$lang['install_admin_pwsalt_note'] = 'Hvis du v&aelig;lger at benytte salts til kodeord, s&aring; er det ikke p&aring; nogen m&aring;de muligt at nulstille glemte admin-kodeord andet end ved at bruge funktionen til glemte kodeord. Det er absolut n&oslash;dvendigt, at hver admin-konto er tilknyttet en email adresse';
+$lang['admin_salt'] = 'Salt admin-kodeord';
+$lang['setup_flat_urls'] = 'Flade URL&#039;er er aktiveret';
+$lang['install_timezone'] = 'Nogle af de servere, som k&oslash;rer PHP 5.3, har ikke indstillet tidszonen korrekt. V&aelig;lg venligst den tidszone, som passer bedst i listen nedenfor, f&oslash;r du forts&aelig;tter. Hvis ikke det er n&oslash;dvendigt p&aring; din server, s&aring; kan du v&aelig;lge &amp;quot;Ingen&amp;quot;. <strong>Bem&aelig;rk:</strong> V&aelig;lg venligst din servers tidszone. Indstillingen vedr&oslash;rer ikke m&aring;den din hjemmeside vises p&aring; - den bruges kun i forbindelse med datoudregninger. Indstillingen kan &aelig;ndres efter installationen ved at redigere config.php filen.';
 $lang['timezone'] = 'Tidszone';
 $lang['none'] = 'Ingen';
-$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_error_estrict'] = 'Unders&oslash;ger error_reporting for at sikre, at E_STRICT er deaktiveret';
 $lang['test_estrict_failed'] = 'E_STRICT er sl&aring;et til';
-$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
-$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['info_estrict_failed'] = 'Nogle af de biblioteker, som CMSMS bruger, fungerer ikke ret godt, n&aring;r E_STRICT er aktiveret. Deaktiv&eacute;r venligst E_STRICT f&oslash;r du forts&aelig;tter';
+$lang['test_error_edeprecated'] = 'Unders&oslash;ger error_reporting for at sikre, at E_DEPRECATED er deaktiveret';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED er sl&aring;et til';
-$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
+$lang['info_edeprecated_failed'] = 'Hvis E_DEPRECATED er aktiveret i fejlrapporteringen (error reporting), vil brugerne se en masse advarselsbeskeder, hvilket kan g&aring; ud over b&aring;de udseende og funktionalitet';
 $lang['invalidemail'] = 'Den angivne email adresse er ikke gyldig';
 $lang['empty_query'] = 'Tom foresp&oslash;rgsel? %s';
 $lang['no_db_driver'] = 'Ingen kompatibel database driver fundet';
@@ -23,9 +33,9 @@ $lang['test_check_register_globals'] = 'Kontrollerer for PHP register globals';
 $lang['test_check_register_globals_failed'] = 'PHP register globals er aktiv. Af sikkerhedshensyn b&oslash;r dette v&aelig;re sl&aring;et fra';
 $lang['test_check_disable_functions'] = 'Kontrollerer PHP funktioner der er sl&aring;et fra';
 $lang['test_check_disable_functions_failed'] = 'Advarsel: dette er en list over funktioner der er sl&aring;et fra p&aring; din server';
-$lang['install_admin_db_port'] = 'Database port';
+$lang['install_admin_db_port'] = 'Databaseport';
 $lang['install_admin_db_port_info'] = 'Hvis du ikke ved det, lad dette felt forblive blankt for at benytte standard-installingerne';
-$lang['install_admin_db_socket'] = 'Database socket';
+$lang['install_admin_db_socket'] = 'Database-socket';
 $lang['install_admin_db_socket_info'] = 'Ikke underst&oslash;ttet';
 $lang['install_admin_frontendlang'] = 'Standard sprog for frontend. Dette angiver lokale installer for diverse dato funktioner etc.';
 $lang['install_default_encoding'] = 'I stort set alle situationer skal default_encoding v&aelig;re utf-8.';
@@ -47,10 +57,10 @@ $lang['schema_ok'] = 'CMS-databasen er opdateret. Benytter skema version %s';
 $lang['noneed_upgrade_schema'] = 'CMS-databasen er opdateret. Benytter skema version %s';
 $lang['upgrade_modules'] = 'Opgrad&eacute;r moduler';
 $lang['noneed_upgrade_modules'] = 'Kerne-moduler er opdateret';
-$lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
-$lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
-$lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
-$lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it&#039;s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as &quot;Needs Upgrade&quot;';
+$lang['upgrade_sql_module_from_to'] = 'Opgraderer SQL for modulet &quot;%s&quot; fra %s til %s ...';
+$lang['upgrade_event_module_from_to'] = 'Opgraderer h&aelig;ndelser vedr&oslash;rende modulet &quot;%s&quot; fra %s til %s ...';
+$lang['sitedown_not_removed'] = 'Kunne ikke fjerne filen tmp/cache/SITEDOWN. Slet den venligst manuelt ellers vil der blive ved med at v&aelig;re en besked  om, at din hjemmeside er nede grundet vedligeholdelse';
+$lang['upgrade_ok'] = 'Gennemg&aring; venligst config.php og ret nye indstillinger, hvor det er n&oslash;dvendigt. Gendan herefter filens rettigheder, s&aring; den igen er l&aring;st. Du b&oslash;r ogs&aring; tjekke, om alle dine moduler er fuldt opdaterede ved at g&aring; til Udvidelser -> Moduler. P&aring; denne side kan du se efter moduler, hvorved der st&aring;r &quot;Opgradering n&oslash;dvendig&quot;';
 $lang['upgrade_complete'] = 'Opgraderingen er udf&oslash;rt';
 $lang['upgrade_end'] = 'CMS er opgraderet. Klik %s for at se dit cms-site eller du kan %s.';
 $lang['here'] = 'her';
@@ -65,32 +75,32 @@ $lang['checksum_not_match'] = 'Checksum passer ikke!';
 $lang['not_checksum'] = 'Kunne ikke hente checksum.';
 $lang['format_datetime'] = '%c';
 $lang['upload_err_ini_size'] = 'Den upload&#039;ede fil er st&oslash;rre end den upload_max_filesize der er angivet i php.ini!';
-$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$lang['upload_err_form_size'] = 'Den uploadede fil overstiger det MAX_FILE_SIZE direktiv, som er blevet specificeret i HTML-formularen.';
 $lang['upload_err_partial'] = 'Den upload&#039;ede fil blev kun delvist upload&#039;et';
 $lang['upload_err_no_file'] = 'Ingen fil blev upload&#039;et.';
 $lang['upload_err_no_tmp_dir'] = 'Mangler en midlertidig mappe.';
 $lang['upload_err_cant_write'] = 'Fejl ved skrivning til disk.';
-$lang['upload_err_extension'] = 'File upload stopped by extension.';
+$lang['upload_err_extension'] = 'Fil-upload stoppet af udvidelse.';
 $lang['upload_err_empty'] = 'Filen er tom';
 $lang['upload_err_unknown'] = 'Ukendt upload problem';
 $lang['function_file_uploads_off'] = 'file_uploads er sl&aring;et fra i din php konfiguration!';
 $lang['upload_file_no_readable'] = 'Den upload&#039;ede fil kan ikke l&aelig;ses';
-$lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
-$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
-$lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. This can cause many problems in CMS.';
+$lang['upload_file_multiple'] = 'Upload af flere filer p&aring; &eacute;n gang er ikke tilladt!';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operationer';
+$lang['test_check_magic_quotes_gpc_failed'] = 'N&aring;r magic_quotes er aktiveret, betyder det, at enkelte og dobbelte anf&oslash;rselstegn samt backslash pr. automatik bliver &quot;escaped&quot; med en backslash. Det kan medf&oslash;re mange problemer i CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
-$lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. This will cause problems with CMS made simple.';
+$lang['test_check_magic_quotes_runtime_failed'] = 'N&aring;r magic_quotes er aktiveret, vil de fleste af de funktioner, som henter data fra alle mulige andre eksterne kilder, inklusiv databaser og tekstfiler, returnere oplysningerne med citationstegn, der er blevet &quot;escaped&quot; - alts&aring; \&quot; i stedet for &quot;. Det giver problemer for CMS made simple.';
 $lang['install_admin_checksum'] = 'Tjek din installation';
 $lang['upgrade_admin_checksum'] = 'Tjek din system opgradering';
-$lang['checksum'] = 'Checksum test';
-$lang['checksum_file'] = 'Checksum fil';
-$lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
+$lang['checksum'] = 'Checksum-test';
+$lang['checksum_file'] = 'Checksum-fil';
+$lang['install_test_checksum'] = 'Du kan validere CMS-filernes integritet ved at sammenligne med CMS&#039; originale checksum. Valideringen kan g&oslash;re det lettere at finde ud af, hvilke af de uploadede filer, der for&aring;rsager problemer.';
 $lang['checksum_passed'] = 'Alle tjeksummer passer!';
-$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
+$lang['checksum_failed'] = 'Checksummen matchede med nogle fejl. Kig i hj&aelig;lp for yderligere information';
 $lang['test_check_open_basedir'] = 'Tjek for PHP Open Basedir';
-$lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
+$lang['test_check_open_basedir_failed'] = 'Open basedir restriktioner er aktiveret. Du kan derfor f&aring; problemer med visse ekstrafunktioner.';
 $lang['unlimited'] = 'Ubegr&aelig;nset';
-$lang['test_open_basedir_session_save_path'] = 'Open basedir is setting. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
+$lang['test_open_basedir_session_save_path'] = 'Open basedir irestriktioner ser ud til at v&aelig;re aktiveret. Hvis du f&aring;r problemer med sessions og ini_set fungerer, s&aring; kan du pr&oslash;ve at aktivere session cookies ved at tilf&oslash;je: ini_set(&#039;session.use_only_cookies&#039;, 1);  i toppen af include.php';
 $lang['install_warn_db_createtables'] = 'Under normale omst&aelig;ndigheder skal dette felt altid v&aelig;re sl&aring;et til. Sl&aring; den kun fra hvis du virkelig ved hvad du g&oslash;r.';
 $lang['install_admin_tablesnotcreated'] = 'Installation fuldf&oslash;rt. Installationen er fuldf&oslash;rt, og som du &oslash;nskede blev database-tabellerne ikke oprettet. Men config-filen er blevet genskabt og alle pr&aelig;-installations-tests er kontrolleret. Tak, og her er dit';
 $lang['info_create_dir_and_file'] = 'HTTP processens ejer kan ikke oprette en fil i den mappe som den ejer. Dette betyder formentlig at safe mode er sl&aring;et til. Mange funktioner i CMS Made Simpl fungerer ikke uden at dette er muligt. Derfor kan der ikke forts&aelig;ttes.';
@@ -108,25 +118,25 @@ $lang['off'] = 'Fra';
 $lang['on'] = 'Til';
 $lang['permission_information'] = 'Information om tilladelse';
 $lang['server_os'] = 'Server Operativ System';
-$lang['server_api'] = 'Server API';
-$lang['server_software'] = 'Server Software';
-$lang['server_information'] = 'Server Information';
-$lang['session_save_path'] = 'Session Save Path';
+$lang['server_api'] = 'Server-API';
+$lang['server_software'] = 'Software installeret p&aring; serveren';
+$lang['server_information'] = 'Oplysninger om serveren';
+$lang['session_save_path'] = 'Sti til der hvor sessions gemmes';
 $lang['max_execution_time'] = 'Maksimal k&oslash;rselstid';
 $lang['gd_version'] = 'GD version';
 $lang['upload_max_filesize'] = 'Maksimal upload st&oslash;rrelse';
 $lang['post_max_size'] = 'Maksibal post st&oslash;rrelse';
 $lang['memory_limit'] = 'PHP hukommelses gr&aelig;nse';
-$lang['server_db_type'] = 'Server Database';
-$lang['server_db_version'] = 'Server Database Version';
+$lang['server_db_type'] = 'Server-database';
+$lang['server_db_version'] = 'Server-database-version';
 $lang['phpversion'] = 'Nuv&aelig;rende PHP version';
 $lang['safe_mode'] = 'PHP Safe Mode';
-$lang['php_information'] = 'PHP Information';
-$lang['cms_install_information'] = 'CMS Install Information';
+$lang['php_information'] = 'Informationer om PHP';
+$lang['cms_install_information'] = 'Informationer vedr&oslash;rende CMS-installationen';
 $lang['cms_version'] = 'CMS Version';
 $lang['systeminfo_copy_paste'] = 'Kopi&eacute;r venligst denne markerede tekst ind i dit forum-indl&aelig;g';
 $lang['help_systeminformation'] = 'Informationen vist heruder er samlet fra flere forskellige steder og opsummeret her s&aring; du nemt kan finde de oplysninger der skal til at af diagnosticere et problem eller f&aring; hj&aelig;lp til din CMS Made Simple installation';
-$lang['systeminfo'] = 'System Information';
+$lang['systeminfo'] = 'Informationer vedr&oslash;rende systemet';
 $lang['systeminfodescription'] = 'Viser forskellig information der kan hj&aelig;lpe til at diagnosticere problemer';
 $lang['error'] = 'Fejl';
 $lang['new_version_available'] = '<em>Bem&aelig;rk:</em> En nyere version af CMS Made Simple er tilg&aelig;ngelig. G&oslash;r venligst din administrator opm&aelig;rksom p&aring; dette.';
@@ -156,7 +166,7 @@ $lang['cantremovefiles'] = 'Problemer ved sletning af filer (rettigheder?)';
 $lang['create'] = 'Opret';
 $lang['database'] = 'Database';
 $lang['databaseprefix'] = 'Database pr&aelig;fiks';
-$lang['databasetype'] = 'Database Type';
+$lang['databasetype'] = 'Databasetype';
 $lang['date'] = 'Dato';
 $lang['default'] = 'Standard';
 $lang['delete'] = 'Slet';
@@ -254,97 +264,95 @@ $lang['test_may_not_exist'] = 'Denne fil eksisterer muligvid ikke endnu. Hvis de
 $lang['could_not_retrieve_a_value'] = 'Kunne ikke finde en v&aelig;rdi... forts&aelig;tter.';
 $lang['displaying_the_value_originally'] = '<br />Viser v&aelig;rdien der tidligere er sat i config filen (dette er ikke n&oslash;dvendigvis korrekt).';
 $lang['test_check_xml_func'] = 'Kontrollerer for grundl&aelig;ggende XML (expat) underst&oslash;ttelse';
-$lang['test_check_xml_failed'] = 'XML underst&oslash;ttelse er ikke kompileret ind i din php installation. Du kan stadig benytte systemet, men vil ikke kunne benytte modul h&aring;ndteringen til at installere nyt moduler direkte fra fjernserveren.';
-$lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
-$lang['test_remote_url'] = 'Test for remote URL';
-$lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
-$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
-$lang['remote_connection_timeout'] = 'Connection Timed Out!';
-$lang['search_string_find'] = 'Connection ok!';
-$lang['connection_failed'] = 'Connection failed!';
-$lang['remote_response_ok'] = 'Remote response: ok!';
-$lang['remote_response_404'] = 'Remote response: not found!';
-$lang['remote_response_error'] = 'Remote response: error!';
-$lang['test_check_file_upload'] = 'Checking file uploads';
-$lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
-$lang['test_check_memory'] = 'Checking PHP memory limit';
-$lang['test_check_memory_failed'] = 'You may not have enough memory to run CMSMS correctly, or with all of your desired addons. If possible, you should try to get your system admin to raise this value. Proceed with caution.';
-$lang['test_check_time_limit'] = 'Checking PHP time limit in second';
-$lang['test_check_time_limit_failed'] = 'Number of seconds a script is allowed to run. If this is reached, the script returns a fatal error.';
-$lang['test_check_post_max'] = 'Checking max post size';
-$lang['test_check_post_max_failed'] = 'You will probably not be able to submit (larger) data. Please be aware of this restriction.';
-$lang['test_check_upload_max'] = 'Checking max upload file size';
-$lang['test_check_upload_max_failed'] = 'You will probably not be able to upload (larger) files using the included file management functions. Please be aware of this restriction.';
-$lang['test_check_writable'] = 'Checking if %s is writable';
-$lang['test_check_upload_failed'] = 'The uploads folder is not writable. You can still install the system, but you will not be able to upload files via the Admin Panel.';
-$lang['test_check_images_failed'] = 'The images folder is not writable. You can still install the system, but you will not be able to upload and use images via the Admin Panel.';
-$lang['test_check_modules_failed'] = 'The modules folder is not writable. You can still install the system, but you will not be able to upload modules via the Admin Panel.';
-$lang['test_check_file_get_contents'] = 'Checking for file_get_contents';
-$lang['test_check_file_get_contents_failed'] = 'The file_get_contents function was added in PHP 4.3 and although a workaround has been added that should allow most functionality that uses this function to work properly in PHP 4.2, it may be advisable to upgrade to PHP 4.3 or greater.';
-$lang['test_check_session_save_path'] = 'Checking if session.save_path is writable';
-$lang['test_empty_session_save_path'] = 'Your session.save_path is empty. PHP will use the temporary directory of your OS. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
-$lang['test_check_session_save_path_failed'] = 'Your session.save_path is &quot;%s&quot;. Not having this as writable may make logins to the Admin Panel not work. You may want to look into making this path writable if you have trouble logging into the Admin Panel. This test may fail if safe_mode is enabled (see below).';
-$lang['test_check_ini_set'] = 'Checking if ini_set works';
-$lang['test_check_ini_set_failed'] = 'Although the ability to override php ini settings is not mandatory, some addon (optional) functionality uses ini_set to extend timeouts, and allow uploading of larger files, etc. You may have difficulty with some addon functionality without this capability. This test may fail if safe_mode is enabled (see below).';
-$lang['install_admin_header'] = 'Admin Account Information';
-$lang['install_admin_info'] = 'Select the username, password and email address for your admin account. Please make sure you record this password somewhere, as there will be no other way to login to your CMS Made Simple admin system without it.';
-$lang['install_admin_email'] = 'E-mail Address';
-$lang['install_admin_email_info'] = 'E-Mail Account Information';
-$lang['install_admin_email_note'] = '<strong>Note:</strong> This function uses the php&#039;s mail function. If you don&#039;t receive this email, it may be an indication that your server is not properly configured and that you should contact your host administrator.';
-$lang['install_admin_sitename'] = 'This is the name of your site. It will be used in various places of the default templates and can be used anywhere with the	{sitename} tag.';
-$lang['install_admin_db'] = 'Database Information';
-$lang['install_admin_db_info'] = '<p>Make sure you have created your database and granted full privileges to a user to use that database.</p>
-<p>For MySQL, use the following:</p>
-<p>Log in to mysql from a console and run the following commands:</p>
+$lang['test_allow_url_fopen_failed'] = 'N&aring;r allow url fopen er deaktiveret, s&aring; har du ikke adgang til filer m.v. via URL hverken via ftp - eller http-protokollen.';
+$lang['test_remote_url'] = 'Unders&oslash;ger remote URL';
+$lang['test_remote_url_failed'] = 'Du vil sandsynligvis ikke kunne &aring;bne en fil, som ligger p&aring; en anden webserver.';
+$lang['connection_error'] = 'Udg&aring;ende HTTP-forbindelser ser ikke ud til at virke! Er der en firewall eller en eller anden adgangskontrolliste til eksterne forbindelser? Det her vil medf&oslash;re, at Modulh&aring;ndteringen, og sandsynligvis ogs&aring; andre funktioner, ikke fungerer.';
+$lang['remote_connection_timeout'] = 'Forbindelsen l&oslash;b ind i en time out!';
+$lang['search_string_find'] = 'Forbindelse ok!';
+$lang['connection_failed'] = 'Forbindelse mislykkedes!';
+$lang['remote_response_ok'] = 'Svar fra fjernserver: ok!';
+$lang['remote_response_404'] = 'Svar fra fjernserver: ikke fundet!';
+$lang['remote_response_error'] = 'Svar fra fjernserver: fejl!';
+$lang['test_check_file_upload'] = 'Unders&oslash;ger uploadede filer';
+$lang['test_check_file_failed'] = 'N&aring;r upload af filer er deaktiveret, vil du ikke kunne bruge nogen af de faciliteter til upload af filer, som f&oslash;lger med i CMS Made Simple. Hvis det er muligt, s&aring; b&oslash;r denne restriktion fjernes af systemet administrator, s&aring; alle systemets filh&aring;ndteringsfunktioner kan anvendes S&aring; er du advaret, hvis du forts&aelig;tter.';
+$lang['test_check_memory'] = 'Unders&oslash;ger PHP&#039;s hukommelsesgr&aelig;nse';
+$lang['test_check_memory_failed'] = 'Der er muligvis ikke hukommelse nok til, at CMSMS kan k&oslash;re korrekt eller med alle de udvidelser, du m&aring;tte &oslash;nske at anvende. Hvis det er muligt, s&aring; b&oslash;r du pr&oslash;ve at f&aring; systemets administrator til at forh&oslash;je denne v&aelig;rdi. V&aelig;r opm&aelig;rksom p&aring; dette, hvis du forts&aelig;tter.';
+$lang['test_check_time_limit'] = 'Unders&oslash;ger PHP&#039;s udl&oslash;bstidsgr&aelig;nse i sekunder';
+$lang['test_check_time_limit_failed'] = 'Antallet af sekunder, som et script m&aring; v&aelig;re om at k&oslash;re. Hvis denne gr&aelig;nse n&aring;s, vil scriptet returnere en fejl og d&oslash;.';
+$lang['test_check_post_max'] = 'Unders&oslash;ger maksimal sendest&oslash;rrelse';
+$lang['test_check_post_max_failed'] = 'Du vil sandsynligvis ikke kunne sende (st&oslash;rre m&aelig;ngder) data. V&aelig;r venligst opm&aelig;rksom p&aring; denne begr&aelig;nsning.';
+$lang['test_check_upload_max'] = 'Unders&oslash;ger maksimal filst&oslash;rrelse for uploads';
+$lang['test_check_upload_max_failed'] = 'Du vil sandsynligvis ikke kunne uploade (st&oslash;rre) filer med de medf&oslash;lgende funktioner til h&aring;ndtering af filer. V&aelig;r venligst opm&aelig;rksom p&aring; denne begr&aelig;nsning.';
+$lang['test_check_writable'] = 'Unders&oslash;ger om der kan skrives til %s';
+$lang['test_check_upload_failed'] = 'Der kan ikke skrives til mappen uploads. Du kan godt bruge systemet alligevel, men du vil ikke kunne uploade filer via administrationspanelet.';
+$lang['test_check_images_failed'] = 'Der kan ikke skrives til mappen images. Du kan godt bruge systemet alligevel, men du vil ikke kunne uploade og bruge billeder via administrationspanelet.';
+$lang['test_check_modules_failed'] = 'Der kan ikke skrives til mappen modules. YDu kan godt bruge systemet alligevel, men du vil ikke kunne uploade moduler via administrationspanelet.';
+$lang['test_check_file_get_contents'] = 'Unders&oslash;ger om file_get_contents er til stede';
+$lang['test_check_file_get_contents_failed'] = 'Funktionen file_get_contents blev tilf&oslash;jet i PHP 4.3 og selvom der er lavet en m&aring;de at komme om ved det p&aring;, s&aring;ledes at det meste af den funktionalitet, som bruger denne funktion, kan k&oslash;re gnidningsl&oslash;st i PHP 4.2, s&aring; kan det anbefales at opgradere til PHP 4.3 eller derover.';
+$lang['test_check_session_save_path'] = 'Unders&oslash;ger om der kan skrives til session.save_path';
+$lang['test_empty_session_save_path'] = 'Din session.save_path er tom. PHP vil bruge dit operativsystems midlertidige mappe. Hvis du f&aring;r problemer med sessions og ini_set virker, s&aring; kan du pr&oslash;ve at aktivere session cookies ved at tilf&oslash;je: ini_set(&#039;session.use_only_cookies&#039;, 1);  i toppen af filen include.php';
+$lang['test_check_session_save_path_failed'] = 'session.save_path er &quot;%s&quot;. N&aring;r stien er skrivebeskyttet, s&aring; kan der ske det, at det bliver umuligt at logge ind i administrationspanelet. Du b&oslash;r fjerne skrivebeskyttelsen, hvis du f&aring;r problemer med at logge ind i administrationspanelet. Denne test kan fejle, s&aring;fremt safe_mode er aktiveret (se nedenfor).';
+$lang['test_check_ini_set'] = 'Unders&oslash;ger om ini_set virker';
+$lang['test_check_ini_set_failed'] = 'Man <strong>skal</strong> ikke n&oslash;dvendigvis kunne tilsides&aelig;tte indstillingerne i php.ini, men der er nogle (ikke obligatoriske) udvidelser og tilf&oslash;jelser, hvis funktionalitet afh&aelig;nger af, at de kan bruge ini-set til at forl&aelig;nge k&oslash;rselstiden og til at tillade upload af st&oslash;rre filer m.v. Du kan f&aring; problemer med nogle udvidelser uden denne mulighed. Testen kan mislykkes, hvis safe_mode er aktiveret (se nedenfor)';
+$lang['install_admin_header'] = 'Oplysninger om administrators konto';
+$lang['install_admin_info'] = 'V&aelig;lg brugernavn, adgangskode og email adresse til din administrator-konto. Du bedes sikre dig, at du gemmer adgangskoden et eller andet sted, da det ikke er muligt at logge ind i CMS Made Simple administrationssystemet uden den.';
+$lang['install_admin_email'] = 'Email adresse';
+$lang['install_admin_email_info'] = 'Send en email med konto-oplysningerne';
+$lang['install_admin_email_note'] = '<strong>Bem&aelig;rk:</strong> Denne funktion anvender php&#039;s mail function. Hvis ikke du modtager denne email, s&aring; kan det tyde p&aring;, at din server ikke er blevet ordentligt konfigureret og at du b&oslash;r kontakte din host administrator.';
+$lang['install_admin_sitename'] = 'Dette er navnet p&aring; din hjemmeside. Det vil blive brugt forskellige steder i standardskabelonerne og kan inds&aelig;ttes hvor som helst med koden {sitename}.';
+$lang['install_admin_db'] = 'Databaseinformation';
+$lang['install_admin_db_info'] = '<p>V&aelig;r sikker p&aring;, at du har oprettet din database og har givet en bruger alle privilegeier, s&aring; denne bruger kan anvende den database.</p>
+<p>Hvad ang&aring;r MySQL, s&aring; g&oslash;r f&oslash;lgende:</p>
+<p>Log ind i mysql via en konsol og k&oslash;r f&oslash;lgende kommandoer:</p>
 <ol>
-<li>create database cms; (use whatever name you want here but make sure to remember it, you&#039;ll need to enter it on this page)</li>
+<li>create database cms; (brug et hvilket som helst navn, du &oslash;nsker, men v&aelig;r sikker p&aring;, du kan huske det, for du skal sidenhen indtaste det p&aring; denne side)</li>
 <li>grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;</li>
 </ol>';
 $lang['install_admin_follow'] = 'Udfyld venligst f&oslash;lgende felter';
-$lang['install_admin_db_type'] = 'Database Type';
-$lang['install_admin_no_db'] = 'No valid database drivers appear to be compiled into your PHP install. Please confirm that you have mysql, mysqli, and/or postgres7 support installed, and try again.';
-$lang['install_admin_db_host'] = 'Database host adresse';
-$lang['install_admin_db_name'] = 'Database navn';
+$lang['install_admin_db_type'] = 'Databasetype';
+$lang['install_admin_no_db'] = 'Det ser ikke ud til, at der er nogen gyldige database-drivers til din installation af PHP. Unders&oslash;g venligst, at der nu ogs&aring; <strong>er</strong> blevet installeret underst&oslash;ttelse af mysql, mysqli, og/eller postgres7 og pr&oslash;v s&aring; igen.';
+$lang['install_admin_db_host'] = 'Databasens v&aelig;rtsadresse';
+$lang['install_admin_db_name'] = 'Databasenavn';
 $lang['install_admin_db_create'] = 'Opret tabeller (advarsel: sletter eksisterende data)';
-$lang['install_admin_db_prefix'] = 'Tabel pr&aelig;fiks';
-$lang['install_admin_db_sample'] = 'Install&eacute;r eksempel indhold og skabeloner';
+$lang['install_admin_db_prefix'] = 'Tabel-pr&aelig;fiks';
+$lang['install_admin_db_sample'] = 'Install&eacute;r eksempel p&aring; indhold og skabeloner';
 $lang['retry'] = 'Fors&oslash;g igen';
-$lang['install_admin_db_create_seq'] = 'Creating %s table sequence...';
-$lang['install_admin_importing'] = 'Importing sample data...';
-$lang['invalid_query'] = 'Invalid query: %s';
-$lang['install_creating_table'] = '<p>Creating %s table... [%s]</p>';
-$lang['install_creating_index'] = '<p>Creating index in %s table... [%s]</p>';
+$lang['install_admin_db_create_seq'] = 'Opretter %s tabel sekvens...';
+$lang['install_admin_importing'] = 'Importerer eksempeldata...';
+$lang['invalid_query'] = 'Ugyldig foresp&oslash;rgsel: %s';
+$lang['install_creating_table'] = '<p>Opretter %s tabel... [%s]</p>';
+$lang['install_creating_index'] = '<p>Opretter indeks i %s tabel... [%s]</p>';
 $lang['done'] = 'f&aelig;rdig';
 $lang['failed'] = 'fejlede';
-$lang['install_admin_error_schema'] = 'Error in retrieve SQL schema';
-$lang['install_admin_set_account'] = 'Setting admin account information...';
+$lang['install_admin_error_schema'] = 'Fejl: SQL schema kunne ikke hentes';
+$lang['install_admin_set_account'] = 'Gemmer administrators konto-oplysninger...';
 $lang['install_admin_set_sitename'] = 'Gemmer sidens navn...';
 $lang['install_admin_setup'] = 'Now let&#039;s continue to setup your configuration file, we already have most of the stuff we need. Chances are you can leave all these values alone, so when you are ready, click Continue.';
 $lang['install_admin_docroot'] = 'CMS dokument-rodmappe (som set fra webserveren.)';
-$lang['install_admin_docroot_path'] = 'Sti til dokument-rodmappe';
-$lang['install_admin_querystring'] = 'Query string (leave this alone unless you have trouble, then edit config.php by hand)';
-$lang['invalid_querys'] = '<b>WARNING<b/>: Invalid queries on your DB!';
-$lang['install_admin_sitedown'] = 'Error: Could not remove the tmp/cache/SITEDOWN file. Please remove manually.';
+$lang['install_admin_docroot_path'] = 'Sti til serverens rodmappe';
+$lang['install_admin_querystring'] = 'Query string (lad denne v&aelig;rdi v&aelig;re som den er, med mindre du l&oslash;ber ind i problemer. I s&aring; fald skal du redigere config.php manuelt)';
+$lang['invalid_querys'] = '<b>ADVARSEL<b/>: Der findes ugyldige foresp&oslash;rgsler til din database!';
+$lang['install_admin_sitedown'] = 'Fejl: Kunne ikke fjerne filen tmp/cache/SITEDOWN. Slet den venligst manuelt.';
 $lang['install_admin_update_hierarchy'] = 'Opdaterer hierakiske positioner..';
 $lang['install_admin_set_core_event'] = 'Ops&aelig;tter kerne h&aelig;ndelser...';
 $lang['install_admin_install_modules'] = 'Installerer moduler...';
 $lang['install_admin_index_search'] = 'Indekserer s&oslash;gning...';
 $lang['install_admin_clear_cache'] = 'Nulstiller sidens cache...';
-$lang['install_admin_emailing'] = 'Sender admin konto information via email...';
+$lang['install_admin_emailing'] = 'Sender admin konto-oplysninger via email...';
 $lang['install_admin_congratulations'] = 'Tillykke, du har nu sat systemet om - her er dit';
 $lang['could_not_connect_db'] = 'Kunne ikke forbinde til databasen. Kontroll&eacute;r at brugernavn og kodeord er korrekte, og at denne bruger har adgang til den angivne database';
 $lang['cannot_write_config'] = 'Fejl: Kan ikke skrive til %s.';
-$lang['email_accountinfo_subject'] = 'CMS Made Simple Administrations Konto Information';
+$lang['email_accountinfo_subject'] = 'CMS Made Simple administrators konto-oplysninger';
 $lang['email_accountinfo_message'] = 'Tak fordi du installerede CMS Made Simple
 
-Dette er dine nye konto oplysninger:
+Dette er dine nye konto-oplysninger:
 brugernavn: %s
 kodeord: %s
 
-Log ind i site administrationen her: %s';
-$lang['utma'] = '156861353.868490754.1298370706.1299501521.1299526853.9';
-$lang['utmz'] = '156861353.1299501521.8.3.utmcsr=twitter.com|utmccn=(referral)|utmcmd=referral|utmcct=/Bovelett';
-$lang['qca'] = 'P0-392249128-1298370706225';
+Log ind i administrationspanelet her: %s';
+$lang['utma'] = '156861353.2012825315.1357380883.1357390139.1357393703.4';
+$lang['utmz'] = '156861353.1357380883.1.1.utmccn=(referral)|utmcsr=docs.cmsmadesimple.org|utmcct=/modules/add-ons|utmcmd=referral';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1299526853';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
