@@ -10,7 +10,7 @@ $lang['ip_addr'] = 'Direcci&oacute;n IP';
 $lang['install_admin_pwsalt_note'] = 'Si elige permitir sal en contrase&ntilde;as, no habr&aacute; ninguna forma de resetear las contrase&ntilde;as de administraci&oacute;n perdidas excepto a trav&eacute;s de la funcionalidad de contrase&ntilde;as perdidas. Es cr&iacute;tico que asocie una direcci&oacute;n de email con cada cuenta administrativa.';
 $lang['admin_salt'] = 'Sal en Contrase&ntilde;as de Administrador';
 $lang['setup_flat_urls'] = 'URLs simples han sido ajustadas';
-$lang['install_timezone'] = 'Algunos servidores que ejecutan php 5.3 no tienen configurada correctamente la zona horaria. Por favor, antes de continuar, seleccione la zona horaria adecuada en la siguiente lista. Si esto no es necesario en su servidor, entonces puede seleccionar &quot;Ninguno&quot;. <strong>Nota:</strong> Selecciona la zona horaria de su servidor. Esto no es una configuraci&oacute;n de visualizaci&oacute;n sino que se usa en los c&aacute;lculos de fechas. Puede cambiar esta configuraci&oacute;n despu&eacute;s de la instalaci&oacute;n modificando el archivo config.php.';
+$lang['install_timezone2'] = 'Seleccione su zona horaria para esta instalaci&oacute;n.  Esta zona horaria ser&aacute; usada cuando se ingresen valores de fecha/reloj en el sistema<br/><br/>CMSMS ha intentado escoger un valor automaticamente basado en la ubicaci&oacute;n actual del servidor, sin embargo puede que este sea incorrecto. <br/><br/><strong style=&quot;color: red;&quot;>Nota:</strong> Este es un cambio en el comportamiento de versiones anteriores de CMSMS. Ademas, puede que necesite habilitar el valor de configuraci&oacute;n de &#039;set_db_timezone&#039; si su servidor est&aacute; en una zona horaria distinta de la de sus usuarios.';
 $lang['timezone'] = 'Zona horaria';
 $lang['none'] = 'Ninguno';
 $lang['test_error_estrict'] = 'Comprobando error_reporting para confirmar que E_STRICT est&aacute; desactivado';
@@ -90,11 +90,11 @@ $lang['test_check_magic_quotes_gpc'] = '&quot;Comillas magicas&quot;(Magic quote
 $lang['test_check_magic_quotes_gpc_failed'] = 'Cuando &quot;magic_quotes&quot; est&aacute; activo, todas las comillas singulares, dobles y la barra diagonal son escapadas con una barra diagonal invertida (\) automatica,ente. Esto puede causar ciertos problemas en CMS.';
 $lang['test_check_magic_quotes_runtime'] = '&quot;Comillas magicas&quot;(Magic quotes) en tiempo de ejecuci&oacute;n';
 $lang['test_check_magic_quotes_runtime_failed'] = 'Cuando &quot;magic_quotes&quot; est&aacute; activo, muchas funciones que devuelven informaci&oacute;n de cualquier fuente externa, incluyendo bases de datos y archivos de texto, tendran las comillas escapadas con una barra diagonal invertida (\). Esto causar&aacute; problemas con CMS Made Simple.';
-$lang['install_admin_checksum'] = 'Revise su instalaci&oacute;n';
-$lang['upgrade_admin_checksum'] = 'Revise su actualizaci&oacute;n de sistema';
-$lang['checksum'] = 'Prueba con archivo de revisi&oacute;n';
-$lang['checksum_file'] = 'Archivo de revisi&oacute;n';
-$lang['install_test_checksum'] = 'Se puede validar la integridad de los archivos del CMS, comparando con el archivo de suma de verificaci&oacute;n (checksum). Esto puede ayudar a localizar problemas con archivos que no han sido subidos correctamente.';
+$lang['install_admin_checksum'] = 'Comprueba la instalaci&oacute;n';
+$lang['upgrade_admin_checksum'] = 'Revise la actualizaci&oacute;n del sistema';
+$lang['checksum'] = 'Comprobaci&oacute;n de la validez de los archivos';
+$lang['checksum_file'] = 'Archivo de comprobaci&oacute;n';
+$lang['install_test_checksum'] = 'Compruebe la integridad de los archivos CMS compar&aacute;ndolos con el archivo de suma de verificaci&oacute;n (checksum) original. Es &uacute;til para saber si tiene problemas con las subidas de los archivos.';
 $lang['checksum_passed'] = '&iexcl;Todas las sumas de verificaci&oacute;n concuerdan!';
 $lang['checksum_failed'] = 'Las sumas de verificaci&oacute;n concuerdan pero hay errores. Ver &#039;ayuda&#039; para mas informaci&oacute;n.';
 $lang['test_check_open_basedir'] = 'Revisar &#039;PHP Open Basedir&#039;';
@@ -109,7 +109,7 @@ $lang['cms_site'] = 'Sitio CMS';
 $lang['or_greater'] = 'O mayor';
 $lang['sitename'] = 'Nombre del sitio';
 $lang['warning_safe_mode'] = '<strong><em>ADVERTENCIA:</em></strong> El modo &#039;PHP Safe&#039; esta habilitado. Esto puede causar dificultades con archivos subidos a traves de la interfaz web de explorador de archivos, incluyendo im&aacute;genes, temas y paquetes XML de m&oacute;dulos. Se recomienda que contacte con el administrador del sitio para saber c&oacute;mo deshabilitar el modo &#039;PHP Safe&#039;.';
-$lang['test'] = 'Prueba';
+$lang['test'] = 'Comprobar';
 $lang['results'] = 'Resultados';
 $lang['untested'] = 'Sin probar';
 $lang['owner'] = 'Propietario';
@@ -204,8 +204,8 @@ $lang['username'] = 'Nombre de usuario';
 $lang['usernameincorrect'] = 'Nombre de usuario o contrase&ntilde;a incorrectos';
 $lang['version'] = 'Versi&oacute;n';
 $lang['install_title'] = 'Instalaci&oacute;n CMS Made Simple (paso %s)';
-$lang['install_system'] = 'Sistema de Instalaci&oacute;n';
-$lang['install_thanks'] = '&iexcl;Gracias por instalar CMS Made Simple!';
+$lang['install_system'] = 'Asistente de Instalaci&oacute;n';
+$lang['install_thanks'] = 'Gracias por instalar CMS Made Simple';
 $lang['upgrade_title'] = 'Actualizaci&oacute;n de CMS Made Simple (paso %s)';
 $lang['upgrade_system'] = 'Actualizar sistema';
 $lang['upgrade_thanks'] = 'Gracias por actualizar CMS Made Simple a versi&oacute;n';
@@ -351,8 +351,8 @@ usuario: %s
 clave: %s
 
 Acceda al panel administrativo aqu&iacute;: %s';
-$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
-$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1444641896.1378156587.1378156587.1378156587.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1378156587.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
