@@ -1,6 +1,8 @@
 <?php
+$lang['error_timedifference'] = 'Le syst&egrave;me de fichiers o&ugrave; CMSMS est install&eacute; a une date significativement diff&eacute;rente de celle r&eacute;elle du serveur';
+$lang['test_timedifference'] = 'Test du syst&egrave;me de fichiers si diff&eacute;rent du serveur';
 $lang['detected'] = 'D&eacute;tect&eacute;';
-$lang['docroot_leaveblank'] = 'Laissez ce champ vide pour utiliser le syst&egrave;me par d&eacute;faut';
+$lang['docroot_leaveblank'] = 'Laissez ce champ vide pour utiliser la valeur par d&eacute;faut';
 $lang['test_xmlreader_class'] = 'V&eacute;rification si la classe XMLReader existe';
 $lang['test_xmlreader_failed'] = 'La classe XMLReader n&#039;est pas activ&eacute;e dans votre installation de PHP. Vous pouvez toujours utiliser le syst&egrave;me, mais ne serez pas en mesure d&#039;utiliser les fonctions du Gestionnaire de Modules.';
 $lang['test_check_xml_failed'] = 'le support XML n&#039;est pas compil&eacute; dans votre installation PHP. Vous pouvez toujours utiliser le syst&egrave;me, mais ne serez pas en mesure d&#039;utiliser les fonctions du Gestionnaire de Modules.';
@@ -10,7 +12,7 @@ $lang['ip_addr'] = 'Adresse IP';
 $lang['install_admin_pwsalt_note'] = 'Si vous choisissez d&#039;activer &quot;Mots de passe Admin s&eacute;curis&eacute;s&quot;, il n&#039;y a absolument aucun moyen de r&eacute;initialiser les mots de passe Admin perdus autrement que par la fonctionnalit&eacute; de r&eacute;cup&eacute;ration du mot de passe sur la page de connexion administration. Il est essentiel que vous associez donc une adresse email &agrave; chaque compte Admin pour recevoir par courrier &eacute;lectronique ce nouveau mot de passe.';
 $lang['admin_salt'] = 'Mots&nbsp;de&nbsp;passe&nbsp;Admin&nbsp;s&eacute;curis&eacute;s';
 $lang['setup_flat_urls'] = 'URL courtes en service';
-$lang['install_timezone'] = 'Certains serveurs utilisant PHP 5.3 ne sont pas configur&eacute;s sur le bon fuseau horaire. Merci de s&eacute;lectionner le fuseau horaire appropri&eacute; dans la liste. Si ce n&#039;est pas n&eacute;cessaire sur votre serveur, vous pouvez s&eacute;lectionner &quot;Aucun&quot;. <strong>Note :</strong> Choisissez le fuseau horaire de votre serveur, ce n&#039;est pas un param&egrave;tre d&#039;affichage mais il sera utilis&eacute; dans le calcul des dates. Vous pouvez toujours modifier ce param&egrave;tre ult&eacute;rieurement dans le fichier config.php.';
+$lang['install_timezone2'] = 'Merci de choisir le fuseau horaire pour votre installation. Cette valeur de fuseau horaire sera utilis&eacute; pour pour les calculs des dates et heures.<br/>CMSMS a tent&eacute; de choisir un fuseau horaire par d&eacute;faut pour vous en fonction de votre serveur actuel, mais cela peut ne pas &ecirc;tre correct. <br/><strong style=&quot;color: red;&quot;>Note :</strong> Il s&#039;agit d&#039;un changement de comportement par rapport aux versions pr&eacute;c&eacute;dentes de CMSMS. En outre, vous devrez peut-&ecirc;tre activer la valeur de config set_db_timezone si votre serveur est dans un autre fuseau horaire que celui contenu dans la base d&#039;utilisateurs primaire';
 $lang['timezone'] = 'Fuseau horaire';
 $lang['none'] = 'Aucun';
 $lang['test_error_estrict'] = 'Test error_reporting pour assurer que E_STRICT est d&eacute;sactiv&eacute;';
@@ -209,7 +211,7 @@ $lang['install_thanks'] = 'Merci pour l&#039;installation de CMS Made Simple&tra
 $lang['upgrade_title'] = 'CMS Made Simple&trade; mise &agrave; niveau (&eacute;tape %s)';
 $lang['upgrade_system'] = 'Mise &agrave; niveau du syst&egrave;me';
 $lang['upgrade_thanks'] = 'Merci pour la mise &agrave; niveau de CMS Made Simple&trade; vers';
-$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Installation Troubleshooting</a> de la page &quot;Official Documentation&quot; de CMS Made Simple&trade;.';
+$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Requirements</a> de la page en anglais &quot;Official Documentation&quot; de CMS Made Simple&trade;.';
 $lang['install_checking'] = 'V&eacute;rification des permissions et de la configuration PHP';
 $lang['install_test'] = 'Test&nbsp;';
 $lang['install_result'] = 'R&eacute;sultat';
@@ -339,7 +341,7 @@ $lang['install_admin_update_hierarchy'] = 'Mise &agrave; jour de la hi&eacute;ra
 $lang['install_admin_set_core_event'] = 'Configuration du noyau CMS Made Simple ...&nbsp;';
 $lang['install_admin_install_modules'] = 'Installation des modules ...&nbsp;';
 $lang['install_admin_index_search'] = 'Recherche de l&#039;index...&nbsp;';
-$lang['install_admin_clear_cache'] = 'Effacement du cache (si besoin) ...&nbsp;';
+$lang['install_admin_clear_cache'] = 'Effacement du cache ...&nbsp;';
 $lang['install_admin_emailing'] = 'Email d&#039;information sur le compte Administrateur envoy&eacute; ...&nbsp;';
 $lang['install_admin_congratulations'] = 'Merci pour l&#039;installation de CMS Made Simple, la configuration est termin&eacute;e - Se connecter sur&nbsp; ';
 $lang['could_not_connect_db'] = 'Impossible de se connecter &agrave; la base de donn&eacute;es. V&eacute;rifiez que le nom d&#039;utilisateur et/ou le mot de passe sont correct, et que les acc&egrave;s sont autoris&eacute;s pour l&#039;utilisateur.';
@@ -352,9 +354,8 @@ Nom utilisateur : %s
 Mot de passe : %s
 
 Se connecter &agrave; l&#039;administration : %s';
-$lang['qca'] = 'P0-1532147203-1273233257739';
-$lang['utma'] = '156861353.2080384792.1340297872.1340297872.1340297872.1';
+$lang['utma'] = '156861353.1805346427.1378658323.1378658323.1378658323.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1340297872.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1378658323.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
