@@ -1,6 +1,18 @@
 <?php
+$lang['error_timedifference'] = 'Il file system in cui &egrave; installato CMSMS ha un tempo significativamente diverso rispetto al tempo effettivo del server';
+$lang['test_timedifference'] = 'Verifico se l&#039;ora del filesystem &egrave; diversa dall&#039;ora del server';
+$lang['detected'] = 'Individuato';
+$lang['docroot_leaveblank'] = 'Lasciate questo campo vuoto per utilizzare i valori predefiniti del sistema';
+$lang['test_xmlreader_class'] = 'Verifico l&#039;esistenza della classe XMLRreader';
+$lang['test_xmlreader_failed'] = 'La classe XMLReader non &egrave; abilitata nella vostra installazione php.  Potete ancora utilizzare il sistema ma non sarete in grado di utilizzare alcuna delle funzioni di installazione remota dei moduli.';
+$lang['test_check_xml_failed'] = 'Il supporto XML non &egrave; compilato nella vostra installazione PHP. Potete ancora utilizzare il sistema, ma non riuscirete a sfruttare alcuna delle funzionalit&agrave; di installazione remota dei moduli.';
+$lang['installed_module'] = 'Modulo Installato';
+$lang['automatedtask_success'] = 'Procedura Automatizzata Eseguita';
+$lang['ip_addr'] = 'indirizzo IP';
+$lang['install_admin_pwsalt_note'] = 'Se decidete di abilitare l&#039;alterazione della password, non ci sar&agrave; alcun modo di recuperare passowrd di amministrazione smarrite se non tramite la funzionalit&agrave; smarrimento password.  E&#039; vitale associare un indirizzo email ad ogni utente amministratore';
+$lang['admin_salt'] = 'Altera password';
 $lang['setup_flat_urls'] = 'Gli URL abbreviati sono impostati';
-$lang['install_timezone'] = 'Alcuni server che eseguono php 5.3 hanno un fuso orario impostato non correttamente.  Selezionate il fuso orario appropriato dalla lista precedente.  Se non &egrave; necessario nel vostro server, potete selezionare &quot;Nessuno&quot;, potete modificare questa impostazione nel file config.php anche in seguito.';
+$lang['install_timezone2'] = 'Please select the timezone for your installation.  This timezone value will be used for entering times into the system and for date and time calculations.<br/><br/>CMSMS has attempted to choose an intelligent default for you based on your servers current location, however this may not be correct.<br/><br/><strong style=&quot;color: red;&quot;>Note:</strong> This is a change in behavior from previous versions of CMSMS. Also, you may need to enable the set_db_timezone config value if your server is in a different timezone than your primary user base.';
 $lang['timezone'] = 'Fuso Orario';
 $lang['none'] = 'Nessuno';
 $lang['test_error_estrict'] = 'Controllo error_reporting per accertare che E_STRICT sia disabilitato';
@@ -199,7 +211,7 @@ $lang['install_thanks'] = 'Grazie per avere installato CMS Made Simple';
 $lang['upgrade_title'] = 'Aggiornamento di CMS Made Simple (passo %s)';
 $lang['upgrade_system'] = 'Sistema di aggiornamento';
 $lang['upgrade_thanks'] = 'Grazie per avere aggiornato CMS Made Simple alla versione';
-$lang['install_please_read'] = 'Vi invitiamo a leggere la pagina sulle <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problematiche di Installazione</a> nella documentazione di CMS Made Simple Documentation Wiki.';
+$lang['install_please_read'] = 'Vi invitiamo a leggere la pagina sulle <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Problematiche di Installazione</a> nella documentazione di CMS Made Simple Documentation Wiki.';
 $lang['install_checking'] = 'Controllo dei permessi e delle impostazioni PHP';
 $lang['install_test'] = 'Test ';
 $lang['install_result'] = 'Risultato';
@@ -254,7 +266,6 @@ $lang['test_may_not_exist'] = 'Questo file potrebbe non esistere ancora. Se &egr
 $lang['could_not_retrieve_a_value'] = 'Non posso recuperare un valore.... passo avanti.';
 $lang['displaying_the_value_originally'] = '<br />Visualizzo il valore originariamente impostato nel file di configurazione (potrebbe essere non essere accurato).';
 $lang['test_check_xml_func'] = 'Controllo per un supporto di base XML (expat)';
-$lang['test_check_xml_failed'] = 'Il supporto XML non &egrave; compilato nella vostra installazione di PHP. Potete ancora utilizzare il sistema, ma non riuscirete a sfruttare alcuna delle funzionalit&agrave; di installazione remota dei moduli.';
 $lang['test_allow_url_fopen_failed'] = 'Quando allow url fopen &egrave; disabilitato, non riuscirete ad accedere agli oggetti URL come i file remoti usando il protocollo ftp o http.';
 $lang['test_remote_url'] = 'Test per indirizzi remoti';
 $lang['test_remote_url_failed'] = 'Probabilmente non potrete aprire file su un server web remoto.';
@@ -342,9 +353,8 @@ nome utente: %s
 password: %s
 
 Potete accedere all&#039;area di amministrazione da qui: %s';
-$lang['utma'] = '156861353.974349155.1299072468.1302003201.1303465107.4';
-$lang['qca'] = 'P0-1868709163-1302003200778';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1075351023.1379535264.1379535264.1379535264.1';
+$lang['utmz'] = '156861353.1379535264.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/list_tagged/admin|utmcmd=referral';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1303465107.4.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
