@@ -1,11 +1,18 @@
 <?php
+$lang['error_timedifference'] = 'Filsystemet hvor CMSMS er installert har en signifikant forskjellig tid enn aktuell servertid';
+$lang['test_timedifference'] = 'Tester om filsystem tid er forskjellig fra server tid';
+$lang['detected'] = 'Oppdaget';
+$lang['docroot_leaveblank'] = 'La dette st&aring; blankt for &aring; benytte systemets standard';
+$lang['test_xmlreader_class'] = 'Tester om XMLReader klassen eksisterer';
+$lang['test_xmlreader_failed'] = 'XMLReader klassen er ikke aktivert i din php installasjon. Du kan fortsatt benytte systemet, men vil ikke kunne benytte noen av de eksterne modulinstallasjons funksjonene.';
+$lang['test_check_xml_failed'] = 'XML st&oslash;tte er ikke kompilert inn i din php installasjon. Du kan fortsatt benytte systemet, men vil ikke kunne benytte noen av fjerninstallasjonsfunksjonene for moduler.';
 $lang['installed_module'] = 'Modul installert';
 $lang['automatedtask_success'] = 'Automatisk oppgavekj&oslash;ring vellykket';
 $lang['ip_addr'] = 'IP Adresse';
 $lang['install_admin_pwsalt_note'] = 'Velger du sl&aring; p&aring; Salt kryptering, finnes det ingen mulighet for &aring; nullstille glemte passord, utenom gjennom nullstill passord funksjonaliteten. Det er derfor kritisk at alle kontoer har en tilknyttet epostadresse.';
 $lang['admin_salt'] = 'Salt administrator passord';
 $lang['setup_flat_urls'] = 'Flate URLer er aktiverte';
-$lang['install_timezone'] = 'Noen servere som kj&oslash;rer php 5.3 har ikke satt tidssonen korrekt. Vennligst velg den korrekte tidssonen fra listen nedenfor f&oslash;r du fortsetter. Om dette ikke er n&oslash;dvendig p&aring; din server s&aring; kan du velge &quot;Ingen&quot;.  <strong>Merk:</strong> Vennligst velg din servers tidssone, dette er ikke en visningsinnstilling, men er benyttet i beregninger relatert til datoer.  Denne innstillingen kan endres etter at installasjonen ved &aring; endre i config.php filen.';
+$lang['install_timezone2'] = 'Vennligst velg tidssone for din installasjon. Denne tidssone verdi vil bli brukt til &aring; angi tider inn i systemet og for dato og klokkeslett beregninger.<br/><br/>CMSMS har fors&oslash;kt &aring; velge en intelligent standard for deg, basert p&aring; din servers n&aring;v&aelig;rende posisjon, men dette er ikke sikkert at er riktig .<br/><br/><strong style=&quot;color: red;&quot;>Merk: </strong> Dette er en endring i atferd fra tidligere versjoner av CMSMS. Det kan ogs&aring; hende at du m&aring; aktivere set_db_timezone config verdien hvis din server er i en annen tidssone enn din prim&aelig;re brukergruppe.';
 $lang['timezone'] = 'Tdssone';
 $lang['none'] = 'Ingen';
 $lang['test_error_estrict'] = 'Tester error_reporting for &aring; sikre at E_STRICT ikke er aktivert';
@@ -204,7 +211,7 @@ $lang['install_thanks'] = 'Takk for at du installerer CMS Made Simple';
 $lang['upgrade_title'] = 'CMS Made Simple Oppgradering (trinn %s)';
 $lang['upgrade_system'] = 'Oppgrader Systemet';
 $lang['upgrade_thanks'] = 'Takk for at du oppgraderer CMS Made Simple til ';
-$lang['install_please_read'] = 'Vennligst les <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting" >Installation Troubleshooting</a>- siden i CMS Made Simple Dokumentasjon Wiki.';
+$lang['install_please_read'] = 'Vennligst les <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Installation Troubleshooting</a> - siden i CMS Made Simple&amp;trade; Official Documentation.';
 $lang['install_checking'] = 'Tester rettigheter og PHP innstillinger';
 $lang['install_test'] = 'Test ';
 $lang['install_result'] = 'Resultat';
@@ -259,7 +266,6 @@ $lang['test_may_not_exist'] = 'Det er mulig denne filen ikke eksisterer enn&arin
 $lang['could_not_retrieve_a_value'] = 'Klarte ikke lese verdien.... fortsetter alikevel.';
 $lang['displaying_the_value_originally'] = '<br />Viser verdien opprinnelig satt i config filen (dette kan v&aelig;re uriktig).';
 $lang['test_check_xml_func'] = 'Tester om grunnleggende XML (expat) st&oslash;tte';
-$lang['test_check_xml_failed'] = 'XML st&oslash;tte er ikke kompilert inn i din php installasjon. Du kan fortsatt benytte systemet, men vil ikke kunne benytte noen av fjerninstallasjonsfunksjonene for moduler.';
 $lang['test_allow_url_fopen_failed'] = 'N&aring;r &#039;allow url fopen&#039; er sl&aring;tt av vil du ikke v&aelig;re i stand til &aring; n&aring; URL objekter som filer ved &aring; benytte ftp eller http protokollene.';
 $lang['test_remote_url'] = 'Test for tilgang til fjern URL';
 $lang['test_remote_url_failed'] = 'Du vil trolig ikke kunne &aring;pne en fil p&aring; en fjern-webserver.';
@@ -348,8 +354,8 @@ passord: %s
 
 Logg inn i nettstedets administrasjon her: %s';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.1064316688.1319894667.1320446839.1320502404.15';
-$lang['utmz'] = '156861353.1319894667.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353.1.10.1320502404';
+$lang['utma'] = '156861353.793561001.1377811834.1378677756.1378746753.28';
+$lang['utmz'] = '156861353.1377811834.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
