@@ -1,4 +1,6 @@
 <?php
+$lang['error_timedifference'] = 'Het bestandsysteem waar CMSMS is ge&iuml;nstalleerd heeft een andere tijd als de servertijd';
+$lang['test_timedifference'] = 'Test uitvoeren of het bestandsysteem tijd verschilt van de server tijd';
 $lang['detected'] = 'Gedetecteerd';
 $lang['docroot_leaveblank'] = 'Laat dit veld leeg voor de systeemstandaard';
 $lang['test_xmlreader_class'] = 'Controle of de XMLReader class bestaat';
@@ -11,7 +13,11 @@ $lang['ip_addr'] = 'IP-adres';
 $lang['install_admin_pwsalt_note'] = 'Als u er voor kiest om de wachtwoorden te versleutelen, dan is er geen enkele andere mogelijkheid meer om verloren admin-wachtwoorden te herstellen dan via de &#039;wachtwoord vergeten&#039;-functionaliteit. Het is dus van belang dat u voor iedere admin-account een geldig e-mailadres invoert.';
 $lang['admin_salt'] = 'Versleutel wachtwoorden van administrators';
 $lang['setup_flat_urls'] = 'Platte URL&#039;s worden weer aangemaakt!';
-$lang['install_timezone'] = 'Sommige webservers met PHP 5.3 hebben de tijdzone niet goed ingesteld. Selecteer hier &uacute;w juiste tijdzone. Als dit voor uw webserver niet van toepassing is, dan kiest u &quot;Geen&quot;. <strong>Opmerking:</strong> Dit is geen display instelling, maar is gerelateerd aan datum en tijd instellingen. U kunt deze instelling later altijd nog weer wijzigen in de config.php.';
+$lang['install_timezone2'] = 'Selecteer de tijdzone voor deze installatie.  Deze tijdzone zal worden gebruikt voor invoervelden en voor datum- en tijdberekeningen.<br />
+<br />
+CMSMS heeft geprobeerd een standaard in te stellen voor de huidige server locatie, de waarde kan echter niet correct zijn...<br />
+<br />
+<strong style=&quot;color: red;&quot;>Opmerking:</strong> Deze functie is gewijzigd ten opzichte van eerdere CMSMS versies. Het kan zijn dat u de <b>set_db_timezone</b> config waarde moet veranderen als de webserver in een andere tijdzone staat dan uw (admin) gebruikers.';
 $lang['timezone'] = 'Tijdzone';
 $lang['none'] = 'Geen';
 $lang['test_error_estrict'] = 'Error_reporting testen om er zeker van te zijn dat E_STRICT is uitgeschakeld';
@@ -71,7 +77,7 @@ $lang['errorfilenotwritable'] = 'Bestand niet beschrijfbaar!';
 $lang['nofiles'] = 'Deze bron bestaat niet!';
 $lang['is_directory'] = 'Deze bron is een map!';
 $lang['is_readable_false'] = 'Deze bron is niet leesbaar!';
-$lang['checksum_match'] = 'Checksum klopt!';
+$lang['checksum_match'] = 'Checksum correct!';
 $lang['checksum_not_match'] = 'Checksum komt niet overeen!';
 $lang['not_checksum'] = 'Geen checksum gevonden!';
 $lang['format_datetime'] = '%c ';
@@ -206,11 +212,11 @@ $lang['usernameincorrect'] = 'Gebruikersnaam of wachtwoord zijn niet correct';
 $lang['version'] = 'Versie';
 $lang['install_title'] = 'CMS Made Simple Installatie (stap %s)';
 $lang['install_system'] = 'Installeer Systeem';
-$lang['install_thanks'] = 'Bedankt voor het installeren van CMS Made Simple.';
+$lang['install_thanks'] = 'Bedankt voor het installeren van CMS Made Simple';
 $lang['upgrade_title'] = 'CMS Made Simple Upgrade (stap %s)';
 $lang['upgrade_system'] = 'Upgraden van het systeem';
 $lang['upgrade_thanks'] = 'Bedankt voor het upgraden van CMS Made Simple naar';
-$lang['install_please_read'] = 'Lees de <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting" > Installation Troubleshooting</a> pagina in het CMS Made Simple Documentatie Wiki.';
+$lang['install_please_read'] = 'Lees de <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Installation Troubleshooting</a> pagina op de offici&euml;le CMS Made Simple documentatie website';
 $lang['install_checking'] = 'Controleer rechten en PHP instellingen';
 $lang['install_test'] = 'Test ';
 $lang['install_result'] = 'Resultaat';
@@ -227,9 +233,8 @@ $lang['install_value_required'] = 'Een instelling voldoet niet aan de minimale e
 $lang['install_value_recommended'] = 'Een instelling is boven de vereiste, maar onder de aanbevolen waarde<br />of... een onderdeel dat <em>misschien</em> vereist is voor optionele functionaliteit is niet beschikbaar';
 $lang['install_value_exceed'] = 'Een instelling valt binnen of boven de aanbevolen drempel waardes<br />of... een onderdeel dat <em>misschien<em> vereist is voor optionele functionaliteit is beschikbaar
 ';
-$lang['install_test_failed'] = 'Een of meer van de tests zijn niet gelukt. Het systeem kan wel ge&iuml;nstalleerd worden, maar sommige functionaliteiten zullen misschien niet correct functioneren.<br />Probeer de situatie te corrigeren en klik op &quot;Probeer opnieuw&quot;, of klik op &quot;Volgende&quot;.
-';
-$lang['install_test_passed'] = 'Alle testen zijn gelukt (in ieder geval op het minimale niveau). Klik de &quot;Volgende&quot; button.';
+$lang['install_test_failed'] = 'Een of meer van de tests zijn niet geslaagd.<br />Het CMS kan wel ge&iuml;nstalleerd worden, maar sommige functionaliteiten kunnen misschien niet correct werken.<br />Probeer de server instellingen te corrigeren en klik op &quot;Probeer opnieuw&quot; of klik op &quot;Volgende&quot;.';
+$lang['install_test_passed'] = 'Alle testen zijn geslaagd (in ieder geval op het minimale niveau). Klik de &quot;Volgende&quot; button.';
 $lang['install_failed_again'] = 'E&eacute;n of meerdere testen zijn mislukt. Herstel de problemen en voer de test opnieuw uit.';
 $lang['install_try_again'] = 'Probeer opnieuw';
 $lang['install_continue'] = 'Volgende';
@@ -344,7 +349,7 @@ $lang['install_admin_update_hierarchy'] = 'Bijwerken van hierarchie posities...'
 $lang['install_admin_set_core_event'] = 'Opzetten van core events...';
 $lang['install_admin_install_modules'] = 'Bezig met installeren van modules...';
 $lang['install_admin_index_search'] = 'Indexeren voor zoekfunctie... ';
-$lang['install_admin_clear_cache'] = 'Verwijderen van site cache (indien aanwezig)';
+$lang['install_admin_clear_cache'] = 'Verwijderen van site cache...';
 $lang['install_admin_emailing'] = 'E-mail mijn admin account informatie...';
 $lang['install_admin_congratulations'] = 'Gefeliciteerd, de installatie is gelukt - hier is uw';
 $lang['could_not_connect_db'] = 'Kan geen verbinding maken met de database. Controleer de gebruikersnaam en het wachtwoord, en controleer of de gebruiker rechten heeft op de opgeven database.';
@@ -357,9 +362,8 @@ gebruikersnaam: %s
 wachtwoord: %s
 
 Log hier in op het beheerpaneel van de website: %s';
-$lang['utma'] = '156861353.1289126069.1327844918.1334919334.1338234714.10';
-$lang['utmz'] = '156861353.1329944852.5.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/latest_files';
-$lang['qca'] = 'P0-856617467-1310370352588';
+$lang['utma'] = '156861353.439918069.1379932820.1379932820.1379932820.1';
+$lang['utmz'] = '156861353.1379932820.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
