@@ -1,4 +1,9 @@
 <?php
+$lang['detected'] = 'Zisten&eacute;';
+$lang['docroot_leaveblank'] = 'Nechajte pr&aacute;zdne pre použitie prednastaven&yacute;ch syst&eacute;mov&yacute;ch nastaven&iacute;';
+$lang['test_xmlreader_class'] = 'Kontrolujem existenciu XMLReader ';
+$lang['test_xmlreader_failed'] = 'Trieda XMLReader nie je nain&scaron;talovan&aacute; na va&scaron;om serveri. M&ocirc;žete ďalej použ&iacute;vať  syst&eacute;m, av&scaron;ak nem&ocirc;žete in&scaron;talovať vzdialene moduly priamo cez CMS syst&eacute;m.';
+$lang['test_check_xml_failed'] = 'Va&scaron;a in&scaron;tal&aacute;cia PHP neobsahuje podporu XML. M&ocirc;žete naďalej použ&iacute;vať syst&eacute;m, av&scaron;ak nebudete m&ocirc;cť využ&iacute;vať spr&aacute;vcu modulov pre in&scaron;tal&aacute;ciu a aktualiz&aacute;ciu modulov cez vzdialen&yacute; server.';
 $lang['installed_module'] = 'Modul nain&scaron;talovan&yacute;';
 $lang['automatedtask_success'] = 'Automatizovan&eacute; &uacute;lohu prebehli &uacute;spe&scaron;ne';
 $lang['ip_addr'] = 'IP adresa';
@@ -259,7 +264,6 @@ $lang['test_may_not_exist'] = 'S&uacute;bor možno e&scaron;te neexistujte. Ak t
 $lang['could_not_retrieve_a_value'] = 'Nepodarilo sa z&iacute;skať hodnotu';
 $lang['displaying_the_value_originally'] = '<br />Zobrazovanie nastaven&iacute; z configuračn&eacute;ho s&uacute;boru (nemus&iacute; byť presn&eacute;)';
 $lang['test_check_xml_func'] = 'Kontrola z&aacute;kladne podpory pre XML (expat)';
-$lang['test_check_xml_failed'] = 'Va&scaron;a in&scaron;tal&aacute;cia PHP neobsahuje podporu XML. M&ocirc;žete naďalej použ&iacute;vať syst&eacute;m, av&scaron;ak nebudete m&ocirc;cť využ&iacute;vať spr&aacute;vcu modulov pre in&scaron;tal&aacute;ciu a aktualiz&aacute;ciu modulov cez vzdialen&yacute; server.';
 $lang['test_allow_url_fopen_failed'] = 'Pokiaľ nastavenie allow url fopen je vypnut&eacute;, nebudete mať pr&iacute;stup k vzdialen&eacute;mu využitiu protokolov http alebo ftp.';
 $lang['test_remote_url'] = 'Test vzdialenej URL';
 $lang['test_remote_url_failed'] = 'Pravdepodobne nebude m&ocirc;žno otvoriť s&uacute;bor cez vzdialen&yacute; web server. ';
@@ -347,8 +351,8 @@ už&iacute;vateľsk&eacute; meno: %s
 heslo: %s
 
 Prihl&aacute;ste sa pre administr&aacute;ciu str&aacute;nky: %s';
+$lang['utma'] = '156861353.178381654.1338891884.1338891884.1338891884.1';
 $lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.397069566.1316370484.1316370484.1316453841.2';
-$lang['utmz'] = '156861353.1316453841.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
+$lang['utmz'] = '156861353.1338891884.1.1.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
