@@ -1,4 +1,9 @@
 <?php
+$lang['detected'] = 'Identifierad';
+$lang['docroot_leaveblank'] = 'L&auml;mna f&auml;ltet tomt f&ouml;r att anv&auml;nda systemets standard';
+$lang['test_xmlreader_class'] = 'Kontrollerar om XMLReader class existerar';
+$lang['test_xmlreader_failed'] = 'The XMLReader class &auml;r inte tillg&auml;ngligt i din php installation.  Du kan fortfarande anv&auml;nda systemet men kommer inte att kunna anv&auml;nda n&aring;gon av de avl&auml;gsna funktionerna modulinstallation.';
+$lang['test_check_xml_failed'] = 'XML st&ouml;d saknas i din php installation. Du kan fortfarande anv&auml;nda systemet, fj&auml;rrinstallation av moduler via modulhanteraren kommer dock inte fungera.';
 $lang['installed_module'] = 'Modulen installerad';
 $lang['automatedtask_success'] = 'Automatisk uppgift lyckades';
 $lang['ip_addr'] = 'IP Adress';
@@ -259,7 +264,6 @@ $lang['test_may_not_exist'] = 'Denna fil kanske inte existerar &auml;n. Om den i
 $lang['could_not_retrieve_a_value'] = 'Kunde inte hitta ett v&auml;rde.... passerar &auml;nd&aring;.';
 $lang['displaying_the_value_originally'] = '<br />Visar v&auml;rdet som ursprungligen &auml;r angivet i config-filen (detta beh&ouml;ver inte vara riktigt).';
 $lang['test_check_xml_func'] = 'Kontrollerar basic XML (expat) support';
-$lang['test_check_xml_failed'] = 'XML st&ouml;d saknas i din php installation. Du kan fortfarande anv&auml;nda systemet, fj&auml;rrinstallation av moduler via modulhanteraren kommer dock inte fungera.';
 $lang['test_allow_url_fopen_failed'] = 'N&auml;r allow url fopen &auml;r inaktiverat kommer du inte att kunna komma &aring;t URL-objekt som fil som anv&auml;nder FTP- eller HTTP-protokollen.';
 $lang['test_remote_url'] = 'Test f&ouml;r avl&auml;gsna URL';
 $lang['test_remote_url_failed'] = 'Du kommer troligen inte att kunna &ouml;ppna filer p&aring; en fj&auml;rrserver';
@@ -347,9 +351,8 @@ anv&auml;ndarnamn: %s
 l&ouml;senord: %s
 
 Logga in p&aring; adminsidorna: %s';
-$lang['qca'] = 'P0-1088949386-1297632998614';
-$lang['utmz'] = '156861353.1313947469.1.1.utmccn=(organic)|utmcsr=google|utmctr=cmsms translation center|utmcmd=organic';
-$lang['utma'] = '156861353.301356295.1313947469.1313947469.1313950036.2';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1120957069.1339885466.1339885466.1339885466.1';
+$lang['utmz'] = '156861353.1339885466.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/|utmcmd=referral';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
