@@ -71,11 +71,20 @@ function &adodb_connect()
 		$dbinstance->debug = true;
 	}
 	
-	if($config['set_names'] == true)
-	{
-	  $dbinstance->Execute("SET NAMES 'utf8'");
+	$p1 = array();
+	if($config['set_names'] == true) {
+	  $p1[] = "NAMES 'utf8'";
 	}
-	
+	if($config['set_db_timezone'] == true) {
+	  $dt = new DateTime();
+	  $dtz = new DateTimeZone($config['timezone']);
+	  $offset = timezone_offset_get($dtz,$dt);
+	  $symbol = ($offset < 0) ? '-' : '+';
+	  $hrs = abs((int)($offset / 3600));
+	  $mins = abs((int)($offset % 3600));
+	  $p1[] = sprintf("time_zone = '%s%d:%02d'",$symbol,$hrs,$mins);
+	}
+	$dbinstance->Execute('SET '.implode(',',$p1));
 	return $dbinstance;
 }
 
@@ -95,9 +104,7 @@ function adodb_error($dbtype, $function_performed, $error_number, $error_message
 		echo "<strong>Database Connection Failed</strong><br />";
 		echo "Error: {$error_message} ({$error_number})<br />";
 		echo "Function Performed: {$function_performed}<br />";
-		echo "Host/DB: {$host}/{$database}<br />";
-		echo "Database Type: {$dbtype}<br />";
 	}
 }
 
-?>
+?>
\ No newline at end of file
