@@ -54,7 +54,7 @@ class cms_http_request
     /**
      * Contains the target path
      *
-     * @var string
+o     * @var string
      */
     private $path;
     
@@ -313,6 +313,8 @@ class cms_http_request
      */
     function clear()
     {
+      $config = cmsms()->GetConfig();
+
         // Set the request defaults
         $this->host         = '';
         $this->port         = 0;
@@ -333,7 +335,7 @@ class cms_http_request
         $this->status       = 0;
         $this->timeout      = '25';
         $this->useCurl      = TRUE;
-        $this->referrer     = '';
+        $this->referrer     = $config['root_url'].'::'.CMS_VERSION;
         $this->username     = '';
         $this->password     = '';
         $this->redirect     = FALSE;
@@ -345,7 +347,7 @@ class cms_http_request
         $this->saveCookie   = TRUE;
         $this->maxRedirect  = 3;
         $this->cookiePath   = TMP_CACHE_LOCATION.'/c'.md5(get_class().session_id()).'.dat'; // by default, use a cookie file that is unique only to this session.
-        $this->userAgent    = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.9';
+        $this->userAgent    = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.6) Gecko/20070725 Firefox/2.0.0.9 CMSMS:'.CMS_VERSION;
     }
     
     /**
@@ -381,6 +383,7 @@ class cms_http_request
      */
     function setMethod($method)
     {
+      $method = strtoupper($method);
         if ($method == 'GET' || $method == 'POST')
         {
             $this->method = $method;
@@ -445,6 +448,7 @@ class cms_http_request
 
     function setRawPostData($data)
     {
+      $this->setMethod('POST');
       $this->rawPostData = $data;
     }
 
@@ -688,7 +692,7 @@ class cms_http_request
     }
 
 
-    private function _isCurlSuitable()
+    public static function is_curl_suitable()
     {
       static $_curlgood = -1;
 
@@ -753,7 +757,7 @@ class cms_http_request
         }
 
         // If cURL is not installed, we'll force fscokopen
-	$this->useCurl = $this->useCurl && $this->_isCurlSuitable();
+	$this->useCurl = $this->useCurl && self::is_curl_suitable();
         
         // GET method configuration
         if($this->method == 'GET')
@@ -949,7 +953,6 @@ class cms_http_request
             }
             
             // Specify the referrer
-	    $this->addRequestHeader("Referer: " . $this->referrer);
             if ($this->referrer != '')
             {
 	      $this->addRequestHeader("Referer: " . $this->referrer);
