@@ -17,7 +17,7 @@
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 #
-#$Id: Content.inc.php 8194 2012-07-23 16:56:58Z calguy1000 $
+#$Id: Content.inc.php 8433 2012-10-30 22:30:33Z calguy1000 $
 
 /**
  * Class definition and methods for Content
@@ -55,11 +55,6 @@ class Content extends ContentBase
 	 * @var string
 	 */
     protected $stylesheet;
-	/**
-	 * @access private
-	 * @var array
-	 */
-	private $__fieldhash;
 
 	/**
 	 * Indicate whether or not this content type may be copied
@@ -121,7 +116,7 @@ class Content extends ContentBase
 
 		if (isset($params))
 			{
-				$this->__fieldhash = null; // clear the field hash.
+				//$this->__fieldhash = null; // clear the field hash.
 				$parameters = array('pagedata','searchable','disable_wysiwyg');
 
 				//pick up the template id before we do parameters
@@ -322,9 +317,11 @@ class Content extends ContentBase
 
 	private function _get_form_data()
 	{
-		if( isset($this->__fieldhash) && is_array($this->__fieldhash) ) return;
-		$tmp = $this->SetupForm();
-		if( is_array($tmp) && count($tmp) ) $this->__fieldhash = $tmp;
+		static $__fieldhash = null;
+		if( $__fieldhash == null ) {
+			$__fieldhash = $this->SetupForm();
+		}
+		return $__fieldhash;
 	}
 
 	/**
@@ -334,8 +331,8 @@ class Content extends ContentBase
 	 */
     function TabNames()
     {
-		$this->_get_form_data();
-		return array_keys($this->__fieldhash);
+		$tmp = $this->_get_form_data();
+		return array_keys($tmp);
     }
 
 	/**
@@ -348,7 +345,7 @@ class Content extends ContentBase
 	 */
     function EditAsArray($adding = false, $tab = 0, $showadmin = false)
     {
-		$this->_get_form_data();
+		$fieldhash = $this->_get_form_data();
 		$tabnames = $this->TabNames(); 
 	
 		$templateops = cmsms()->GetTemplateOperations();
@@ -361,7 +358,7 @@ class Content extends ContentBase
 
 		if( isset($tabnames[$tab]) )
 		{
-			return $this->__fieldhash[$tabnames[$tab]];
+			return $fieldhash[$tabnames[$tab]];
 		}
     }
 
@@ -451,21 +448,11 @@ class Content extends ContentBase
     private function parse_content_blocks()
     {
 		if ($this->_contentBlocksLoaded) return TRUE;
-		$smarty = cmsms()->GetSmarty();
-		$smarty->force_compile = TRUE;
 		
-		$ocompid = $smarty->compile_id;
-		$smarty->compile_id = 'c'.time();
-		$smarty->registerDefaultPluginHandler(array(&$smarty,'_dummyDfltPluginHandler'));
-		$smarty->registerPlugin('compiler','content',array('CMS_Content_Block','smarty_compiler_contentblock'),false);
-		$smarty->registerPlugin('compiler','content_image',array('CMS_Content_Block','smarty_compiler_imageblock'),false);
-		$smarty->registerPlugin('compiler','content_module',array('CMS_Content_Block','smarty_compiler_moduleblock'),false);
-		$smarty->registerResource('template',new CMSPageTemplateResource(''));
-		$smarty->fetch('template:'.$this->TemplateId(),'x'.time(),'c'.time()); // do the magic.
-		$smarty->registerDefaultPluginHandler(array(&$smarty,'defaultPluginHandler'));
-		$smarty->compile_id = $ocompid;
+		$parser = cmsms()->get_template_parser();
+		$parser->fetch('template:'.$this->TemplateId()); // do the magic.
 
-		$this->_contentBlocks = CMS_Content_block::get_content_blocks();
+		$this->_contentBlocks = CMS_Content_Block::get_content_blocks();
 
 		if( !is_array($this->_contentBlocks) || !count($this->_contentBlocks) ) 
 			return FALSE;
