@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 8156 2012-07-06 04:37:25Z calguy1000 $
+#$Id: misc.functions.php 9235 2014-01-27 15:25:37Z uniqu3 $
 
 /**
  * Misc functions
@@ -36,10 +36,12 @@
  */
 function redirect($to, $noappend=false)
 {
-     $_SERVER['PHP_SELF'] = null;
+  $_SERVER['PHP_SELF'] = null;
 
-    $schema = $_SERVER['SERVER_PORT'] == '443' ? 'https' : 'http';
-    $host = strlen($_SERVER['HTTP_HOST'])?$_SERVER['HTTP_HOST']:$_SERVER['SERVER_NAME'];
+  $schema = 'http';
+  if( isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] != 'off' ) $schema = 'https';
+
+  $host = strlen($_SERVER['HTTP_HOST'])?$_SERVER['HTTP_HOST']:$_SERVER['SERVER_NAME'];
 
     $components = parse_url($to);
     if(count($components) > 0)
@@ -313,7 +315,7 @@ function cms_cleanfile($filename)
  */
 function my_htmlentities($val, $convert_single_quotes = false)
 {
-  return cms_htmlentities($val,ENT_QUOTES,'UTF-8',$confvert_single_quotes);
+  return cms_htmlentities($val,ENT_QUOTES,'UTF-8',$convert_single_quotes);
 }
 
 
@@ -357,8 +359,7 @@ function cms_utf8entities($val)
  */
 function debug_bt_to_log()
 {
-  if( cmsms()->config['debug_to_log'] || check_login(TRUE) )
-    {
+  if( cmsms()->config['debug_to_log'] || check_login(TRUE) ) {
       $bt=debug_backtrace();
       $file = $bt[0]['file'];
       $line = $bt[0]['line'];
@@ -367,21 +368,20 @@ function debug_bt_to_log()
       $out[] = "Backtrace in $file on line $line";
 
       $bt = array_reverse($bt);
-      foreach($bt as $trace)
-	{
-	  if( $trace['function'] == 'debug_bt_to_log' ) continue;
+      foreach($bt as $trace) {
+	if( $trace['function'] == 'debug_bt_to_log' ) continue;
 
-	  $file = $trace['file'];
-	  $line = $trace['line'];
-	  $function = $trace['function'];
-	  $out[] = "$function at $file:$line"; 
-	}
+	$file = $line = '';
+	if( isset($trace['file']) ) $file = $trace['file'];
+	if( isset($trace['line']) ) $line = $trace['line'];
+	$function = $trace['function'];
+	$out[] = "$function at $file:$line"; 
+      }
 
       $filename = TMP_CACHE_LOCATION . '/debug.log';
-      foreach ($out as $txt)
-	{
-	  error_log($txt . "\n", 3, $filename);
-	}
+      foreach ($out as $txt) {
+	error_log($txt . "\n", 3, $filename);
+      }
     }
 }
 
@@ -546,18 +546,17 @@ function debug_output($var, $title="")
  */
 function debug_to_log($var, $title='',$filename = '')
 {
-  if( cmsms()->config['debug_to_log'] || check_login(TRUE) )
-    {
-      if( $filename == '' )
-	{
-	  $filename = TMP_CACHE_LOCATION . '/debug.log';
-	}
-      $errlines = explode("\n",debug_display($var, $title, false, false));
-      foreach ($errlines as $txt)
-	{
-	  error_log($txt . "\n", 3, $filename);
-	}
+  if( cmsms()->config['debug_to_log'] || check_login(TRUE) ) {
+    if( $filename == '' ) {
+      $filename = TMP_CACHE_LOCATION . '/debug.log';
+      $x = @filemtime($filename);
+      if( $x !== FALSE && $x < (time() - 24 * 3600) ) @unlink($filename);
     }
+    $errlines = explode("\n",debug_display($var, $title, false, false));
+    foreach ($errlines as $txt) {
+      error_log($txt . "\n", 3, $filename);
+    }
+  }
 }
 
 
@@ -2184,15 +2183,23 @@ function cms_to_bool($str)
 /**
  *
  */
-function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$custom_root='')
+function cms_get_jquery($exclude = '',$ssl = null,$cdn = false,$append = '',$custom_root='')
 {
   $config = cms_config::get_instance();
   $scripts = array();
-  $basePath=$custom_root!=''?trim($custom_root,'/'):($ssl?$config['ssl_url']:$config['root_url']);
+  $base_url = $config['root_url'];
+  if( is_null($ssl) ) {
+    $base_url = $config->smart_root_url();
+  }
+  else if( $ssl === true || $ssl === TRUE ) {
+    $base_url = $config['ssl_url'];
+  }
+  $basePath=$custom_root!=''?trim($custom_root,'/'):$base_url;
   
   // Scripts to include
-  $scripts['jquery.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js':$basePath.'/lib/jquery/js/jquery-1.7.2.min.js').'"></script>'."\n";
-  $scripts['jquery-ui.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.21/jquery-ui.min.js':$basePath.'/lib/jquery/js/jquery-ui-1.8.21.custom.min.js').'"></script>'."\n";
+  $scripts['jquery.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jquery/1.11.0/jquery.min.js':$basePath.'/lib/jquery/js/jquery-1.11.0.min.js').'"></script>'."\n"
+  . '<script type="text/javascript" src="' . $basePath .'/lib/jquery/js/jquery-migrate-1.2.1.min.js"></script>' . "\n";
+  $scripts['jquery-ui.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jqueryui/1.10.4/jquery-ui.min.js':$basePath.'/lib/jquery/js/jquery-ui-1.10.4.custom.min.js').'"></script>'."\n";
   $scripts['jquery.ui.nestedSortable.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.ui.nestedSortable-1.3.4.js"></script>'."\n";
   $scripts['jquery.json.min.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.json-2.3.min.js"></script>'."\n";
   
@@ -2240,39 +2247,67 @@ function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$cu
  */	
 if(!function_exists('get_called_class')) {
   function get_called_class() {
-    return cms_function_help::get_called_class();
+    try {
+      return cms_function_help::get_called_class();
+    }
+    catch( Exception $e ) {
+      // ignore
+    }
   }
   // this class must exist in this file until CMSMS 1.12 when we dont have to worry abut PHP 5.2
   // this file is loaded before the autoloader runs.
   class cms_function_help {
 
-    static $i = 0;
-    static $fl = null;
-	
-    public static function get_called_class() {
-	
-      $bt = debug_backtrace();
-		
-      if(self::$fl == $bt[2]['file'].$bt[2]['line']) {
-	self::$i++;
-      } else {
-	self::$i = 0;
-	self::$fl = $bt[2]['file'].$bt[2]['line'];
+    public static function get_called_class($bt = false,$l = 1) 
+    {
+      if (!$bt) $bt = debug_backtrace();
+      if (!isset($bt[$l])) throw new Exception("Cannot find called class -> stack level too deep.");
+      if (!isset($bt[$l]['type'])) { 
+        if( $l >= 2 ) {
+	  throw new Exception ('type not set');
+        }
+        else {
+          return self::get_called_class($bt,$l+1);
+        }
       }
-		
-      $lines = file($bt[2]['file']);
-		
-      preg_match_all('/([a-zA-Z0-9\_]+)::'.$bt[2]['function'].'/',
-		     $lines[$bt[2]['line']-1],
-		     $matches);
-		
-      if( isset($matches[1][self::$i]) )
-	{
-	  return $matches[1][self::$i];
+      else switch ($bt[$l]['type']) {
+      case '::':
+	$lines = file($bt[$l]['file']);
+	$i = 0;
+	$callerLine = '';
+	do {
+	  $i++;
+	  $callerLine = $lines[$bt[$l]['line']-$i] . $callerLine;
+	} while (stripos($callerLine,$bt[$l]['function']) === false);
+	preg_match('/([a-zA-Z0-9\_]+)::'.$bt[$l]['function'].'/',
+		   $callerLine,
+		   $matches);
+	if (!isset($matches[1])) {
+         
+	  // must be an edge case.
+	  throw new Exception ("Could not find caller class: originating method call is obscured.");
 	}
+	switch ($matches[1]) {
+	case 'self':
+	case 'parent':
+	  return self::get_called_class($bt,$l+1);
+	default:
+	  return $matches[1];
+	}
+	// won't get here.
+      case '->': switch ($bt[$l]['function']) {
+	case '__get':
+	  // edge case -> get class of calling object
+	  if (!is_object($bt[$l]['object'])) throw new Exception ("Edge case fail. __get called on non object.");
+	  return get_class($bt[$l]['object']);
+	default: return $bt[$l]['class'];
+	}
+
+      default: throw new Exception ("Unknown backtrace method type");
+      }
     }
   }
-}
+ }
 
 # vim:ts=4 sw=4 noet
 ?>
