@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: page.functions.php 8145 2012-06-30 16:02:30Z calguy1000 $
+#$Id: page.functions.php 8987 2013-09-23 15:41:36Z calguy1000 $
 
 /**
  * Page related functions.  Generally these are functions not necessarily
@@ -173,7 +173,9 @@ function check_passhash($userid, $checksum)
 	$userops = $gCms->GetUserOperations();
 	$oneuser = $userops->LoadUserByID($userid);
 
-	if ($oneuser && (string)$checksum != '' && $checksum == md5(md5($config['root_path'] . '--' . $oneuser->password)))
+	$tmp = array(md5(__FILE__),$oneuser->password,cms_utils::get_real_ip(),$_SERVER['HTTP_USER_AGENT']);
+	$tmp = md5(serialize($tmp));
+	if ($oneuser && (string)$checksum != '' && $checksum == $tmp )
 	{
 		$check = true;
 	}
@@ -198,15 +200,17 @@ function generate_user_object($userid)
   $gCms = cmsms();
 	$config = $gCms->GetConfig();
 
-	$userops =& $gCms->GetUserOperations();
-	$oneuser =& $userops->LoadUserByID($userid);
+	$userops = $gCms->GetUserOperations();
+	$oneuser = $userops->LoadUserByID($userid);
 
 	if ($oneuser)
 	{
 		$_SESSION['cms_admin_user_id'] = $userid;
 		$_SESSION['cms_admin_username'] = $oneuser->username;
 		cms_cookies::set('cms_admin_user_id', $oneuser->id);
-		cms_cookies::set('cms_passhash', md5(md5($config['root_path'] . '--' . $oneuser->password)));
+		$tmp = array(md5(__FILE__),$oneuser->password,cms_utils::get_real_ip(),$_SERVER['HTTP_USER_AGENT']);
+		$tmp = md5(serialize($tmp));
+		cms_cookies::set('cms_passhash', $tmp);
 	}
 }
 
@@ -372,38 +376,35 @@ function author_pages($userid)
   $gCms = cmsms();
   $db = $gCms->GetDb();
   $userops = $gCms->GetUserOperations();
-        $variables = &$gCms->variables;
-	if (!isset($variables['authorpages']))
-	{
-		// Get all of the pages this user owns
-		$query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE owner_id = ?";
-		$data = $db->GetCol($query, array($userid));
+  $variables = &$gCms->variables;
+  if (!isset($variables['authorpages'])) {
+    // Get all of the pages this user owns
+    $query = "SELECT content_id FROM ".cms_db_prefix()."content WHERE owner_id = ?";
+    $data = $db->GetCol($query, array($userid));
 
-		// Get all of the pages this user has access to.
-		$query = "SELECT user_id,content_id FROM ".cms_db_prefix()."additional_users";
-		$result = $db->GetArray($query);
-		foreach( $result as $row )
-		{
-		  $uid = $row['user_id'];
-		  $content_id = $row['content_id'];
-		  if( $uid == $userid )
-		    {
-		      $data[] = $content_id;
-		    }
-		  else if( $uid < 0 )
-		    {
-		      $gid = $uid * -1;
-		      if( $userops->UserInGroup($userid,$gid) )
-			{
-			  $data[] = $content_id;
-			}
-		    }
-		}
-
-		$variables['authorpages'] = $data;
+    // Get all of the pages this user has access to.
+    $query = "SELECT user_id,content_id FROM ".cms_db_prefix()."additional_users";
+    $result = $db->GetArray($query);
+    if( is_array($result) && count($result) ) {
+      foreach( $result as $row ) {
+	$uid = $row['user_id'];
+	$content_id = $row['content_id'];
+	if( $uid == $userid ) {
+	  $data[] = $content_id;
 	}
+	else if( $uid < 0 ) {
+	  $gid = $uid * -1;
+	  if( $userops->UserInGroup($userid,$gid) ) {
+	    $data[] = $content_id;
+	  }
+	}
+      }
+    }
 
-	return $variables['authorpages'];
+    $variables['authorpages'] = $data;
+  }
+
+  return $variables['authorpages'];
 }
 
 /**
@@ -596,9 +597,10 @@ function create_textarea($enablewysiwyg, $text, $name, $classname = '', $id = ''
   $result = '';
   $uid = get_userid(false);
 
-  if ($enablewysiwyg == true || $forcewysiwyg)
-    {
+  if ($enablewysiwyg == true)
+  {
       $module = cms_utils::get_wysiwyg_module($forcewysiwyg);
+      
       if( $module )
 	{
 	  $result = $module->WYSIWYGTextArea($name,$width,$height,$encoding,$text,$stylesheet,$addtext);
@@ -607,10 +609,12 @@ function create_textarea($enablewysiwyg, $text, $name, $classname = '', $id = ''
 
   if( !$result && $wantedsyntax )
     {
+
       // here we should get a list of installed/available modules.
       $module = cmsms()->GetModuleOperations()->GetSyntaxHighlighter($forcewysiwyg);
       if( $module )
 	{
+
 	  $result = $module->SyntaxTextArea($name,$wantedsyntax,$width,$height,$encoding,$text,$addtext);
 	}
     }
@@ -791,12 +795,12 @@ function get_pageid_or_alias_from_url()
   if (isset($smarty->id) && isset($params[$smarty->id . 'returnid']))
     {
       // get page from returnid parameter in module action
-      $page = $params[$smarty->id . 'returnid'];
+      $page = (int)$params[$smarty->id . 'returnid'];
     }
-  else if (isset($config["query_var"]) && $config["query_var"] != '' && isset($_GET[$config["query_var"]]))
+  else if (isset($config["query_var"]) && $config["query_var"] != '' && isset($_REQUEST[$config["query_var"]]))
     {
       // using non friendly urls... get the page alias/id from the query var.
-      $page = $_GET[$config["query_var"]];    
+      $page = trim(cms_htmlentities($_REQUEST[$config["query_var"]])); 
     }
   else
     {
@@ -808,11 +812,12 @@ function get_pageid_or_alias_from_url()
 	  if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['REQUEST_URI'], $matches))
 	    {
 	      // pretty urls... grab all the stuff after the index.php
-	      $page = $matches[1];
+	      $page = cms_htmlentities($matches[1]);
 	    }
 	}
     }
 
+  unset($_REQUEST[$config['query_var']]);
 
   // by here, if page is empty, use the default page id
   if ($page == '')
