@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listcontent.php 7484 2011-10-26 18:23:21Z calguy1000 $
+#$Id: listcontent.php 8955 2013-09-16 17:41:42Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 require_once("../include.php");
@@ -33,6 +33,7 @@ define('XAJAX_DEFAULT_CHAR_ENCODING', $config['admin_encoding']);
 
 require_once(dirname(dirname(__FILE__)) . '/lib/xajax/xajax_core/xajax.inc.php');
 $xajax = new xajax();
+//$xajax->configure('requestURI',$config['admin_url'].'/listcontent.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY]);
 $xajax->register(XAJAX_FUNCTION,'content_list_ajax');
 $xajax->register(XAJAX_FUNCTION,'content_setactive');
 $xajax->register(XAJAX_FUNCTION,'content_setinactive');
@@ -45,9 +46,22 @@ $xajax->register(XAJAX_FUNCTION,'content_delete');
 // $xajax->register(XAJAX_FUNCTION,'reorder_display_list');
 // $xajax->register(XAJAX_FUNCTION,'reorder_process');
 $xajax->processRequest();
-$headtext = $xajax->getJavascript($config['root_url'] . '/lib/xajax')."\n";
+$headtext = $xajax->getJavascript('../lib/xajax')."\n";
 include_once("header.php");
 
+function prettyurls_ok()
+{
+  static $_prettyurls_ok = -1;
+  if( -1 < $_prettyurls_ok ) return $_prettyurls_ok;
+
+  $config = cmsms()->GetConfig();
+  if( isset($config['url_rewriting']) && $config['url_rewriting'] != 'none' )
+    $_prettyurls_ok = 1;
+  else
+    $_prettyurls_ok = 0;
+  return $_prettyurls_ok;
+}
+
 function content_list_ajax()
 {
 	$objResponse = new xajaxResponse();
@@ -114,6 +128,8 @@ function setdefault($contentid)
 			}
 		}
 
+		audit($contentid,'Core','Content item set as default');
+
 		$result = true;
 		$contentops = $gCms->GetContentOperations();
 		$contentops->ClearCache();
@@ -177,19 +193,22 @@ function content_collapseall()
 function expandall()
 {
 	$userid = get_userid();
-	$contentops = cmsms()->GetContentOperations();
-	$all = $contentops->GetAllContent(false);
-	$cs = '';
-	foreach ($all as $thisitem)
+	$hiermanager = cmsms()->GetHierarchyManager();
+
+	function _expandall_sub($node,&$list)
 	{
-	  if( is_object($thisitem) && $thisitem instanceof ContentBase )
-	    {
-		if ($thisitem->HasChildren())
-		{
-			$cs .= $thisitem->Id().'=1.';
-		}
+	  if( $node->has_children() ) {
+	    if( ($id = $node->get_tag('id')) > 0 ) $list[] = "$id=1";
+	    $children = $node->get_children();
+	    for( $i = 0; $i < count($children); $i++ ) {
+	      _expandall_sub($children[$i],$list);
 	    }
+	  }
 	}
+
+	$list = array();
+	_expandall_sub($hiermanager,$list);
+	$cs = implode('.',$list);
 	set_preference($userid, 'collapse', $cs);
 }
 
@@ -348,8 +367,9 @@ function deletecontent($contentid)
 	$access = (check_permission($userid, 'Remove Pages') &&
 	  (check_ownership($userid,$contentid) ||
 	   quick_check_authorship($contentid,$mypages)))
-	  || check_permission($userid, 'Manage All Content');
-	
+	  || check_permission($userid, 'Manage All Content') 
+	  || check_permission($userid, 'Modify Any Page');
+
 	$gCms = cmsms();
 	$hierManager = $gCms->GetHierarchyManager();
 
@@ -405,7 +425,7 @@ function deletecontent($contentid)
 				toggleexpand($contentid, true);
 				
 				// put mention into the admin log
-				audit($contentid, 'Content Item: '.$title, 'Deleted');
+				audit($contentid, 'Core', 'Content Item: '.$title, 'Deleted');
 				
 				$contentops->ClearCache();
 			
@@ -533,13 +553,13 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    {
 	      if (!in_array($one->Id(),$openedArray))
 		{
-		  $txt .= "<a href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=0&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'false'); return false;\">";
+		  $txt .= "<a class=\"expand\" href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=0&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'false'); return false;\">";
 		  $txt .= $expandImg;
 		  $txt .= "</a>";
 		}
 	      else
 		{
-		  $txt .= "<a href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=1&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'true'); return false;\">";
+		  $txt .= "<a class=\"contract\" href=\"{$thisurl}&amp;content_id=".$one->Id()."&amp;col=1&amp;page=".$page."\" onclick=\"xajax_content_toggleexpand(".$one->Id().", 'true'); return false;\">";
 		  $txt .= $contractImg;
 		  $txt .= "</a>";
 		}
@@ -575,7 +595,8 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 		  $str = $one->Name();
 		}
 	      if ($display == 'edit')
-		$txt .= '<a href="editcontent.php'.$urlext.'&amp;content_id='.$one->Id().'&amp;page='.$page.'" title="'. cms_htmlentities($one->Name().' ('.$one->Alias().')', '', '', true). '">' . cms_htmlentities($str, '', '', true) . '</a>';
+		$txt .= '<a class="tooltip" href="editcontent.php'.$urlext.'&amp;content_id='.$one->Id().'&amp;page='.$page.'" title="'. cms_htmlentities($one->Name().' ('.$one->Alias().')', '', '', true). '" onmouseover="document.getElementById(\'' .$one->Id().'_info\').style.display = \'inline-block\';" onmouseout="document.getElementById(\''.$one->Id().'_info\').style.display = \'none\';">
+			' . cms_htmlentities($str, '', '', true) . '<span id="'.$one->Id().'_info"><strong>'.lang('content_id').':</strong> '.$one->Id().'<br /> <strong>'.lang('title').':</strong> '. cms_htmlentities($one->Name()).'<br /> <strong>'.lang('pagealias').':</strong> '.$one->Alias().'</span></a>';
 	      else
 		$txt .= cms_htmlentities($str, '', '', true);
 	    }
@@ -608,6 +629,11 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 		}
 	      $txt = $url;
 	    }
+	  if( !empty($txt) ) {
+	    if( !prettyurls_ok() ) {
+	      $txt = '<span style="color: red;" title="'.lang('prettyurls_noeffect').'">'.$txt.'<span>';
+	    }
+	  }
 	  if( !empty($txt) ) $columns['url'] = $txt;
 	}
 
@@ -812,9 +838,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 	    {
 	      if ($root->getChildrenCount() == 0 && 
 		  ((check_permission($userid, 'Remove Pages') &&
-		    (check_ownership($userid,$one->Id()) || 
-		     quick_check_authorship($one->Id(),$mypages)))
-		   || check_permission($userid,'Manage All Content')) 
+		    (check_ownership($userid,$one->Id()) || quick_check_authorship($one->Id(),$mypages))) || check_permission($userid,'Manage All Content') || check_permission($userid,'Modify Any Page'))
 		 )
 		{
 		  //$txt .= "<a href=\"{$thisurl}&amp;deletecontent=".$one->Id()."\" onclick=\"confirm('".cms_html_entity_decode_utf8(lang('deleteconfirm', $one->mName), true)."');\">";
@@ -902,7 +926,7 @@ function display_hierarchy(&$root, &$userid, $modifyall, &$users, &$menupos, &$o
 
 function display_content_list($themeObject = null)
 {
-  $gCms = cmsms();
+        $gCms = cmsms();
 	global $thisurl;
 	global $urlext;
 
@@ -976,7 +1000,7 @@ function display_content_list($themeObject = null)
 		}
 	}
 
-  debug_buffer('At Start of Display Content List');
+	debug_buffer('At Start of Display Content List');
         $hierarchy = $gCms->GetHierarchyManager();
 
 	$rowcount = 0;
@@ -1125,6 +1149,7 @@ function display_content_list($themeObject = null)
 	    bulkcontentoperations::register_function(lang('secure'),'secure');
 	    bulkcontentoperations::register_function(lang('insecure'),'insecure');
 	    bulkcontentoperations::register_function(lang('settemplate'),'settemplate');
+		bulkcontentoperations::register_function(lang('changeowner'),'changeowner');
 	  }
 	$opts = bulkcontentoperations::get_operation_list();
 	if( !empty($opts) )
@@ -1185,6 +1210,7 @@ function display_content_list($themeObject = null)
 	return $headoflist . $thelist . $footer .'</form></div>';
 }
 
+
 echo $themeObject->ShowMessage('', 'message');
 echo $themeObject->ShowErrors('' ,'error');
 ?>
@@ -1239,6 +1265,10 @@ if (isset($_GET['col']) && isset($_GET['content_id']))
 
 echo '<div class="pageoverflow">';
 echo $themeObject->ShowHeader('currentpages').'</div>';
+debug_buffer('test before loadallcontent');
+cmsms()->GetContentOperations()->LoadAllContent(FALSE,TRUE);
+
+debug_buffer('test after loadallcontent');
 echo '<div id="contentlist">'.display_content_list($themeObject).'</div>';
 
 ?>
