@@ -104,6 +104,7 @@ class NCleanGreyTheme extends AdminTheme
      */
 	function ThemeHeader(){
 		
+        echo '<link rel="stylesheet" type="text/css" href="themes/NCleanGrey/css/default-cmsms/jquery-ui-1.8.21.custom.css" />'."\n";
 		echo '<script type="text/javascript" src="themes/NCleanGrey/includes/standard.js"></script>'."\n";
 		echo '<link rel="shortcut icon" href="themes/NCleanGrey/images/layout/ncleangrey-favicon.ico" />'."\n";
 		echo '<link rel="Bookmark" href="themes/NCleanGrey/images/layout/ncleangrey-favicon.ico" />';
@@ -135,7 +136,7 @@ class NCleanGreyTheme extends AdminTheme
 
     function DisplayTopMenu()
     {
-	
+      $config = cmsms()->GetConfig();	
       $urlext='?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
 	echo '<div id="ncleangrey-container">';
 	//LOGO
@@ -160,7 +161,7 @@ class NCleanGreyTheme extends AdminTheme
 		echo '<div class="breadcrumbs">';
      	//ICON VIEW SITE
 	echo "\n\t<div id=\"nav-icons_all\"><ul id=\"nav-icons\">\n";
-	echo "\n\t<li class=\"viewsite-icon\"><a  rel=\"external\" title=\"".lang('viewsite')."\"  href=\"".$this->_viewsite_url."\">".lang('viewsite')."</a></li>\n";
+	echo "\n\t<li class=\"viewsite-icon\"><a  rel=\"external\" title=\"".lang('viewsite')."\"  href=\"".$config['root_url']."\">".lang('viewsite')."</a></li>\n";
 	//ICON LAGOUT
 	echo "\n\t<li class=\"logout-icon\"><a  title=\"".lang('logout')."\"  href=\"logout.php\">".lang('logout')."</a></li>\n";
 	echo "\n\t</ul></div>\n";     
@@ -192,7 +193,7 @@ class NCleanGreyTheme extends AdminTheme
 		  }
 
 		echo '</p></div>';
-		//LINE AFETER breadcrumbs 
+		//LINE AFTER breadcrumbs 
 		echo '<div class="hstippled">&nbsp;</div>';
     }
 
@@ -203,7 +204,6 @@ class NCleanGreyTheme extends AdminTheme
 		//FOOTER
 		echo '<div id="footer">
 		<a rel="external" href="http://www.cmsmadesimple.org"><b>CMS Made Simple</b></a><b>&trade;</b> &nbsp;&nbsp;&nbsp; '.$CMS_VERSION.' &nbsp;"' . $CMS_VERSION_NAME . '"</div><!--end footer-->';
-		//<br /><span class="icons-license">Icons by <a rel="external" href="http://dryicons.com">DryIcons</a></span>
 		//END
 	}
 	
@@ -239,10 +239,9 @@ class NCleanGreyTheme extends AdminTheme
 	echo '<h3 style="margin:0;">'.lang('help').'</h3>';
 	echo '<ul style="margin:0;">';
 	echo '<li><a rel="external" href="http://forum.cmsmadesimple.org/">'.lang('forums').'</a></li>';
-	echo '<li><a rel="external" href="http://wiki.cmsmadesimple.org/">'.lang('wiki').'</a></li>';
+	echo '<li><a rel="external" href="http://docs.cmsmadesimple.org/">'.lang('documentation').'</a></li>';
 	echo '<li><a rel="external" href="http://dev.cmsmadesimple.org/">'.lang('forge').'</a></li>';
 	echo '<li><a rel="external" href="http://cmsmadesimple.org/main/support/IRC">'.lang('irc').'</a></li>';
-	echo '<li><a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Admin_Panel/Extensions/Modules">'.lang('module_help').'</a></li>';
 	echo '</ul>';
 	echo '</div>';
 	echo '</div>';
@@ -547,7 +546,7 @@ class NCleanGreyTheme extends AdminTheme
 	}
     }
    
-	/* Functions that we want dont want the standard output from */
+	/* Functions that we want don't want the standard output from */
 	function OutputFooterJavascript() {}	
 }
-?>
+?>
\ No newline at end of file
